@@ -30,13 +30,7 @@
 #include <gtk/gtk.h>
 
 void ui_populate_fliplist_menu(GtkWidget *menu, int unit, int separator_count);
-
-gboolean ui_fliplist_add_current_cb(GtkWidget *widget, gpointer data);
-gboolean ui_fliplist_remove_current_cb(GtkWidget *widget, gpointer data);
-gboolean ui_fliplist_next_cb(GtkWidget *widget, gpointer data);
-gboolean ui_fliplist_prev_cb(GtkWidget *widget, gpointer data);
-
-gboolean ui_fliplist_load_callback(GtkWidget *widget, gpointer data);
-gboolean ui_fliplist_save_callback(GtkWidget *widget, gpointer data);
+void ui_fliplist_load_dialog_show(int unit);
+void ui_fliplist_save_dialog_show(int unit);
 
 #endif
