@@ -33,7 +33,7 @@
 
 #include "vice.h"
 
-#include "tick.h"
+#include "archdep.h"
 #include "viewport.h"
 #include "video.h"
 
