@@ -47,14 +47,14 @@ enum {
 
 
 GtkWidget *vice_gtk3_message_info(const char *title,
-                                  const char *fmt, ...);
+                                  const char *fmt, ...) VICE_ATTR_PRINTF2;
 
 GtkWidget *vice_gtk3_message_confirm(void (*callback)(GtkDialog *, gboolean),
                                      const char *title,
-                                     const char *fmt, ...);
+                                     const char *fmt, ...) VICE_ATTR_PRINTF3;
 
 GtkWidget *vice_gtk3_message_error(const char *title,
-                                   const char *fmt, ...);
+                                   const char *fmt, ...) VICE_ATTR_PRINTF2;
 
 GtkWidget *vice_gtk3_integer_input_box(
         void (*callback)(GtkDialog *, int, gboolean),
