@@ -36,12 +36,12 @@
 #include "savefiledialog.h"
 
 
-/** \brief  Callback for the "response" event
+/** \brief  Callback for the 'response' event
  */
 static void (*filename_cb)(GtkDialog *, char *, gpointer);
 
 
-/** \brief  Handler for the dialog's "response" event
+/** \brief  Handler for the dialog's 'response' event
  *
  * \param[in,out]   dialog      save-file dialog
  * \param[in]       response_id response ID
@@ -51,12 +51,10 @@ static void on_response(GtkDialog *dialog, gint response_id, gpointer data)
 {
     gchar *filename;
 
-    debug_gtk3("Got response ID %d\n", (int)response_id);
     switch (response_id) {
         case GTK_RESPONSE_ACCEPT:
             filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
             if (filename != NULL) {
-                debug_gtk3("Calling callback with '%s'\n", filename);
                 filename_cb(dialog, filename, data);
             }
             break;
@@ -67,9 +65,6 @@ static void on_response(GtkDialog *dialog, gint response_id, gpointer data)
 }
 
 
-
-
-#ifndef SANDBOX_MODE
 /** \brief  Create a 'save file' dialog
  *
  * \param[in]   title       dialog title
@@ -89,7 +84,7 @@ GtkWidget *vice_gtk3_save_file_dialog(
         const char *proposed,
         gboolean confirm,
         const char *path,
-        void (*callback)(GtkDialog *, char *, gpointer),
+        void (*callback)(GtkDialog *, gchar *, gpointer),
         gpointer param)
 {
     GtkWidget *dialog;
@@ -127,45 +122,3 @@ GtkWidget *vice_gtk3_save_file_dialog(
     gtk_widget_show(dialog);
     return dialog;
 }
-#else
-/** \brief  Create a 'save file' dialog
- *
- * \param[in]   title       dialog title
- * \param[in]   proposed    proposed file name (optional)
- * \param[in]   confirm     confirm overwriting an existing file
- * \param[in]   path        set starting directory (optional)
- *
- * \return  filename or `NULL` on cancel
- *
- * \note    the filename returned is allocated by GLib and needs to be freed
- *          after use with g_free()
- */
-gchar *vice_gtk3_save_file_dialog(
-        const char *title,
-        const char *proposed,
-        gboolean confirm,
-        const char *path,
-        void (*callback)(char *))
-{
-    GtkFileChooserNative *dialog;
-    gint result;
-    gchar *filename;
-
-    debug_gtk3("Warning: Using the GtkFileChooserNative!");
-
-    dialog = gtk_file_chooser_native_new(
-            title,
-            ui_get_active_window(),
-            GTK_FILE_CHOOSER_ACTION_SAVE,
-            NULL, NULL);
-
-    result = gtk_native_dialog_run(GTK_NATIVE_DIALOG(dialog));
-    if (result == GTK_RESPONSE_ACCEPT) {
-        filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
-    } else {
-        filename = NULL;
-    }
-    g_object_unref(dialog);
-    return filename;
-}
-#endif
