@@ -8,9 +8,6 @@
  * $VICERES InternalFunctionROM         x128
  * $VICERES InternalFunctionName        x128
  * $VICERES InternalFunctionROMRTCSave  x128
- * $VICERES ExternalFunctionROM         x128
- * $VICERES ExternalFunctionName        x128
- * $VICERES ExternalFunctionROMRTCSave  x128
  */
 
 /*
@@ -115,7 +112,7 @@ static GtkWidget *create_rom_widget(const char *prefix)
     /* row 1: ROM type */
     label = gtk_label_new("ROM type");
     gtk_widget_set_halign(label, GTK_ALIGN_START);
-    g_object_set(label, "margin-left", 16, NULL);
+    gtk_widget_set_margin_start(label, 16);
     gtk_grid_attach(GTK_GRID(grid), label, 0, 1, 1, 1);
     type = create_rom_type_widget(prefix);
     gtk_grid_attach(GTK_GRID(grid), type, 1, 1, 1, 1);
@@ -123,13 +120,13 @@ static GtkWidget *create_rom_widget(const char *prefix)
     /* row 2: ROM image browser */
     label = gtk_label_new("ROM file");
     gtk_widget_set_halign(label, GTK_ALIGN_START);
-    g_object_set(label, "margin-left", 16, NULL);
+    gtk_widget_set_margin_start(label, 16);
     gtk_grid_attach(GTK_GRID(grid), label, 0, 2, 1, 1);
     gtk_grid_attach(GTK_GRID(grid), create_rom_file_widget(prefix), 1, 2, 1, 1);
 
     rtc = vice_gtk3_resource_check_button_new_sprintf("%sFunctionROMRTCSave",
             "Save RTC data", prefix);
-    g_object_set(rtc, "margin-left", 16, NULL);
+    gtk_widget_set_margin_start(rtc, 16);
     gtk_grid_attach(GTK_GRID(grid), rtc, 0, 3, 2, 1);
 
     gtk_widget_show_all(grid);
@@ -147,14 +144,11 @@ GtkWidget *c128_function_rom_widget_create(GtkWidget *parent)
 {
     GtkWidget *grid;
     GtkWidget *internal_widget;
-    GtkWidget *external_widget;
 
     grid = vice_gtk3_grid_new_spaced(16, 32);
 
     internal_widget = create_rom_widget("Internal");
     gtk_grid_attach(GTK_GRID(grid), internal_widget, 0, 0, 1, 1);
-    external_widget = create_rom_widget("External");
-    gtk_grid_attach(GTK_GRID(grid), external_widget, 0, 1, 1, 1);
 
     gtk_widget_show_all(grid);
     return grid;
