@@ -31,8 +31,7 @@
 #include "vice.h"
 #include <gtk/gtk.h>
 
-
-GtkWidget * cia_model_widget_create(GtkWidget *machine_model_widget, int count);
+GtkWidget * cia_model_widget_create(int count);
 void        cia_model_widget_sync(GtkWidget *widget);
 void        cia_model_widget_set_callback(GtkWidget *widget,
                                           void (*func)(int cia_num, int cia_model));
