@@ -36,12 +36,10 @@
 
 #include <gtk/gtk.h>
 
-#include "basewidgets.h"
-#include "debug_gtk3.h"
+#include "vice_gtk3.h"
 #include "drive-check.h"
 #include "drive.h"
 #include "resources.h"
-#include "widgethelpers.h"
 
 #include "driveidlemethodwidget.h"
 
@@ -50,9 +48,9 @@
 /** \brief  Idle method (name,id) tuples
  */
 static const vice_gtk3_combo_entry_int_t idle_methods[] = {
-    { "None",           0 },
-    { "Skip cycles",    1 },
-    { "Trap idle",      2 },
+    { "None",           DRIVE_IDLE_NO_IDLE },
+    { "Skip cycles",    DRIVE_IDLE_SKIP_CYCLES },
+    { "Trap idle",      DRIVE_IDLE_TRAP_IDLE },
     { NULL,             -1 }
 };
 
@@ -65,17 +63,12 @@ static const vice_gtk3_combo_entry_int_t idle_methods[] = {
  */
 GtkWidget *drive_idle_method_widget_create(int unit)
 {
-    GtkWidget *grid;
     GtkWidget *combo;
 
-    grid = uihelpers_create_grid_with_label("Idle method", 1);
-    g_object_set_data(G_OBJECT(grid), "UnitNumber", GINT_TO_POINTER(unit));
-
     combo = vice_gtk3_resource_combo_box_int_new_sprintf(
             "Drive%dIdleMethod", idle_methods, unit);
+    g_object_set_data(G_OBJECT(combo), "UnitNumber", GINT_TO_POINTER(unit));
     gtk_widget_set_hexpand(combo, TRUE);
-    g_object_set(combo, "margin-left", 16, NULL);
-    gtk_grid_attach(GTK_GRID(grid), combo, 0, 1, 1, 1);
-    gtk_widget_show_all(grid);
-    return grid;
+    gtk_widget_show_all(combo);
+    return combo;
 }
