@@ -33,23 +33,20 @@
  */
 
 #include "vice.h"
-
 #include <gtk/gtk.h>
 
-#include "debug_gtk3.h"
+#include "vice_gtk3.h"
 #include "drive-check.h"
 #include "drive.h"
-#include "driveoptionswidget.h"
 #include "driveparallelcablewidget.h"
 #include "drivewidgethelpers.h"
 #include "machine-drive.h"
 #include "resources.h"
-#include "widgethelpers.h"
 
 #include "drivemodelwidget.h"
 
 
-/** \brief  Handler for the "toggled" event of the radio buttons
+/** \brief  Handler for the 'toggled' event of the radio buttons
  *
  * \param[in]   widget      radio button
  * \param[in]   user_data   unit number
@@ -57,6 +54,7 @@
 static void on_radio_toggled(GtkWidget *widget, gpointer user_data)
 {
     if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget))) {
+
         GtkWidget *parent;
         int unit;
         int new_type;
@@ -67,10 +65,10 @@ static void on_radio_toggled(GtkWidget *widget, gpointer user_data)
         new_type = GPOINTER_TO_INT(user_data);
         old_type = ui_get_drive_type(unit);
 
-
         /* prevent drive reset when switching unit number and updating the
          * drive type widget */
         if (new_type != old_type) {
+
             void (*cb_func)(GtkWidget *, gpointer);
             gpointer cb_data;
 
@@ -85,29 +83,7 @@ static void on_radio_toggled(GtkWidget *widget, gpointer user_data)
                 /* trigger callback */
                 cb_func(widget, cb_data);
             }
-
         }
-
-        /* this should be handled by signal handlers in uidrivesettings.c now */
-#if 0
-        /* enable/disable 40-track settings widget */
-        if (drive_extend_widget != NULL) {
-             tgtk_widget_set_sensitive(drive_extend_widget,
-                    drive_check_extend_policy(new_type));
-        }
-        /* update expansions widget */
-        if (drive_expansion_widget != NULL) {
-            drive_expansion_widget_update(drive_expansion_widget, unit_number);
-        }
-        /* update parallel cable widget */
-        if (drive_parallel_cable_widget != NULL) {
-            drive_parallel_cable_widget_update(drive_parallel_cable_widget,
-                    unit_number);
-        }
-        if (drive_options_widget != NULL) {
-            drive_options_widget_update(drive_options_widget, unit_number);
-        }
-#endif
     }
 }
 
@@ -115,9 +91,9 @@ static void on_radio_toggled(GtkWidget *widget, gpointer user_data)
 /** \brief  Create a drive unit selection widget
  *
  * Creates a widget with four radio buttons, horizontally aligned, to select
- * a drive unit (8-11)
+ * a drive unit (8-11).
  *
- * \param[in]   unit    default drive unit
+ * \param[in]   unit    default drive unit (8-11)
  *
  * \return  GtkGrid
  */
@@ -131,10 +107,13 @@ GtkWidget *drive_model_widget_create(int unit)
     int type;
     size_t num;
     int row;
+    GtkWidget *child;
 
     resources_get_int_sprintf("Drive%dType", &type, unit);
 
-    grid = uihelpers_create_grid_with_label("Drive type", 2);
+    grid = vice_gtk3_grid_new_spaced_with_label(-1, 0, "Drive type", 2);
+    child = gtk_grid_get_child_at(GTK_GRID(grid), 0, 0);
+    gtk_widget_set_margin_bottom(child, 8);
     /* store unit number as a property in the widget */
     g_object_set_data(G_OBJECT(grid), "UnitNumber", GINT_TO_POINTER(unit));
 
@@ -145,18 +124,23 @@ GtkWidget *drive_model_widget_create(int unit)
     num = i;
 
     for (i = 0; list[i].name != NULL && i < num / 2; i++) {
+
         GtkWidget *radio = gtk_radio_button_new_with_label(group, list[i].name);
+
         gtk_radio_button_join_group(GTK_RADIO_BUTTON(radio), last);
-        g_object_set(radio, "margin-left", 16, NULL);
-        g_object_set_data(G_OBJECT(radio), "ModelID",
-                GINT_TO_POINTER(list[i].id));
+        gtk_widget_set_margin_start(radio, 16);
+        g_object_set_data(G_OBJECT(radio),
+                          "ModelID",
+                          GINT_TO_POINTER(list[i].id));
 
         if (list[i].id == type) {
             gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio), TRUE);
         }
 
-        g_signal_connect(radio, "toggled", G_CALLBACK(on_radio_toggled),
-                GINT_TO_POINTER(list[i].id));
+        g_signal_connect(radio,
+                         "toggled",
+                         G_CALLBACK(on_radio_toggled),
+                         GINT_TO_POINTER(list[i].id));
 
         gtk_grid_attach(GTK_GRID(grid), radio, 0, (gint)(i + 1), 1, 1);
         last = GTK_RADIO_BUTTON(radio);
@@ -164,17 +148,22 @@ GtkWidget *drive_model_widget_create(int unit)
 
     row = 1;
     while (list[i].name != NULL) {
+
         GtkWidget *radio = gtk_radio_button_new_with_label(group, list[i].name);
+
         gtk_radio_button_join_group(GTK_RADIO_BUTTON(radio), last);
-        g_object_set(radio, "margin-left", 16, NULL);
-        g_object_set_data(G_OBJECT(radio), "ModelID",
-                GINT_TO_POINTER(list[i].id));
+        gtk_widget_set_margin_start(radio, 16);
+        g_object_set_data(G_OBJECT(radio),
+                          "ModelID",
+                          GINT_TO_POINTER(list[i].id));
         if (list[i].id == type) {
             gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio), TRUE);
         }
 
-        g_signal_connect(radio, "toggled", G_CALLBACK(on_radio_toggled),
-                GINT_TO_POINTER(list[i].id));
+        g_signal_connect(radio,
+                         "toggled",
+                         G_CALLBACK(on_radio_toggled),
+                         GINT_TO_POINTER(list[i].id));
 
         gtk_grid_attach(GTK_GRID(grid), radio, 1, row, 1, 1);
         row++;
@@ -195,7 +184,6 @@ GtkWidget *drive_model_widget_create(int unit)
  * types available/unavailable.
  *
  * \param[in,out]   widget  drive type widget
- * \param[in]       unit    new unit number
  */
 void drive_model_widget_update(GtkWidget *widget)
 {
@@ -221,6 +209,7 @@ void drive_model_widget_update(GtkWidget *widget)
 
         GtkWidget *radio = gtk_grid_get_child_at(GTK_GRID(widget),
                 0, (gint)(i + 1));
+
         if (radio != NULL && GTK_IS_RADIO_BUTTON(radio)) {
             gtk_widget_set_sensitive(radio,
                     drive_check_type((unsigned int)(list[i].id),
@@ -234,7 +223,9 @@ void drive_model_widget_update(GtkWidget *widget)
 
     row = 1;
     while (list[i].name != NULL) {
+
         GtkWidget *radio = gtk_grid_get_child_at(GTK_GRID(widget), 1, row);
+
         if (radio != NULL && GTK_IS_RADIO_BUTTON(radio)) {
             gtk_widget_set_sensitive(radio,
                     drive_check_type((unsigned int)(list[i].id),
@@ -265,3 +256,210 @@ void drive_model_widget_add_callback(GtkWidget *widget,
     g_object_set_data(G_OBJECT(widget), "CallbackFunc", (gpointer)cb_func);
     g_object_set_data(G_OBJECT(widget), "CallbackData", cb_data);
 }
+
+
+/*****************************************************************************
+ *          Drive model widget implementation using a GtkComboBox            *
+ *****************************************************************************/
+
+
+/* Combo box columns */
+enum {
+    COL_NAME,   /**< drive model name column */
+    COL_ID,     /**< drive model id column */
+    COL_COUNT   /**< number of columns */
+};
+
+
+/** \brief  Get drive unit number
+ *
+ * \param[in]   self    combo box
+ *
+ * \return  unit number
+ */
+static int get_unit_number(GtkWidget *self)
+{
+    return GPOINTER_TO_INT(g_object_get_data(G_OBJECT(self), "UnitNumber"));
+}
+
+
+/** \brief  Get drive type (called model in the UI)
+ *
+ * \param[in]   self    combo box
+ *
+ * \return  drive type
+ */
+static int get_drive_type(GtkWidget *self)
+{
+    int unit;
+    int type;
+
+    unit = get_unit_number(self);
+    resources_get_int_sprintf("Drive%dType", &type, unit);
+    return type;
+}
+
+
+/** \brief  Handler for the 'changed' event of the combo box
+ *
+ * Trigger user-defined callback on value change.
+ *
+ * \param[in]   self    drive model combo box
+ * \param[in]   data    extra event data (unused)
+ */
+static void on_combo_changed(GtkWidget *self, gpointer data)
+{
+    int combo_val = drive_model_widget_value_combo(self);
+    int resource_val = get_drive_type(self);
+    int unit = get_unit_number(self);
+
+
+    if (combo_val != resource_val) {
+        void (*callback)(GtkWidget *, gpointer);
+
+        debug_gtk3("New value %d differs from resource %d: triggering callback.",
+                   combo_val, resource_val);
+        if (resources_set_int_sprintf("Drive%dType", combo_val, unit) < 0) {
+            /* TODO: flip combo back to previous value? */
+            debug_gtk3("Failed to set resource Drive%dType to %d.", unit, combo_val);
+            return;
+        }
+
+        callback = g_object_get_data(G_OBJECT(self), "CallbackFunc");
+        if (callback != NULL) {
+            callback(self, g_object_get_data(G_OBJECT(self), "CallbackData"));
+        }
+    }
+}
+
+
+/** \brief  Create model for the combo box
+ *
+ * \param[in]   self        drive model widget
+ * \param[in]   show_all    show all drive types, use FALSE to only show types
+ *                          supported by the current machine config
+ *
+ * \return  GtkListStore
+ */
+static GtkListStore *create_combo_model(GtkWidget *self, gboolean show_all)
+{
+    GtkListStore *model;
+    GtkTreeIter iter;
+    drive_type_info_t *list;
+    int unit;
+    int i;
+
+    unit = get_unit_number(self);
+    list = machine_drive_get_type_info_list();
+    model = gtk_list_store_new(COL_COUNT, G_TYPE_STRING, G_TYPE_INT);
+
+    for (i = 0; list[i].name != NULL; i++) {
+        /* TODO: check if supported by current config */
+        if (show_all || drive_check_type((unsigned int)(list[i].id),
+                                         (unsigned int)(unit - DRIVE_UNIT_MIN))) {
+            gtk_list_store_append(model, &iter);
+            gtk_list_store_set(model, &iter,
+                               COL_NAME, list[i].name,
+                               COL_ID, list[i].id,
+                               -1);
+        }
+    }
+    return model;
+}
+
+
+/** \brief  Create drive model combo box
+ *
+ * \param[in]   unit        drive unit (8-11)
+ * \param[in]   show_all    show all drive types, use FALSE to only show types
+ *                          supported by the current machine config
+ *
+ * \return  GtkComboBox
+ */
+GtkWidget *drive_model_widget_create_combo(int unit, gboolean show_all)
+{
+    GtkWidget *combo;
+    GtkListStore *model;
+    GtkCellRenderer *renderer;
+    gulong handler_id;
+
+    combo = gtk_combo_box_new();
+    g_object_set_data(G_OBJECT(combo), "UnitNumber", GINT_TO_POINTER(unit));
+
+    model = create_combo_model(combo, show_all);
+    gtk_combo_box_set_model(GTK_COMBO_BOX(combo), GTK_TREE_MODEL(model));
+
+    renderer = gtk_cell_renderer_text_new();
+    gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(combo), renderer, TRUE);
+    gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(combo),
+                                   renderer,
+                                   "text", 0,
+                                   NULL);
+
+    handler_id = g_signal_connect(combo, "changed", G_CALLBACK(on_combo_changed), NULL);
+    g_object_set_data(G_OBJECT(combo), "ChangedHandlerID", GULONG_TO_POINTER(handler_id));
+
+    drive_model_widget_sync_combo(combo);
+    gtk_widget_show_all(combo);
+    return combo;
+}
+
+
+/** \brief  Synchronize the widget with its resource
+ *
+ * Select current item based on resource without triggering the 'changed' event.
+ *
+ * \param[in]   widget  drive model widget
+ *
+ * \return  TRUE if an item matched the current resource value
+ */
+gboolean drive_model_widget_sync_combo(GtkWidget *widget)
+{
+    GtkTreeModel *model;
+    GtkTreeIter iter;
+    gulong handler_id;
+    int type;
+
+    model = gtk_combo_box_get_model(GTK_COMBO_BOX(widget));
+    type = get_drive_type(widget);
+    handler_id = GPOINTER_TO_ULONG(g_object_get_data(G_OBJECT(widget),
+                                                     "ChangedHandlerID"));
+
+    if (gtk_tree_model_get_iter_first(model, &iter)) {
+        do {
+            int id;
+
+            gtk_tree_model_get(model, &iter, COL_ID, &id, -1);
+            if (id == type) {
+                g_signal_handler_block(G_OBJECT(widget), handler_id);
+                gtk_combo_box_set_active_iter(GTK_COMBO_BOX(widget), &iter);
+                g_signal_handler_unblock(G_OBJECT(widget), handler_id);
+                return TRUE;
+            }
+        } while (gtk_tree_model_iter_next(model, &iter));
+    }
+    return FALSE;
+}
+
+
+/** \brief  Get current drive model
+ *
+ * \param[in]   widget  drive model widget
+ *
+ * \return  drive model ID or -1 when no item is selected in the widget
+ */
+int drive_model_widget_value_combo(GtkWidget *widget)
+{
+    if (gtk_combo_box_get_active(GTK_COMBO_BOX(widget)) >= 0) {
+        GtkTreeModel *model;
+        GtkTreeIter iter;
+        int id;
+
+        model = gtk_combo_box_get_model(GTK_COMBO_BOX(widget));
+        if (gtk_combo_box_get_active_iter(GTK_COMBO_BOX(widget), &iter)) {
+            gtk_tree_model_get(model, &iter, COL_ID, &id, -1);
+            return id;
+        }
+    }
+    return -1;
+}
