@@ -27,9 +27,8 @@
 #ifndef VICE_JAMACTIONWIDGET_H
 #define VICE_JAMACTIONWIDGET_H
 
-#include "vice.h"
 #include <gtk/gtk.h>
 
-GtkWidget *jam_action_widget_create(void);
+GtkWidget *jam_action_widget_create(GtkWidget *parent);
 
 #endif
