@@ -1,9 +1,10 @@
-/**
+/** \file   petkeyboardtypewidget.h
  * \brief   PET keyboard type widget - header
  *
- * Written by
- *  Bas Wassink <b.wassink@ziggo.nl>
- *
+ * \author  Bas Wassink <b.wassink@ziggo.nl>
+ */
+
+/*
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
  *
@@ -35,5 +36,8 @@ void pet_keyboard_type_widget_set_keyboard_num_get(int (*f)(void));
 void pet_keyboard_type_widget_set_keyboard_list_get(kbdtype_info_t *(*f)(void));
 
 GtkWidget * pet_keyboard_type_widget_create(void);
+void        pet_keyboard_type_widget_set_callback(GtkWidget *widget,
+                                                  void (*func)(int));
+void        pet_keyboard_type_widget_sync(GtkWidget *widget);
 
 #endif
