@@ -1,11 +1,10 @@
-/**
+/** \file   sidmodelwidget.h
  * \brief   Widget to set the SID model - header
  *
- * Written by
- *  Bas Wassink <b.wassink@ziggo.nl>
- *
- * Controls the following resource(s):
- *
+ * \author  Bas Wassink <b.wassink@ziggo.nl>
+ */
+
+/*
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
  *
@@ -34,5 +33,7 @@
 
 GtkWidget * sid_model_widget_create(GtkWidget *machine_model_widget);
 void        sid_model_widget_update(GtkWidget *widget, int model);
+void        sid_model_widget_sync(GtkWidget *widget);
+void        sid_model_widget_set_callback(GtkWidget *widget, void (*callback)(int));
 
 #endif
