@@ -73,7 +73,7 @@ GtkWidget *sound_sample_rate_widget_create(void)
             "Sample rate", 1);
     group = vice_gtk3_resource_radiogroup_new(
             "SoundSampleRate", sample_rates, GTK_ORIENTATION_VERTICAL);
-    g_object_set(group, "margin-left", 16, NULL);
+    gtk_widget_set_margin_start(group, 16);
     gtk_grid_attach(GTK_GRID(grid), group, 0, 1, 1, 1);
     gtk_widget_show_all(grid);
     return grid;
