@@ -39,8 +39,11 @@
 #include "log.h"
 #include "machine.h"
 #include "mainlock.h"
+#include "uiactions.h"
 #include "util.h"
 #include "vsidcontrolwidget.h"
+#include "vsidplaylistwidget.h"
+#include "vsidstate.h"
 
 #include "vsidtuneinfowidget.h"
 
@@ -156,7 +159,7 @@ static int song_lengths_count;
 static void on_destroy(GtkWidget *widget, gpointer data)
 {
     if (song_lengths != NULL) {
-        free(song_lengths);
+        lib_free(song_lengths);
         song_lengths = NULL;
         song_lengths_count = 0;
     }
@@ -226,17 +229,16 @@ static GtkWidget *create_readonly_entry(void)
 static GtkWidget *create_tune_num_widget(void)
 {
     GtkWidget *label;
-    char *text;
+    gchar text[256];
 
-    text = lib_msprintf("%d of %d (Default: %d)",
-            tune_current, tune_count, tune_default);
+    g_snprintf(text, sizeof text,
+               "%d of %d (default: %d)",
+               tune_current, tune_count, tune_default);
     label = gtk_label_new(text);
     gtk_widget_set_halign(label, GTK_ALIGN_START);
-    lib_free(text);
     return label;
 }
 
-
 /** \brief  Update tune number widget
  *
  * Updates the 'X of Y (default: Z)' widget
@@ -252,10 +254,9 @@ static void update_tune_num_widget(void)
     if (tune_num_widget != NULL) {
         gchar buffer[256];
 
-        g_snprintf(buffer, 256,
-                "%d of %d (default: %d)",
-                tune_current, tune_count, tune_default);
-
+        g_snprintf(buffer, sizeof buffer,
+                   "%d of %d (default: %d)",
+                   tune_current, tune_count, tune_default);
         gtk_label_set_text(GTK_LABEL(tune_num_widget), buffer);
     }
 }
@@ -463,24 +464,11 @@ static void driver_info_set_image(void)
 }
 
 
-#if 0
-/** \brief  Create temp songlength widget
- *
- * \return  GtkLabel
- */
-static GtkWidget *create_sldb_widget(void)
-{
-    GtkWidget *label;
-
-    label = gtk_label_new("N/A");
-    gtk_widget_set_halign(label, GTK_ALIGN_START);
-    gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
-    gtk_widget_show_all(label);
-    return label;
-}
-#endif
-
 /** \brief  Update play time based ui elements
+ *
+ * This function also determines if vsid should play the next subtune or play
+ * the next SID in the playlist, so it's probably doing too much or just
+ * misnamed.
  */
 void vsid_tune_info_widget_update(void)
 {
@@ -495,12 +483,29 @@ void vsid_tune_info_widget_update(void)
         total = song_lengths[tune_current - 1];
         /* determine progress bar value */
         fraction = 1.0 - ((gdouble)(total / 100 - play_time) / (gdouble)(total / 100));
-        if (fraction < 0.0) {
-            fraction = 1.0;
+        if (play_time >= total / 100) {
+            fraction = 1.0; /* keep fraction at 1.0 max if looping */
             /* skip to next tune, if repeat is off */
             if (!vsid_control_widget_get_repeat()) {
-                vsid_control_widget_next_tune();
+                play_time = 0;
                 fraction = 0.0;
+                vsid_state_set_current_tune_played();
+#ifdef DEBUG
+                vsid_state_print_tunes_played();
+#endif
+
+                /* next subtune or next tune? */
+                if (vsid_state_get_all_tunes_played()) {
+                    /* load next tune in the playlist if a single row in
+                     * the playlist was selected */
+                    if (vsid_playlist_get_current_row(NULL) >= 0) {
+                        vsid_playlist_next();
+                    } else {
+                        ui_action_trigger(ACTION_PSID_SUBTUNE_NEXT);
+                    }
+                } else {
+                    ui_action_trigger(ACTION_PSID_SUBTUNE_NEXT);
+                }
             }
         }
         vsid_control_widget_set_progress(fraction);
@@ -527,7 +532,7 @@ GtkWidget *vsid_tune_info_widget_create(void)
     label = gtk_label_new(NULL);
     gtk_label_set_markup(GTK_LABEL(label), "<b>SID file info:</b>");
     gtk_widget_set_halign(label, GTK_ALIGN_START);
-    g_object_set(G_OBJECT(label), "margin-bottom", 16, NULL);
+    gtk_widget_set_margin_bottom(label, 16);
     gtk_grid_attach(GTK_GRID(grid), label, 0, row, 2, 1);
     row++;
 
@@ -595,14 +600,6 @@ GtkWidget *vsid_tune_info_widget_create(void)
     gtk_grid_attach(GTK_GRID(grid), driver_info_widget, 1, row, 1, 1);
     row++;
 
-#if 0
-    /* song length info */
-    label = create_left_aligned_label("Song lengths:");
-    gtk_widget_set_valign(label, GTK_ALIGN_START);
-    sldb_widget = create_sldb_widget();
-    gtk_grid_attach(GTK_GRID(grid), label, 0, 9, 1, 1);
-    gtk_grid_attach(GTK_GRID(grid), sldb_widget, 1, 9, 1, 1);
-#endif
     g_signal_connect_unlocked(grid, "destroy", G_CALLBACK(on_destroy), NULL);
 
     gtk_widget_show_all(grid);
@@ -745,17 +742,6 @@ void vsid_tune_info_widget_set_time(unsigned int dsec)
 }
 
 
-/** \brief  Set driver information
- *
- * \param[in]   text    driver information
- */
-void vsid_tune_info_widget_set_driver(const char *text)
-{
-    /* NOP: replaced with separate driver parameter funcions */
-    debug_gtk3("Deprecated! use set_driver_addr(), set_load_addr() etc.");
-}
-
-
 /** \brief  Set driver address
  *
  * \param[in]   addr    driver address
@@ -822,9 +808,6 @@ void vsid_tune_info_widget_set_data_size(uint16_t size)
 }
 
 /** \brief  Set song lengths for each sub-tune
- *
- * For now this is more of a debugging/test function, the idea is to allow
- * tunes to automatically skip to the next song when their time is up.
  *
  * \param[in]   psid    SID file
  *
@@ -834,6 +817,10 @@ int vsid_tune_info_widget_set_song_lengths(const char *psid)
 {
     int num;
 
+    if (song_lengths != NULL) {
+        lib_free(song_lengths);
+    }
+
     num = hvsc_sldb_get_lengths(psid, &song_lengths);
     if (num < 0) {
         log_warning(LOG_DEFAULT, "failed to get song lengths.");
