@@ -33,7 +33,7 @@
 
 extern ui_menu_entry_t joyport_menu[];
 
-extern void uijoyport_menu_create(int port1, int port2, int port3, int port4, int port5);
+extern void uijoyport_menu_create(int port1, int port2, int port3_4, int port5, int port6_10);
 extern void uijoyport_menu_shutdown(void);
 
 #endif
