@@ -109,32 +109,24 @@ const ui_menu_entry_t plus4cart_menu[] = {
     { "Smart attach cartridge image",
       MENU_ENTRY_DIALOG,
       attach_cart_callback,
-      (ui_callback_data_t)CARTRIDGE_PLUS4_DETECT },
+      (ui_callback_data_t)CARTRIDGE_CRT },
     SDL_MENU_ITEM_SEPARATOR,
-    { "Attach C0 low image",
-      MENU_ENTRY_DIALOG,
-      attach_cart_callback,
-      (ui_callback_data_t)CARTRIDGE_PLUS4_16KB_C0LO },
-    { "Attach C0 high image",
-      MENU_ENTRY_DIALOG,
-      attach_cart_callback,
-      (ui_callback_data_t)CARTRIDGE_PLUS4_16KB_C0HI },
     { "Attach C1 low image",
       MENU_ENTRY_DIALOG,
       attach_cart_callback,
-      (ui_callback_data_t)CARTRIDGE_PLUS4_16KB_C1LO },
+      (ui_callback_data_t)CARTRIDGE_PLUS4_GENERIC_C1LO },
     { "Attach C1 high image",
       MENU_ENTRY_DIALOG,
       attach_cart_callback,
-      (ui_callback_data_t)CARTRIDGE_PLUS4_16KB_C1HI },
+      (ui_callback_data_t)CARTRIDGE_PLUS4_GENERIC_C1HI },
     { "Attach C2 low image",
       MENU_ENTRY_DIALOG,
       attach_cart_callback,
-      (ui_callback_data_t)CARTRIDGE_PLUS4_16KB_C2LO },
+      (ui_callback_data_t)CARTRIDGE_PLUS4_GENERIC_C2LO },
     { "Attach C2 high image",
       MENU_ENTRY_DIALOG,
       attach_cart_callback,
-      (ui_callback_data_t)CARTRIDGE_PLUS4_16KB_C2HI },
+      (ui_callback_data_t)CARTRIDGE_PLUS4_GENERIC_C2HI },
     SDL_MENU_ITEM_SEPARATOR,
     { "Detach cartridge image",
       MENU_ENTRY_OTHER,
