@@ -34,6 +34,7 @@
 #include "menu_speed.h"
 #include "resources.h"
 #include "uimenu.h"
+#include "vsync.h"
 
 UI_MENU_DEFINE_TOGGLE(WarpMode)
 UI_MENU_DEFINE_RADIO(Speed)
@@ -50,7 +51,7 @@ static UI_MENU_CALLBACK(custom_Speed_callback)
     if (activated) {
         sprintf(buf, "%i", previous > 0 ? previous : 0);
         value = sdl_ui_text_input_dialog("Enter custom maximum speed", buf);
-        if (value > 0) {
+        if (value) {
             new_value = (int)strtol(value, NULL, 0);
             if (new_value != previous) {
                 resources_set_int("Speed", new_value);
@@ -78,7 +79,7 @@ static UI_MENU_CALLBACK(custom_Fps_callback)
     if (activated) {
         sprintf(buf, "%i", previous < 0 ? -previous : 0);
         value = sdl_ui_text_input_dialog("Enter target Fps", buf);
-        if (value > 0) {
+        if (value) {
             new_value = -(int)strtol(value, NULL, 0);
             if (new_value != previous) {
                 resources_set_int("Speed", new_value);
@@ -93,10 +94,18 @@ static UI_MENU_CALLBACK(custom_Fps_callback)
     return NULL;
 }
 
+static UI_MENU_CALLBACK(set_warp_mode_callback)
+{
+    if (activated) {
+        vsync_set_warp_mode(!vsync_get_warp_mode());
+    }
+    return vsync_get_warp_mode() ? MENU_CHECKMARK_CHECKED_STRING : NULL;
+}
+
 const ui_menu_entry_t speed_menu[] = {
     { "Warp mode",
-      MENU_ENTRY_RESOURCE_TOGGLE,
-      toggle_WarpMode_callback,
+      MENU_ENTRY_OTHER_TOGGLE,
+      set_warp_mode_callback,
       NULL },
     SDL_MENU_ITEM_SEPARATOR,
     SDL_MENU_ITEM_TITLE("Maximum CPU speed"),
