@@ -125,10 +125,16 @@ UI_MENU_DEFINE_TOGGLE(VICIIVSPBug)
 /* audio leak */
 
 UI_MENU_DEFINE_TOGGLE(VICIIAudioLeak)
-UI_MENU_DEFINE_TOGGLE(VDCAudioLeak)
-UI_MENU_DEFINE_TOGGLE(CrtcAudioLeak)
 UI_MENU_DEFINE_TOGGLE(TEDAudioLeak)
 UI_MENU_DEFINE_TOGGLE(VICAudioLeak)
+UI_MENU_DEFINE_TOGGLE(VDCAudioLeak)
+UI_MENU_DEFINE_TOGGLE(CrtcAudioLeak)
+
+/* delayline type */
+
+UI_MENU_DEFINE_TOGGLE(VICIIPALDelaylineType)
+UI_MENU_DEFINE_TOGGLE(TEDPALDelaylineType)
+UI_MENU_DEFINE_TOGGLE(VICPALDelaylineType)
 
 /* CRT emulation menu */
 
@@ -139,8 +145,6 @@ UI_MENU_DEFINE_SLIDER_VIDEO(VICPALOddLineOffset, 0, 2000)
 
 UI_MENU_DEFINE_SLIDER_VIDEO(VDCPALScanLineShade, 0, 1000)
 UI_MENU_DEFINE_SLIDER_VIDEO(VDCPALBlur, 0, 1000)
-UI_MENU_DEFINE_SLIDER_VIDEO(VDCPALOddLinePhase, 0, 2000)
-UI_MENU_DEFINE_SLIDER_VIDEO(VDCPALOddLineOffset, 0, 2000)
 
 UI_MENU_DEFINE_SLIDER_VIDEO(VICIIPALScanLineShade, 0, 1000)
 UI_MENU_DEFINE_SLIDER_VIDEO(VICIIPALBlur, 0, 1000)
@@ -154,10 +158,18 @@ UI_MENU_DEFINE_SLIDER_VIDEO(TEDPALOddLineOffset, 0, 2000)
 
 UI_MENU_DEFINE_SLIDER_VIDEO(CrtcPALScanLineShade, 0, 1000)
 UI_MENU_DEFINE_SLIDER_VIDEO(CrtcPALBlur, 0, 1000)
-UI_MENU_DEFINE_SLIDER_VIDEO(CrtcPALOddLinePhase, 0, 2000)
-UI_MENU_DEFINE_SLIDER_VIDEO(CrtcPALOddLineOffset, 0, 2000)
 
 #define VICE_SDL_CRTEMU_MENU_ITEMS(chip)                        \
+    { "Scanline shade",                                         \
+      MENU_ENTRY_RESOURCE_INT,                                  \
+      slider_##chip##PALScanLineShade_callback,                 \
+      (ui_callback_data_t)"Set PAL shade (0-1000)" },           \
+    { "Blur",                                                   \
+      MENU_ENTRY_RESOURCE_INT,                                  \
+      slider_##chip##PALBlur_callback,                          \
+      (ui_callback_data_t)"Set PAL blur (0-1000)" }
+
+#define VICE_SDL_CRTEMU_PALNTSC_MENU_ITEMS(chip)                \
     { "Scanline shade",                                         \
       MENU_ENTRY_RESOURCE_INT,                                  \
       slider_##chip##PALScanLineShade_callback,                 \
@@ -173,15 +185,19 @@ UI_MENU_DEFINE_SLIDER_VIDEO(CrtcPALOddLineOffset, 0, 2000)
     { "Oddline offset",                                         \
       MENU_ENTRY_RESOURCE_INT,                                  \
       slider_##chip##PALOddLineOffset_callback,                 \
-      (ui_callback_data_t)"Set PAL oddline offset (0-2000)" }
+      (ui_callback_data_t)"Set PAL oddline offset (0-2000)" },  \
+    { "U-only Delayline",                                       \
+      MENU_ENTRY_RESOURCE_TOGGLE,                               \
+      toggle_##chip##PALDelaylineType_callback,                 \
+      NULL }
 
 static const ui_menu_entry_t vic_crt_controls_menu[] = {
-    VICE_SDL_CRTEMU_MENU_ITEMS(VIC),
+    VICE_SDL_CRTEMU_PALNTSC_MENU_ITEMS(VIC),
     SDL_MENU_LIST_END
 };
 
 static const ui_menu_entry_t vicii_crt_controls_menu[] = {
-    VICE_SDL_CRTEMU_MENU_ITEMS(VICII),
+    VICE_SDL_CRTEMU_PALNTSC_MENU_ITEMS(VICII),
     SDL_MENU_LIST_END
 };
 
@@ -191,7 +207,7 @@ static const ui_menu_entry_t vdc_crt_controls_menu[] = {
 };
 
 static const ui_menu_entry_t ted_crt_controls_menu[] = {
-    VICE_SDL_CRTEMU_MENU_ITEMS(TED),
+    VICE_SDL_CRTEMU_PALNTSC_MENU_ITEMS(TED),
     SDL_MENU_LIST_END
 };
 
@@ -284,12 +300,12 @@ static const ui_menu_entry_t crtc_color_controls_menu[] = {
 
 UI_MENU_DEFINE_INT(SDLCustomWidth)
 UI_MENU_DEFINE_INT(SDLCustomHeight)
-#ifndef USE_SDLUI2    
+#ifndef USE_SDL2UI
 UI_MENU_DEFINE_RADIO(SDLLimitMode)
 #endif
 UI_MENU_DEFINE_INT(Window0Width)
 UI_MENU_DEFINE_INT(Window0Height)
-    
+
 
 #define VICE_SDL_SIZE_MENU_DOUBLESIZE(chip)         \
     { "Double size",                                \
@@ -316,11 +332,11 @@ UI_MENU_DEFINE_INT(Window0Height)
     SDL_MENU_ITEM_TITLE("Fullscreen mode"),         \
     { "Automatic",                                  \
       MENU_ENTRY_RESOURCE_RADIO,                    \
-      radio_##chip##SDLFullscreenMode_callback,     \
+      radio_##chip##FullscreenMode_callback,     \
       (ui_callback_data_t)FULLSCREEN_MODE_AUTO },   \
     { "Custom",                                     \
       MENU_ENTRY_RESOURCE_RADIO,                    \
-      radio_##chip##SDLFullscreenMode_callback,     \
+      radio_##chip##FullscreenMode_callback,     \
       (ui_callback_data_t)FULLSCREEN_MODE_CUSTOM }, \
     SDL_MENU_ITEM_SEPARATOR,                        \
     SDL_MENU_ITEM_TITLE("Custom resolution"),       \
@@ -332,7 +348,7 @@ UI_MENU_DEFINE_INT(Window0Height)
       MENU_ENTRY_RESOURCE_INT,                      \
       int_SDLCustomHeight_callback,                 \
       (ui_callback_data_t)"Set height" },
-#ifndef USE_SDLUI2
+#ifndef USE_SDL2UI
 #define VICE_SDL_SIZE_MENU_ITEMS_LIMIT(chip)        \
     SDL_MENU_ITEM_SEPARATOR,                        \
     SDL_MENU_ITEM_TITLE("Resolution limit mode"),   \
@@ -368,7 +384,7 @@ VICE_SDL_SIZE_MENU_ITEMS_SHARED(chip)               \
 VICE_SDL_SIZE_MENU_ITEMS_LIMIT(chip)                \
 VICE_SDL_SIZE_MENU_ITEMS_LATER_SHARED(chip)
 
-#if defined(HAVE_HWSCALE) || defined(USE_SDLUI2)
+#if defined(HAVE_HWSCALE) || defined(USE_SDL2UI)
 
 UI_MENU_DEFINE_RADIO(SDLGLAspectMode)
 
@@ -406,7 +422,7 @@ UI_MENU_DEFINE_STRING(AspectRatio)
 UI_MENU_DEFINE_TOGGLE(SDLGLFlipX)
 UI_MENU_DEFINE_TOGGLE(SDLGLFlipY)
 
-#ifndef USE_SDLUI2
+#ifndef USE_SDL2UI
 #define VICE_SDL_SIZE_MENU_OPENGL_ITEMS(chip)               \
     SDL_MENU_ITEM_SEPARATOR,                                \
     SDL_MENU_ITEM_TITLE("OpenGL"),                          \
@@ -463,12 +479,12 @@ UI_MENU_DEFINE_TOGGLE(SDLGLFlipY)
 UI_MENU_DEFINE_TOGGLE(VICIIDoubleSize)
 UI_MENU_DEFINE_TOGGLE(VICIIDoubleScan)
 UI_MENU_DEFINE_TOGGLE(VICIIFullscreen)
-UI_MENU_DEFINE_RADIO(VICIISDLFullscreenMode)
+UI_MENU_DEFINE_RADIO(VICIIFullscreenMode)
 
 static const ui_menu_entry_t vicii_size_menu[] = {
     VICE_SDL_SIZE_MENU_DOUBLESIZE(VICII)
     VICE_SDL_SIZE_MENU_ITEMS(VICII)
-#if defined(HAVE_HWSCALE) || defined(USE_SDLUI2)
+#if defined(HAVE_HWSCALE) || defined(USE_SDL2UI)
     VICE_SDL_SIZE_MENU_OPENGL_ITEMS(VICII)
 #endif
     SDL_MENU_LIST_END
@@ -481,13 +497,13 @@ UI_MENU_DEFINE_TOGGLE(VDCDoubleSize)
 UI_MENU_DEFINE_TOGGLE(VDCStretchVertical)
 UI_MENU_DEFINE_TOGGLE(VDCDoubleScan)
 UI_MENU_DEFINE_TOGGLE(VDCFullscreen)
-UI_MENU_DEFINE_RADIO(VDCSDLFullscreenMode)
+UI_MENU_DEFINE_RADIO(VDCFullscreenMode)
 
 static const ui_menu_entry_t vdc_size_menu[] = {
     VICE_SDL_SIZE_MENU_DOUBLESIZE(VDC)
     VICE_SDL_SIZE_MENU_STRETCHVERTICAL(VDC)
     VICE_SDL_SIZE_MENU_ITEMS(VDC)
-#if defined(HAVE_HWSCALE) || defined(USE_SDLUI2)
+#if defined(HAVE_HWSCALE) || defined(USE_SDL2UI)
     VICE_SDL_SIZE_MENU_OPENGL_ITEMS(VDC)
 #endif
     SDL_MENU_LIST_END
@@ -497,7 +513,7 @@ static const ui_menu_entry_t vdc_size_menu[] = {
 /* Crtc size menu */
 
 UI_MENU_DEFINE_TOGGLE(CrtcFullscreen)
-UI_MENU_DEFINE_RADIO(CrtcSDLFullscreenMode)
+UI_MENU_DEFINE_RADIO(CrtcFullscreenMode)
 UI_MENU_DEFINE_TOGGLE(CrtcDoubleSize)
 UI_MENU_DEFINE_TOGGLE(CrtcStretchVertical)
 UI_MENU_DEFINE_TOGGLE(CrtcDoubleScan)
@@ -506,7 +522,7 @@ static const ui_menu_entry_t crtc_size_menu[] = {
     VICE_SDL_SIZE_MENU_DOUBLESIZE(Crtc)
     VICE_SDL_SIZE_MENU_STRETCHVERTICAL(Crtc)
     VICE_SDL_SIZE_MENU_ITEMS(Crtc)
-#if defined(HAVE_HWSCALE) || defined(USE_SDLUI2)
+#if defined(HAVE_HWSCALE) || defined(USE_SDL2UI)
     VICE_SDL_SIZE_MENU_OPENGL_ITEMS(Crtc)
 #endif
     SDL_MENU_LIST_END
@@ -518,12 +534,12 @@ static const ui_menu_entry_t crtc_size_menu[] = {
 UI_MENU_DEFINE_TOGGLE(TEDDoubleSize)
 UI_MENU_DEFINE_TOGGLE(TEDDoubleScan)
 UI_MENU_DEFINE_TOGGLE(TEDFullscreen)
-UI_MENU_DEFINE_RADIO(TEDSDLFullscreenMode)
+UI_MENU_DEFINE_RADIO(TEDFullscreenMode)
 
 static const ui_menu_entry_t ted_size_menu[] = {
     VICE_SDL_SIZE_MENU_DOUBLESIZE(TED)
     VICE_SDL_SIZE_MENU_ITEMS(TED)
-#if defined(HAVE_HWSCALE) || defined(USE_SDLUI2)
+#if defined(HAVE_HWSCALE) || defined(USE_SDL2UI)
     VICE_SDL_SIZE_MENU_OPENGL_ITEMS(TED)
 #endif
     SDL_MENU_LIST_END
@@ -535,12 +551,12 @@ static const ui_menu_entry_t ted_size_menu[] = {
 UI_MENU_DEFINE_TOGGLE(VICDoubleSize)
 UI_MENU_DEFINE_TOGGLE(VICDoubleScan)
 UI_MENU_DEFINE_TOGGLE(VICFullscreen)
-UI_MENU_DEFINE_RADIO(VICSDLFullscreenMode)
+UI_MENU_DEFINE_RADIO(VICFullscreenMode)
 
 static const ui_menu_entry_t vic_size_menu[] = {
     VICE_SDL_SIZE_MENU_DOUBLESIZE(VIC)
     VICE_SDL_SIZE_MENU_ITEMS(VIC)
-#if defined(HAVE_HWSCALE) || defined(USE_SDLUI2)
+#if defined(HAVE_HWSCALE) || defined(USE_SDL2UI)
     VICE_SDL_SIZE_MENU_OPENGL_ITEMS(VIC)
 #endif
     SDL_MENU_LIST_END
@@ -629,7 +645,7 @@ UI_MENU_DEFINE_FILE_STRING(VICPaletteFile)
 
 
 /* C128 video menu */
-#ifndef USE_SDLUI2
+#ifndef USE_SDL2UI
 static UI_MENU_CALLBACK(radio_VideoOutput_c128_callback)
 {
     int value = vice_ptr_to_int(param);
@@ -649,15 +665,15 @@ static UI_MENU_CALLBACK(radio_VideoOutput_c128_callback)
     int value = vice_ptr_to_int(param);
     int dual_window = 0;
 
-    resources_get_int("SDL2DualWindow", &dual_window);
+    resources_get_int("DualWindow", &dual_window);
 
     if (activated) {
         if (value < 2) {
             sdl_video_canvas_switch(value);
-            resources_set_int("SDL2DualWindow", 0);
+            resources_set_int("DualWindow", 0);
             sdl2_hide_second_window();
         } else if (value == 2) {
-            resources_set_int("SDL2DualWindow", 1);
+            resources_set_int("DualWindow", 1);
             sdl2_show_second_window();
         }
     } else {
@@ -671,7 +687,7 @@ static UI_MENU_CALLBACK(radio_VideoOutput_c128_callback)
     }
     return NULL;
 }
-#endif /* USE_SDLUI2 */
+#endif /* USE_SDL2UI */
 
 const ui_menu_entry_t c128_video_menu[] = {
     SDL_MENU_ITEM_TITLE("Video output"),
@@ -683,7 +699,7 @@ const ui_menu_entry_t c128_video_menu[] = {
       MENU_ENTRY_RESOURCE_RADIO,
       radio_VideoOutput_c128_callback,
       (ui_callback_data_t)1 },
-#ifdef USE_SDLUI2
+#ifdef USE_SDL2UI
     { "Dual Windows",
       MENU_ENTRY_RESOURCE_RADIO,
       radio_VideoOutput_c128_callback,
