@@ -30,7 +30,7 @@
 
 #include "mouse.h"
 
-extern int mousedrv_resources_init(mouse_func_t *funcs);
+extern int mousedrv_resources_init(const mouse_func_t *funcs);
 extern int mousedrv_cmdline_options_init(void);
 extern void mousedrv_init(void);
 
