@@ -38,6 +38,7 @@
 
 #include "debug.h"
 #include "c64mem.h"
+#include "c64rom.h"
 #include "lib.h"
 #include "log.h"
 #include "machine.h"
@@ -385,11 +386,10 @@ int vsid_ui_init(void)
     sdl_vsid_set_play_func(machine_play_psid);
 
     sdl_ui_set_menu_params = vsid_set_menu_params;
-    uikeyboard_menu_create();
     uisid_menu_create();
 
     sdl_ui_set_main_menu(vsid_main_menu);
-    sdl_ui_font_init("chargen", 0, 0x800, 0);
+    sdl_ui_font_init(C64_CHARGEN_NAME, 0, 0x800, 0);
 
     sdl_vsid_draw_init(draw_func);
     sdl_vsid_activate();
@@ -553,7 +553,6 @@ void vsid_ui_set_data_size(uint16_t size)
 
 void vsid_ui_close(void)
 {
-    uikeyboard_menu_shutdown();
     uisid_menu_shutdown();
     sdl_ui_font_shutdown();
 }
