@@ -60,6 +60,7 @@
 #include "menu_userport.h"
 #include "menu_video.h"
 #include "petmem.h"
+#include "petrom.h"
 #include "pets.h"
 #include "petui.h"
 #include "pet-resources.h"
@@ -170,7 +171,7 @@ static ui_menu_entry_t xpet_main_menu[] = {
       MENU_ENTRY_SUBMENU,
       submenu_callback,
       (ui_callback_data_t)settings_manager_menu },
-#ifdef USE_SDLUI2
+#ifdef USE_SDL2UI
     { "Edit",
       MENU_ENTRY_SUBMENU,
       submenu_callback,
@@ -192,7 +193,7 @@ static ui_menu_entry_t xpet_main_menu[] = {
 #endif
 static UI_MENU_CALLBACK(pause_callback_wrapper)
 {
-    xpet_main_menu[MENU_ADVANCE_FRAME_IDX].status = 
+    xpet_main_menu[MENU_ADVANCE_FRAME_IDX].status =
         sdl_pause_state || !sdl_menu_state ? MENU_STATUS_ACTIVE : MENU_STATUS_INACTIVE;
     xpet_main_menu[MENU_VIRTUAL_KEYBOARD_IDX].status =
         sdl_pause_state ? MENU_STATUS_INACTIVE : MENU_STATUS_ACTIVE;
@@ -244,15 +245,6 @@ int petui_init_early(void)
     return 0;
 }
 
-/* KLUDGES: this needs to be updated when ROM files are being renamed */
-static const char *get_chargen_name(void)
-{
-    if (machine_class == VICE_MACHINE_PET) {
-        return PET_CHARGEN_NAME;
-    }
-    return "chargen";
-}
-
 /** \brief  Initialize the UI
  *
  * \return  0 on success, -1 on failure
@@ -276,7 +268,7 @@ int petui_init(void)
     uimedia_menu_create();
 
     sdl_ui_set_main_menu(xpet_main_menu);
-    sdl_ui_font_init(get_chargen_name(), 0, 0x400, 0);
+    sdl_ui_font_init(PET_CHARGEN2_NAME, 0, 0x400, 0);
 
 #ifdef HAVE_FFMPEG
     sdl_menu_ffmpeg_init();
