@@ -60,6 +60,7 @@
 #include "menu_speed.h"
 #include "menu_userport.h"
 #include "menu_video.h"
+#include "scpu64rom.h"
 #include "scpu64ui.h"
 #include "ui.h"
 #include "uifonts.h"
@@ -164,7 +165,7 @@ static ui_menu_entry_t xscpu64_main_menu[] = {
       MENU_ENTRY_SUBMENU,
       submenu_callback,
       (ui_callback_data_t)settings_manager_menu },
-#ifdef USE_SDLUI2
+#ifdef USE_SDL2UI
     { "Edit",
       MENU_ENTRY_SUBMENU,
       submenu_callback,
@@ -186,7 +187,7 @@ static ui_menu_entry_t xscpu64_main_menu[] = {
 #endif
 static UI_MENU_CALLBACK(pause_callback_wrapper)
 {
-    xscpu64_main_menu[MENU_ADVANCE_FRAME_IDX].status = 
+    xscpu64_main_menu[MENU_ADVANCE_FRAME_IDX].status =
         sdl_pause_state || !sdl_menu_state ? MENU_STATUS_ACTIVE : MENU_STATUS_INACTIVE;
     xscpu64_main_menu[MENU_VIRTUAL_KEYBOARD_IDX].status =
         sdl_pause_state ? MENU_STATUS_INACTIVE : MENU_STATUS_ACTIVE;
@@ -244,7 +245,7 @@ int scpu64ui_init(void)
     uimedia_menu_create();
 
     sdl_ui_set_main_menu(xscpu64_main_menu);
-    sdl_ui_font_init("chargen", 0, 0x800, 0);
+    sdl_ui_font_init(C64_CHARGEN_NAME, 0, 0x800, 0);
     sdl_vkbd_set_vkbd(&vkbd_c64);
 
 #ifdef HAVE_FFMPEG
