@@ -25,9 +25,9 @@
  */
 
 #include "vice.h"
-#include "archdep_boot_path.h"
 #include "archdep_defs.h"
-#include "archdep_join_paths.h"
+
+#include "archdep_boot_path.h"
 #include "archdep_stat.h"
 #include "lib.h"
 #include "log.h"
@@ -38,7 +38,7 @@
 
 /** \brief  Filename of the TrueType CBM font used for directory display
  */
-#define VICE_CBM_FONT_TTF "C64_Pro_Mono-STYLE.ttf"
+#define VICE_CBM_FONT_TTF "CBM.ttf"
 
 
 /** \fn  int archdep_register_cbmfont(void)
@@ -49,7 +49,7 @@
  * \return    bool as int
  */
 
-#ifdef ARCHDEP_OS_MACOS
+#ifdef MACOS_COMPILE
 
 # include <CoreText/CTFontManager.h>
 
@@ -88,7 +88,7 @@ int archdep_register_cbmfont(void)
     return 1;
 }
 
-#elif defined(ARCHDEP_OS_UNIX)
+#elif defined(UNIX_COMPILE)
 
 # ifdef HAVE_FONTCONFIG
 
@@ -137,7 +137,7 @@ int archdep_register_cbmfont(void)
  * Windows part of the API
  */
 
-# ifdef ARCHDEP_OS_WINDOWS
+# ifdef WINDOWS_COMPILE
 
 /* Make sure AddFontResourceEx prototyped is used in wingdi.h */
 #ifndef _WIN32_WINNT
@@ -188,7 +188,7 @@ int archdep_register_cbmfont(void)
  */
 void archdep_unregister_cbmfont(void)
 {
-#ifdef ARCHDEP_OS_WINDOWS
+#ifdef WINDOWS_COMPILE
     char *path;
 
     if (sysfile_locate(VICE_CBM_FONT_TTF, "common", &path) < 0) {
