@@ -33,13 +33,13 @@
 #include <errno.h>
 #include <string.h>
 
-#include "lib.h"
-#include "log.h"
 #include "archdep_exit.h"
 #include "archdep_home_path.h"
-#include "archdep_join_paths.h"
-#include "archdep_mkdir.h"
 #include "archdep_user_cache_path.h"
+#include "archdep_mkdir.h"
+#include "lib.h"
+#include "log.h"
+#include "util.h"
 
 #include "archdep_create_user_cache_dir.h"
 
@@ -52,7 +52,7 @@ void archdep_create_user_cache_dir(void)
 {
     const char *cache = archdep_user_cache_path();
 
-#if defined(ARCHDEP_OS_UNIX) || defined(ARCHDEP_OS_HAIKU)
+#if defined(UNIX_COMPILE) || defined(HAIKU_COMPILE)
     const char *home = archdep_home_path();
     char *tmp;
 
@@ -62,7 +62,7 @@ void archdep_create_user_cache_dir(void)
      * XDG is a Freedesktop spec. We use it however for vicerc and other files
      * and it expected to be there
      */
-    tmp = archdep_join_paths(home, ARCHDEP_XDG_CACHE_HOME, NULL);
+    tmp = util_join_paths(home, ARCHDEP_XDG_CACHE_HOME, NULL);
     archdep_mkdir(tmp, 0755);
     errno = 0;
     lib_free(tmp);
