@@ -32,10 +32,10 @@
 #include <stdbool.h>
 #include <stdio.h>
 
-#ifdef ARCHDEP_OS_UNIX
+#ifdef UNIX_COMPILE
 # include <unistd.h>
 # include <sys/types.h>
-#elif defined(ARCHDEP_OS_WINDOWS)
+#elif defined(WINDOWS_COMPILE)
 # include <windows.h>
 #endif
 
@@ -55,7 +55,7 @@
  */
 bool archdep_ethernet_available(void)
 {
-#ifdef ARCHDEP_OS_UNIX
+#ifdef UNIX_COMPILE
 # ifdef HAVE_TUNTAP
     /* When TUN/TAP is available, ethernet support is available for all users */
     return true;
@@ -65,7 +65,7 @@ bool archdep_ethernet_available(void)
 # else
     return false;
 # endif
-#elif defined ARCHDEP_OS_WINDOWS
+#elif defined WINDOWS_COMPILE
     /* check if the wpcap .dll is loaded */
     return GetModuleHandleA("WPCAP.DLL") != NULL;
 #else
