@@ -25,15 +25,14 @@
  */
 
 #include "vice.h"
-#include "config.h"
+#include "archdep_defs.h"
 
 #include <stdlib.h>
 
 #include "archdep_boot_path.h"
-#include "archdep_defs.h"
 #include "archdep_is_macos_bindist.h"
-#include "archdep_join_paths.h"
 #include "lib.h"
+#include "util.h"
 
 #include "archdep_get_vice_docsdir.h"
 
@@ -44,26 +43,22 @@
  */
 char *archdep_get_vice_docsdir(void)
 {
-    char *path;
-
-#ifdef ARCHDEP_OS_WINDOWS
+#ifdef WINDOWS_COMPILE
     /* Cannot use VICE_DOCDIR here since Windows installs assume any file to
      * be relative to the emu binary.
      */
-# if defined(USE_SDLUI) || defined(USE_SDLUI2)
-    path = archdep_join_paths(archdep_boot_path(), "doc", NULL);
+# if defined(USE_SDLUI) || defined(USE_SDL2UI)
+    return util_join_paths(archdep_boot_path(), "doc", NULL);
 # else
-    path = archdep_join_paths(archdep_boot_path(), "..", "doc", NULL);
+    return util_join_paths(archdep_boot_path(), "..", "doc", NULL);
 # endif
-#elif defined(ARCHDEP_OS_MACOS)
+#elif defined(MACOS_COMPILE)
     if (archdep_is_macos_bindist()) {
-        path = archdep_join_paths(archdep_boot_path(), "..", "share", "vice", "doc", NULL);
+        return util_join_paths(archdep_boot_path(), "..", "share", "vice", "doc", NULL);
     } else {
-        path = lib_strdup(VICE_DOCDIR);
+        return lib_strdup(VICE_DOCDIR);
     }
 #else
-    path = lib_strdup(VICE_DOCDIR);
+    return lib_strdup(VICE_DOCDIR);
 #endif
-
-    return path;
 }
