@@ -31,13 +31,27 @@ set -o nounset
 #                         $1           $2      $3             $4              $5         $6
 #
 
+[ -z ${DEPS_PREFIX+set} ] && (>&2 echo "ERROR: Please set DEPS_PREFIX environment variable to something like /opt/local, /usr/local, or /opt/homebrew"; exit 1)
 [ -z ${CODE_SIGN_ID+set} ] && CODE_SIGN_ID=""
 
+if which gtk-update-icon-cache-3.0 > /dev/null; then
+  # macports
+  GTK_UPDATE_ICON_CACHE=gtk-update-icon-cache-3.0
+elif which gtk3-update-icon-cache >/dev/null; then
+  GTK_UPDATE_ICON_CACHE=gtk3-update-icon-cache
+else
+  >&2 echo "ERROR: Could not find gtk-update-icon-cache-3.0 or gtk3-update-icon-cache"
+  exit 1
+fi
+
+CPU_ARCH=$(uname -m | tr _ -)
+
 echo "Generating macOS binary distribution."
 echo "  UI type: $UI_TYPE"
+echo " CPU arch: $CPU_ARCH"
 
 # setup BUILD dir
-BUILD_DIR=$(echo "vice-$UI_TYPE-$VICE_VERSION" | tr '[:upper:]' '[:lower:]')
+BUILD_DIR=$(echo "vice-$CPU_ARCH-$UI_TYPE-$VICE_VERSION" | tr '[:upper:]' '[:lower:]')
 
 SVN_VERSION=$(svn info --show-item revision "$TOP_DIR" 2>/dev/null || true)
 if [[ ! -z "$SVN_VERSION" ]]; then
@@ -56,7 +70,7 @@ mkdir $BUILD_DIR
 
 # define emulators and command line tools
 EMULATORS="xscpu64 x64dtv x64sc x128 xcbm2 xcbm5x0 xpet xplus4 xvic vsid"
-TOOLS="c1541 petcat cartconv"
+TOOLS="c1541 tools/petcat/petcat tools/cartconv/cartconv"
 
 # define data files for emulators
 ROM_COMMON="DRIVES PRINTER"
@@ -112,7 +126,7 @@ copy_lib_recursively () {
   chmod 644 "$lib_dest"
 
   # copy this lib's libs
-  LIB_LIBS=`otool -L "$lib_dest" | egrep '^\s+/(opt|usr)/local/' | grep -v "$lib_basename" | awk '{print $1}'`
+  LIB_LIBS=`otool -L "$lib_dest" | egrep "^\s+$DEPS_PREFIX/" | grep -v "$lib_basename" | awk '{print $1}'`
 
   for lib_lib in $LIB_LIBS; do
     copy_lib_recursively "$lib_lib"
@@ -129,6 +143,7 @@ APP_RESOURCES=$APP_CONTENTS/Resources
 APP_ETC=$APP_RESOURCES/etc
 APP_SHARE=$APP_RESOURCES/share
 APP_COMMON=$APP_SHARE/vice/common
+APP_GLSL=$APP_SHARE/vice/GLSL
 APP_ICONS=$APP_SHARE/vice/icons
 APP_ROMS=$APP_SHARE/vice
 APP_DOCS=$APP_SHARE/vice/doc
@@ -136,7 +151,7 @@ APP_BIN=$APP_RESOURCES/bin
 APP_LIB=$APP_RESOURCES/lib
 
 if ! which -s platypus; then
-  echo "ERROR: platypus not found (sudo port install platypus)"
+  echo "ERROR: platypus not found (sudo port install platypus / brew install platypus)"
   exit 1
 fi
 
@@ -254,7 +269,7 @@ for emu in $BINARIES ; do
   fi
 
   # copy any needed "local" libs
-  LOCAL_LIBS=`otool -L $APP_BIN/$emu | egrep '^\s+/(opt|usr)/local/' | awk '{print $1}'`
+  LOCAL_LIBS=`otool -L $APP_BIN/$emu | egrep "^\s+$DEPS_PREFIX/" | awk '{print $1}'`
 
   for lib in $LOCAL_LIBS; do
     copy_lib_recursively $lib
@@ -295,16 +310,16 @@ elif [ "$UI_TYPE" = "GTK3" ]; then
   cp "$TOP_DIR/src/arch/gtk3/macOS-ui-runtime.sh" "$APP_BIN/ui-runtime.sh"
 
   # Gtk runtime stuff
-  cp -r /opt/local/lib/gdk-pixbuf-2.0 $APP_LIB
-  cp -r /opt/local/lib/gtk-3.0 $APP_LIB
-  cp -r /opt/local/etc/gtk-3.0 $APP_ETC
-  cp -r /opt/local/share/glib-2.0 $APP_SHARE
+  cp -r $DEPS_PREFIX/lib/gdk-pixbuf-2.0 $APP_LIB
+  cp -r $DEPS_PREFIX/lib/gtk-3.0 $APP_LIB
+  cp -r $DEPS_PREFIX/etc/gtk-3.0 $APP_ETC
+  cp -r $DEPS_PREFIX/share/glib-2.0 $APP_SHARE
 
   # Get rid of any compiled python that came with glib share
   find $APP_SHARE -name '*.pyc' -exec rm {} \;
 
   import_scalable_gtk_icons() {
-    local in_icons="/opt/local/share/icons/$1"
+    local in_icons="$DEPS_PREFIX/share/icons/$1"
     local out_icons="$APP_SHARE/icons/$1"
 
     mkdir "$out_icons"
@@ -340,7 +355,7 @@ elif [ "$UI_TYPE" = "GTK3" ]; then
     cp -r "$in_icons/scalable" "$out_icons/"
 
     # create the icon-theme.cache file
-    gtk-update-icon-cache-3.0 "$out_icons/"
+    $GTK_UPDATE_ICON_CACHE "$out_icons/"
   }
 
   mkdir $APP_SHARE/icons
@@ -348,13 +363,13 @@ elif [ "$UI_TYPE" = "GTK3" ]; then
   import_scalable_gtk_icons Adwaita
 
   # hicolor is small, just copy it. It doesn't have any scalable assets.
-  cp -r /opt/local/share/icons/hicolor "$APP_SHARE/icons/"
-  gtk-update-icon-cache-3.0 "$APP_SHARE/icons/hicolor"
+  cp -r $DEPS_PREFIX/share/icons/hicolor "$APP_SHARE/icons/"
+  $GTK_UPDATE_ICON_CACHE "$APP_SHARE/icons/hicolor"
 fi
 
 # .so libs need their libs too
 for lib in `find $APP_LIB -name '*.so'`; do
-  LIB_LIBS=`otool -L $lib | egrep '^\s+/(opt|usr)/local/' | awk '{print $1}'`
+  LIB_LIBS=`otool -L $lib | egrep "^\s+$DEPS_PREFIX/" | awk '{print $1}'`
 
   for lib_lib in $LIB_LIBS; do
     copy_lib_recursively $lib_lib
@@ -363,16 +378,21 @@ done
 
 # Some libs are loaded at runtime
 if grep -q "^#define HAVE_EXTERNAL_LAME " "src/config.h"; then
-  copy_lib_recursively /opt/local/lib/libmp3lame.dylib
+  copy_lib_recursively $DEPS_PREFIX/lib/libmp3lame.dylib
 fi
 
 # ffmpeg
 if grep -q "^#define EXTERNAL_FFMPEG " "src/config.h"; then
-  copy_lib_recursively "$(find /opt/local/lib -type f -name 'libavformat.*.dylib')"
-  copy_lib_recursively "$(find /opt/local/lib -type f -name 'libavcodec.*.dylib')"
-  copy_lib_recursively "$(find /opt/local/lib -type f -name 'libavutil.*.dylib')"
-  copy_lib_recursively "$(find /opt/local/lib -type f -name 'libswscale.*.dylib')"
-  copy_lib_recursively "$(find /opt/local/lib -type f -name 'libswresample.*.dylib')"
+  copy_lib_recursively "$(find $DEPS_PREFIX/lib -type f -name 'libavformat.*.dylib')"
+  copy_lib_recursively "$(find $DEPS_PREFIX/lib -type f -name 'libavcodec.*.dylib')"
+  copy_lib_recursively "$(find $DEPS_PREFIX/lib -type f -name 'libavutil.*.dylib')"
+  copy_lib_recursively "$(find $DEPS_PREFIX/lib -type f -name 'libswscale.*.dylib')"
+  if grep -q "^#define HAVE_FFMPEG_AVRESAMPLE " "src/config.h"; then
+    copy_lib_recursively "$(find $DEPS_PREFIX/lib -type f -name 'libavresample.*.dylib')"
+  fi
+  if grep -q "^#define HAVE_FFMPEG_SWRESAMPLE " "src/config.h"; then
+    copy_lib_recursively "$(find $DEPS_PREFIX/lib -type f -name 'libswresample.*.dylib')"
+  fi
 fi
 
 # --- copy tools ---------------------------------------------------------------
@@ -380,25 +400,26 @@ fi
 BIN_DIR=$BUILD_DIR/bin
 mkdir $BIN_DIR
 
-for tool in $TOOLS ; do
-  echo -n "  copying tool $tool: "
+for tool_file in $TOOLS ; do
+  tool_name=$(basename $tool_file)
+  echo -n "  copying tool $tool_name: "
 
   # copy binary
   echo -n "[binary] "
-  if [ ! -e src/$tool ]; then
-    echo "ERROR: missing binary: src/$tool"
+  if [ ! -e src/$tool_file ]; then
+    echo "ERROR: missing binary: src/$tool_file"
     exit 1
   fi
-  cp src/$tool $APP_BIN/$tool
+  cp src/$tool_file $APP_BIN/$tool_name
   
   # strip binary
   if [ x"$STRIP" = "xstrip" ]; then
     echo -n "[strip] "
-    /usr/bin/strip $APP_BIN/$tool
+    /usr/bin/strip $APP_BIN/$tool_name
   fi
 
   # copy any needed "local" libs
-  LOCAL_LIBS=`otool -L $APP_BIN/$tool | egrep '^\s+/(opt|usr)/local/' | awk '{print $1}'`
+  LOCAL_LIBS=`otool -L $APP_BIN/$tool_name | egrep "^\s+$DEPS_PREFIX/" | awk '{print $1}'`
 
   for lib in $LOCAL_LIBS; do
       copy_lib_recursively $lib
@@ -439,15 +460,16 @@ relink () {
   local thing_basename=`basename $lib`
 
   #
-  # Any link to a lib in /opt/local is updated to @rpath/$lib
+  # Any link to a lib in $DEPS_PREFIX is updated to @rpath/$lib
   #
 
   set +o pipefail
-  THING_LIBS=`otool -L $thing | egrep '^\s+/(opt|usr)/local/' | awk '{print $1}'`
+  THING_LIBS=`otool -L $thing | egrep "^\s+$DEPS_PREFIX/" | awk '{print $1}'`
   set -o pipefail
 
   for thing_lib in $THING_LIBS; do
-    install_name_tool -change $thing_lib @rpath/$(basename $thing_lib) $thing
+    install_name_tool -change $thing_lib @rpath/$(basename $thing_lib) $thing \
+      2> >(grep -v "invalidate the code signature")
   done
 
   #
@@ -455,7 +477,8 @@ relink () {
   # so we can blindly call it.
   #
 
-  install_name_tool -id @rpath/$thing_basename $thing
+  install_name_tool -id @rpath/$thing_basename $thing \
+    2> >(grep -v "invalidate the code signature")
 
   #
   # If any existing rpaths exist, remove them.
@@ -467,10 +490,12 @@ relink () {
   set -o pipefail
 
   for rpath in $THING_RPATHS; do
-    install_name_tool -delete_rpath $rpath $thing
+    install_name_tool -delete_rpath $rpath $thing \
+      2> >(grep -v "invalidate the code signature")
   done
   
-  install_name_tool -add_rpath @executable_path/../lib $thing
+  install_name_tool -add_rpath @executable_path/../lib $thing \
+    2> >(grep -v "invalidate the code signature")
 }
 
 echo "Relinking libs and binaries to relative bundle paths"
@@ -481,15 +506,28 @@ for lib in $(find $APP_LIB -type f -name '*.dylib' -or -name '*.so'); do
 done
 
 for bin in $BINARIES $TOOLS; do
-  relink $APP_BIN/$bin
-  chmod 555 $APP_BIN/$bin
+  relink $APP_BIN/$(basename $bin)
+  chmod 555 $APP_BIN/$(basename $bin)
 done
 
 if [ "$UI_TYPE" = "GTK3" ]; then
   # these copied cache files would otherwise point to local files
-  sed -i '' -e 's,/opt/local,@executable_path/..,' $APP_ETC/gtk-3.0/gtk.immodules 
-  sed -i '' -e 's,/opt/local,@executable_path/..,' $APP_ETC/gtk-3.0/gdk-pixbuf.loaders
-  sed -i '' -e 's,/opt/local,@executable_path/..,' $(find $APP_LIB/gdk-pixbuf-* -name loaders.cache)
+  if [ -e $APP_ETC/gtk-3.0/gtk.immodules ]; then
+    # macports
+    sed -i '' -e "s,$DEPS_PREFIX,@executable_path/..," $APP_ETC/gtk-3.0/gtk.immodules
+  fi
+
+  if [ -e $APP_LIB/gtk-3.0/3.0.0/immodules.cache ]; then
+    # homebrew
+    sed -i '' -e "s,$DEPS_PREFIX[^ ]immodules/,@executable_path/../lib/gtk-3.0/3.0.0/immodules/," $APP_LIB/gtk-3.0/3.0.0/immodules.cache
+  fi
+
+  if [ -e $APP_ETC/gtk-3.0/gdk-pixbuf.loaders ]; then
+    # macports
+    sed -i '' -e "s,$DEPS_PREFIX,@executable_path/..," $APP_ETC/gtk-3.0/gdk-pixbuf.loaders
+  fi
+
+  sed -i '' -e "s,$DEPS_PREFIX,@executable_path/..," $(find $APP_LIB/gdk-pixbuf-* -name loaders.cache)
 fi
 
 
@@ -498,18 +536,19 @@ fi
 echo "  creating command line launchers"
 # TODO replace these with a small C program that we can code sign.
 for emu in $EMULATORS $TOOLS; do
-  cat << "  HEREDOC" | sed 's/^    //' > "$BIN_DIR/$emu"
+  emu=$(basename $emu)
+  cat << "HEREDOC" | sed 's/^    //' > "$BIN_DIR/$emu"
     #!/bin/bash
-    cd $(dirname "$0")
+    export VICE_INITIAL_CWD="$(pwd)"
     export PROGRAM="$(basename "$0")"
-    ../VICE.app/Contents/Resources/script "$@"
-  HEREDOC
+    "$(dirname "$0")/../VICE.app/Contents/Resources/script" "$@"
+HEREDOC
   chmod +x "$BIN_DIR/$emu"
 done
 
-cat << "HEREDOC" | sed 's/^  //' > "$BIN_DIR/README.txt"
-  These launchers are intended to be invoked from a terminal and make
-  visible the log output that is hidden when lanching the *.app versions.
+cat << "HEREDOC" | sed 's/^  //' > "$BUILD_DIR/Terminal-README.txt"
+  The launchers in bin are intended to be invoked from a terminal, and make
+  visible the log output that is hidden when lanching the .app versions.
 
   From macOS 10.15 (Catalina) onwards, double clicking these in Finder
   will not initially work due to not being able to codesign a shell script.
@@ -542,7 +581,16 @@ done
 if [ "$UI_TYPE" = "GTK3" ]; then
   # --- copy vice.gresource ---
   echo "  copying vice.gresource"
-  cp "data/common/vice.gresource" "$APP_COMMON/"
+  cp data/common/vice.gresource "$APP_COMMON/"
+
+  # --- copy hotkeys files ---
+  cp "$TOP_DIR/data/common/"*.vhk "$APP_COMMON/"
+
+  # --- copy GLSL shaders ---
+  mkdir -p "$APP_GLSL"
+  for shader in $(find "$TOP_DIR/data/GLSL/" -type f -name '*.vert' -or -name '*.frag'); do
+    cp "$shader" "$APP_GLSL/"
+  done
 fi
 
 
@@ -568,7 +616,7 @@ if [ -n "$CODE_SIGN_ID" ]; then
   done
 
   for bin in $BINARIES $TOOLS ; do
-    code_sign_file $APP_BIN/$bin
+    code_sign_file $APP_BIN/$(basename $bin)
   done
 
   for app in $(find $BUILD_DIR -type d -name '*.app'); do
