@@ -47,11 +47,11 @@ typedef struct autostart_prg_s autostart_prg_t;
 extern void autostart_prg_init(void);
 extern void autostart_prg_shutdown(void);
 
-extern int autostart_prg_with_virtual_fs(const char *file_name,
+extern int autostart_prg_with_virtual_fs(int unit, int drive, const char *file_name,
                                          fileio_info_t *fh, log_t log);
 extern int autostart_prg_with_ram_injection(const char *file_name,
                                             fileio_info_t *fh, log_t log);
-extern int autostart_prg_with_disk_image(const char *file_name,
+extern int autostart_prg_with_disk_image(int unit, int drive, const char *file_name,
                                          fileio_info_t *fh, log_t log,
                                          const char *image_name);
 
