@@ -42,6 +42,7 @@
 #include "c128memrom.h"
 #include "c128mmu.h"
 #include "c64cart.h"
+#include "c128cart.h"
 #include "c64cia.h"
 #include "c64meminit.h"
 #include "c64memrom.h"
@@ -52,6 +53,7 @@
 #include "functionrom.h"
 #include "georam.h"
 #include "keyboard.h"
+#include "keymap.h"
 #include "log.h"
 #include "machine.h"
 #include "maincpu.h"
@@ -72,13 +74,20 @@
 #include "video.h"
 
 /* #define DEBUG_MMU */
+/* #define DEBUG_KEYS */
 
 #ifdef DEBUG_MMU
-#define DEBUG_PRINT(x) printf x
+#define DEBUG_PRINT(x) log_debug x
 #else
 #define DEBUG_PRINT(x)
 #endif
 
+#ifdef DEBUG_KEYS
+#define DBGKEY(x) log_debug x
+#else
+#define DBGKEY(x)
+#endif
+
 /* ------------------------------------------------------------------------- */
 
 /* Number of possible video banks (16K each).  */
@@ -98,6 +107,12 @@ uint8_t *mem_chargen_rom_ptr;
 /* Currently selected RAM bank.  */
 uint8_t *ram_bank;
 
+/* Currently selected DMA bank.  */
+uint8_t *dma_bank;
+
+/* Current mem_read/mem_store is DMA */
+static int mem_dma_rw = 0;
+
 /* Shared memory.  */
 static uint16_t top_shared_limit, bottom_shared_limit;
 
@@ -136,7 +151,7 @@ static int tape_motor_in = 0;
 /* Current memory configuration.  */
 static int mem_config;
 
-/* Current watchpoint state. 
+/* Current watchpoint state.
           0 = no watchpoints
     bit0; 1 = watchpoints active
     bit1; 2 = watchpoints trigger on dummy accesses
@@ -146,12 +161,12 @@ static int watchpoints_active = 0;
 /* Current machine type.  */
 static unsigned int mem_machine_type;
 
-/* Logging goes here.  */
-static log_t c128_mem_log = LOG_DEFAULT;
-
 /* Status of the CAPS key (ASCII/DIN).  */
 static int caps_sense = 1;
 
+/* called when CAPS was pressed or released */
+static int mem_caps_key_event(int enabled);
+
 /* ------------------------------------------------------------------------- */
 
 static uint8_t watch_read(uint16_t addr)
@@ -197,6 +212,218 @@ void mem_toggle_watchpoints(int flag, void *context)
 
 /* ------------------------------------------------------------------------- */
 
+/* functions for mmu region swap handling */
+
+/* FIXME: some cases might not be handled correctly yet
+          they will be implemented based on the results
+          of tests on real hardware. */
+static uint8_t c128_mem_mmu_page_0 = 0;
+static uint8_t c128_mem_mmu_page_1 = 1;
+
+static uint8_t c128_mem_mmu_page_0_bank = 0;
+static uint8_t c128_mem_mmu_page_1_bank = 0;
+
+static uint8_t c128_mem_mmu_page_0_target_ram = 1;
+static uint8_t c128_mem_mmu_page_1_target_ram = 1;
+
+static uint8_t c128_mem_mmu_zp_sp_shared = 0;
+
+void c128_mem_set_mmu_page_0(uint8_t val)
+{
+    c128_mem_mmu_page_0 = val;
+}
+
+void c128_mem_set_mmu_page_1(uint8_t val)
+{
+    c128_mem_mmu_page_1 = val;
+}
+
+void c128_mem_set_mmu_page_0_bank(uint8_t val)
+{
+    c128_mem_mmu_page_0_bank = val;
+}
+
+void c128_mem_set_mmu_page_1_bank(uint8_t val)
+{
+    c128_mem_mmu_page_1_bank = val;
+}
+
+void c128_mem_set_mmu_page_0_target_ram(uint8_t val)
+{
+    c128_mem_mmu_page_0_target_ram = val;
+}
+
+void c128_mem_set_mmu_page_1_target_ram(uint8_t val)
+{
+    c128_mem_mmu_page_1_target_ram = val;
+}
+
+void c128_mem_set_mmu_zp_sp_shared(uint8_t val)
+{
+    c128_mem_mmu_zp_sp_shared = val;
+}
+
+/* returns 0x100 if normal read needs to be done, or <0x100 if the read was remapped */
+static uint16_t c128_mem_mmu_wrap_read_zero(uint16_t address)
+{
+    uint8_t addr_pos = (address & 0xff);
+    uint8_t addr_page = 0;
+    uint8_t addr_bank = 0;
+    uint16_t addr;
+    int use_ram_only = 0;
+
+    /* Make sure the internal cpu port is always used for address 0 and 1 */
+    if (address == 0 || address == 1) {
+        return 0x100;
+    }
+
+    /* Check if there is no translation that needs to be done */
+    if (c128_mem_mmu_page_0 == 0 && c128_mem_mmu_page_0_bank == 0) {
+        return 0x100;
+    }
+
+    /* check if the address page is page 0 and in shared memory then bank does not change */
+    if (c128_mem_mmu_zp_sp_shared && addr_page == 0) {
+        addr_page = c128_mem_mmu_page_0;
+        use_ram_only = 1;
+    /* check if the address page is page 0 and replace addr with mmu given page and bank */
+    } else if (addr_page == 0) {
+        addr_page = c128_mem_mmu_page_0;
+        addr_bank = c128_mem_mmu_page_0_bank;
+        use_ram_only = 1;
+    /* check if the address page is page 0 target and if it is current RAM, ifso replace addr with page 0 and bank 0 */
+    } else if (addr_page == c128_mem_mmu_page_0 && c128_mem_mmu_page_0_target_ram) {
+        addr_page = 0;
+        addr_bank = c128_mem_mmu_page_0_bank;
+        use_ram_only = 1;
+    }
+
+    if (use_ram_only) {
+        addr = (addr_page << 8) | addr_pos;
+        return mem_ram[addr | (addr_bank << 16)];
+    }
+
+    return 0x100;
+}
+
+/* returns 0x100 if normal read needs to be done, or <0x100 if the read was remapped */
+static uint16_t c128_mem_mmu_wrap_read(uint16_t address)
+{
+    uint8_t addr_pos = (address & 0xff);
+    uint8_t addr_page = (address >> 8);
+    uint8_t addr_bank = 0;
+    uint16_t addr;
+    int use_ram_only = 0;
+
+    /* Check if there is no translation that needs to be done */
+    if (c128_mem_mmu_page_0 == 0 && c128_mem_mmu_page_1 == 1 && c128_mem_mmu_page_0_bank == 0 && c128_mem_mmu_page_1_bank == 0) {
+        return 0x100;
+    }
+
+    /* Make sure the internal cpu port is always used for address 0 and 1 */
+    if (address == 0 || address == 1) {
+        return 0x100;
+    }
+
+    /* check if the address page is page 1 and in shared memory then bank does not change */
+    if (c128_mem_mmu_zp_sp_shared && addr_page == 1) {
+        addr_page = c128_mem_mmu_page_1;
+        use_ram_only = 1;
+    /* check if the address page is page 0 and in shared memory then bank does not change */
+    } else if (c128_mem_mmu_zp_sp_shared && addr_page == 0) {
+        addr_page = c128_mem_mmu_page_0;
+        use_ram_only = 1;
+    /* check if the address page is page 1 and replace addr with mmu given page and bank */
+    } else if (addr_page == 1) {
+        addr_page = c128_mem_mmu_page_1;
+        addr_bank = c128_mem_mmu_page_1_bank;
+        use_ram_only = 1;
+    /* check if the address page is page 1 target and if it is current RAM, ifso replace addr with page 1 and bank 0 */
+    } else if (addr_page == c128_mem_mmu_page_1 && c128_mem_mmu_page_1_target_ram) {
+        addr_page = 1;
+        addr_bank = c128_mem_mmu_page_1_bank;
+        use_ram_only = 1;
+    /* check if the address page is page 0 and replace addr with mmu given page and bank */
+    } else if (addr_page == 0) {
+        addr_page = c128_mem_mmu_page_0;
+        addr_bank = c128_mem_mmu_page_0_bank;
+        use_ram_only = 1;
+    /* check if the address page is page 0 target and if it is current RAM, ifso replace addr with page 0 and bank 0 */
+    } else if (addr_page == c128_mem_mmu_page_0 && c128_mem_mmu_page_0_target_ram) {
+        addr_page = 0;
+        addr_bank = c128_mem_mmu_page_0_bank;
+        use_ram_only = 1;
+    }
+
+    addr = (addr_page << 8) | addr_pos;
+
+    if (use_ram_only) {
+        return (uint16_t)mem_ram[addr | (addr_bank << 16)];
+    }
+
+    return 0x100;
+}
+
+/* returns 1 if normal write needs to be done, or 0 if write was remapped and done */
+static uint8_t c128_mem_mmu_wrap_store(uint16_t address, uint8_t value)
+{
+    uint8_t addr_pos = (address & 0xff);
+    uint8_t addr_page = (address >> 8);
+    uint8_t addr_bank = 0;
+    uint16_t addr;
+    int use_ram_only = 0;
+
+    /* Check if there is no translation that needs to be done */
+    if (c128_mem_mmu_page_0 == 0 && c128_mem_mmu_page_1 == 1 && c128_mem_mmu_page_0_bank == 0 && c128_mem_mmu_page_1_bank == 0) {
+        return 1;
+    }
+
+
+    /* Make sure the internal cpu port is always used for address 0 and 1 */
+    if (address == 0 || address == 1) {
+        return 1;
+    }
+
+    /* check if the address page is page 1 and in shared memory then bank does not change */
+    if (c128_mem_mmu_zp_sp_shared && addr_page == 1) {
+        addr_page = c128_mem_mmu_page_1;
+        use_ram_only = 1;
+    /* check if the address page is page 0 and in shared memory then bank does not change */
+    } else if (c128_mem_mmu_zp_sp_shared && addr_page == 0) {
+        addr_page = c128_mem_mmu_page_0;
+        use_ram_only = 1;
+    /* check if the address page is page 1 and replace addr with mmu given page and bank */
+    } else if (addr_page == 1) {
+        addr_page = c128_mem_mmu_page_1;
+        addr_bank = c128_mem_mmu_page_1_bank;
+        use_ram_only = 1;
+    /* check if the address page is page 1 target and if it is current RAM, ifso replace addr with page 1 and bank 0 */
+    } else if (addr_page == c128_mem_mmu_page_1 && c128_mem_mmu_page_1_target_ram) {
+        addr_page = 1;
+        addr_bank = c128_mem_mmu_page_1_bank;
+        use_ram_only = 1;
+    /* check if the address page is page 0 and replace addr with mmu given page and bank */
+    } else if (addr_page == 0) {
+        addr_page = c128_mem_mmu_page_0;
+        addr_bank = c128_mem_mmu_page_0_bank;
+        use_ram_only = 1;
+    /* check if the address page is page 0 target and if it is current RAM, ifso replace addr with page 0 and bank 0 */
+    } else if (addr_page == c128_mem_mmu_page_0 && c128_mem_mmu_page_0_target_ram) {
+        addr_page = 0;
+        addr_bank = c128_mem_mmu_page_0_bank;
+        use_ram_only = 1;
+    }
+
+    addr = (addr_page << 8) | addr_pos;
+
+    if (use_ram_only) {
+        mem_ram[addr | (addr_bank << 16)] = value;
+        return 0;
+    } else {
+        return 1;
+    }
+}
+
 static void mem_update_chargen(unsigned int chargen_high)
 {
     uint8_t *old_chargen_rom_ptr;
@@ -261,7 +488,7 @@ void mem_update_config(int config)
 void mem_set_machine_type(unsigned type)
 {
     mem_machine_type = type;
-    caps_sense = 1;
+    mem_caps_key_event(0); /* disable the CAPS key */
     mem_pla_config_changed();
 }
 
@@ -284,8 +511,9 @@ void mem_set_ram_config(uint8_t value)
     DEBUG_PRINT(("MMU: VIC-II base at $%05X\n", ((value & 0xc0) << 2)));
 
     if ((value & 0x3) == 0) {
-        shared_size = 1024;
+        shared_size = 1024; /* 1k */
     } else {
+        /* 4k, 8k, 16k */
         shared_size = 0x1000 << ((value & 0x3) - 1);
     }
 
@@ -325,16 +553,20 @@ void mem_pla_config_changed(void)
     }
 }
 
-static void mem_toggle_caps_key(void)
+/* called when CAPS was pressed or released */
+static int mem_caps_key_event(int pressed)
 {
-    caps_sense = (caps_sense) ? 0 : 1;
+    DBGKEY(("mem_caps_key_event pressed:%d", pressed));
+    /*keyboard_custom_key_set(KBD_CUSTOM_CAPS, pressed);
+    pressed = keyboard_custom_key_get(KBD_CUSTOM_CAPS);*/
+    if (pressed != 1) {
+        pressed = 0;
+    }
+    /* caution, the resource value is 1 when the key is not pressed (enabled = 0) */
+    caps_sense = pressed ? 0 : 1;
     mem_pla_config_changed();
-    log_message(c128_mem_log, "CAPS key (ASCII/DIN) %s.", (caps_sense) ? "released" : "pressed");
-}
-
-static int mem_get_caps_key(void)
-{
-    return caps_sense;
+    DBGKEY(("mem_caps_key_event CAPS key (ASCII/DIN) %s.", (caps_sense) ? "released" : "pressed"));
+    return pressed;
 }
 
 /* ------------------------------------------------------------------------- */
@@ -358,6 +590,7 @@ static int mem_get_caps_key(void)
 
 uint8_t zero_read(uint16_t addr)
 {
+    uint16_t retval = 0;
     addr &= 0xff;
 
     switch ((uint8_t)addr) {
@@ -384,7 +617,17 @@ uint8_t zero_read(uint16_t addr)
             }
             break;
         default:
-            vicii.last_cpu_val = mem_page_zero[addr];
+            if (mem_dma_rw) {
+                /* FIXME: it is assumed that DMA transfers do NOT follow the MMU page 0 translation. */
+                vicii.last_cpu_val = dma_bank[addr];
+            } else {
+                retval = c128_mem_mmu_wrap_read_zero(addr);
+                if (retval == 0x100) {
+                    vicii.last_cpu_val = mem_page_zero[addr];
+                } else {
+                    vicii.last_cpu_val = (uint8_t)retval;
+                }
+            }
     }
 
     return vicii.last_cpu_val;
@@ -398,16 +641,9 @@ void zero_store(uint16_t addr, uint8_t value)
 
     switch ((uint8_t)addr) {
         case 0:
-#if 0
-            if (vbank == 0) {
-                vicii_mem_vbank_store((uint16_t)0, vicii_read_phi1_lowlevel());
-            } else {
-#endif
             mem_page_zero[0] = vicii_read_phi1_lowlevel();
             machine_handle_pending_alarms(maincpu_rmw_flag + 1);
-#if 0
-    }
-#endif
+
             /* when switching an unused bit from output (where it contained a
                stable value) to input mode (where the input is floating), some
                of the charge is transferred to the floating input */
@@ -427,16 +663,9 @@ void zero_store(uint16_t addr, uint8_t value)
             }
             break;
         case 1:
-#if 0
-            if (vbank == 0) {
-                vicii_mem_vbank_store((uint16_t)1, vicii_read_phi1_lowlevel());
-            } else {
-#endif
             mem_page_zero[1] = vicii_read_phi1_lowlevel();
             machine_handle_pending_alarms(maincpu_rmw_flag + 1);
-#if 0
-    }
-#endif
+
             /* when writing to an unused bit that is output, charge the "capacitor",
                otherwise don't touch it */
             if (pport.dir & 0x80) {
@@ -451,15 +680,12 @@ void zero_store(uint16_t addr, uint8_t value)
             }
             break;
         default:
-#if 0
-            if (vbank == 0) {
-                vicii_mem_vbank_store(addr, value);
-            } else {
-#endif
-            mem_page_zero[addr] = value;
-#if 0
-    }
-#endif
+            if (mem_dma_rw) {
+                /* FIXME: it is assumed that DMA transfers do NOT follow the MMU page 0 translation. */
+                dma_bank[addr] = value;
+            } else if (c128_mem_mmu_wrap_store(addr, value)) {
+                mem_page_zero[addr] = value;
+            }
     }
 }
 
@@ -467,12 +693,28 @@ void zero_store(uint16_t addr, uint8_t value)
 
 uint8_t one_read(uint16_t addr)
 {
-    return mem_page_one[addr - 0x100];
+    uint16_t retval = 0;
+
+    if (mem_dma_rw) {
+        /* FIXME: it is assumed that DMA transfers do NOT follow the MMU page 1 translation. */
+        retval = dma_bank[addr];
+    } else {
+        retval = c128_mem_mmu_wrap_read(addr);
+        if (retval == 0x100) {
+            return mem_page_one[addr - 0x100];
+        }
+    }
+    return (uint8_t)retval;
 }
 
 void one_store(uint16_t addr, uint8_t value)
 {
-    mem_page_one[addr - 0x100] = value;
+    if (mem_dma_rw) {
+        /* FIXME: it is assumed that DMA transfers do NOT follow the MMU page 1 translation. */
+        dma_bank[addr] = value;
+    } else if (c128_mem_mmu_wrap_store(addr, value)) {
+        mem_page_one[addr - 0x100] = value;
+    }
 }
 
 /* ------------------------------------------------------------------------- */
@@ -491,6 +733,28 @@ void chargen_store(uint16_t addr, uint8_t value)
     mem_chargen_rom_ptr[addr & 0x0fff] = value;
 }
 
+/* ------------------------------------------------------------------------- */
+
+/* DMA memory access.  */
+
+void mem_dma_store(uint16_t addr, uint8_t value)
+{
+    mem_dma_rw = 1;
+    _mem_write_tab_ptr[addr >> 8](addr, value);
+    mem_dma_rw = 0;
+}
+
+uint8_t mem_dma_read(uint16_t addr)
+{
+    uint8_t retval = 0;
+
+    mem_dma_rw = 1;
+    retval = _mem_read_tab_ptr[addr >> 8](addr);
+    mem_dma_rw = 0;
+    return retval;
+}
+
+
 /* ------------------------------------------------------------------------- */
 
 /* Generic memory access.  */
@@ -560,21 +824,49 @@ void mem_store_without_romlh(uint16_t addr, uint8_t value)
 /* $0200 - $3FFF: RAM (normal or shared).  */
 uint8_t lo_read(uint16_t addr)
 {
-    vicii.last_cpu_val = READ_BOTTOM_SHARED(addr);
+    uint16_t retval = 0;
 
+    if (mem_dma_rw) {
+        /* FIXME: it is assumed that DMA transfers do NOT follow the MMU shared ram translation. */
+        vicii.last_cpu_val = dma_bank[addr];
+    } else {
+        retval = c128_mem_mmu_wrap_read(addr);
+        if (retval == 0x100) {
+            vicii.last_cpu_val = READ_BOTTOM_SHARED(addr);
+        } else {
+            vicii.last_cpu_val = (uint8_t)retval;
+        }
+    }
     return vicii.last_cpu_val;
 }
 
 void lo_store(uint16_t addr, uint8_t value)
 {
     vicii.last_cpu_val = value;
-    STORE_BOTTOM_SHARED(addr, value);
+
+    if (mem_dma_rw) {
+        /* FIXME: it is assumed that DMA transfers do NOT follow the MMU shared ram translation. */
+        dma_bank[addr] = value;
+    } else if (c128_mem_mmu_wrap_store(addr, value)) {
+        STORE_BOTTOM_SHARED(addr, value);
+    }
 }
 
 uint8_t ram_read(uint16_t addr)
 {
-    vicii.last_cpu_val = ram_bank[addr];
+    uint16_t retval = 0;
 
+    if (mem_dma_rw) {
+        vicii.last_cpu_val = dma_bank[addr];
+    } else {
+        retval = c128_mem_mmu_wrap_read(addr);
+
+        if (retval == 0x100) {
+            vicii.last_cpu_val = ram_bank[addr];
+        } else {
+            vicii.last_cpu_val = (uint8_t)retval;
+        }
+    }
     return vicii.last_cpu_val;
 }
 
@@ -582,20 +874,26 @@ void ram_store(uint16_t addr, uint8_t value)
 {
     vicii.last_cpu_val = value;
 
-    ram_bank[addr] = value;
+    if (mem_dma_rw) {
+        dma_bank[addr] = value;
+    } else if (c128_mem_mmu_wrap_store(addr, value)) {
+        ram_bank[addr] = value;
+    }
 }
 
 void ram_hi_store(uint16_t addr, uint8_t value)
 {
     vicii.last_cpu_val = value;
 
-    if (vbank == 3) {
+    if (mem_dma_rw) {
+        dma_bank[addr] = value;
+    } else if (vbank == 3) {
         vicii_mem_vbank_3fxx_store(addr, value);
     } else {
         ram_bank[addr] = value;
     }
 
-    if (addr == 0xff00) {
+    if (addr == 0xff00 && !mem_dma_rw) {
         reu_dma(-1);
     }
 }
@@ -612,7 +910,11 @@ void basic_lo_store(uint16_t addr, uint8_t value)
 {
     vicii.last_cpu_val = value;
 
-    ram_bank[addr] = value;
+    if (mem_dma_rw) {
+        dma_bank[addr] = value;
+    } else {
+        ram_bank[addr] = value;
+    }
 }
 
 /* $8000 - $BFFF: RAM or high BASIC ROM.  */
@@ -625,7 +927,12 @@ uint8_t basic_hi_read(uint16_t addr)
 void basic_hi_store(uint16_t addr, uint8_t value)
 {
     vicii.last_cpu_val = value;
-    ram_bank[addr] = value;
+
+    if (mem_dma_rw) {
+        dma_bank[addr] = value;
+    } else {
+        ram_bank[addr] = value;
+    }
 }
 
 /* $C000 - $CFFF: RAM (normal or shared) or Editor ROM.  */
@@ -713,19 +1020,41 @@ uint8_t hi_read(uint16_t addr)
 void hi_store(uint16_t addr, uint8_t value)
 {
     vicii.last_cpu_val = value;
-    STORE_TOP_SHARED(addr, value);
+
+    if (mem_dma_rw) {
+        dma_bank[addr] = value;
+    } else {
+        STORE_TOP_SHARED(addr, value);
+    }
 }
 
 uint8_t top_shared_read(uint16_t addr)
 {
-    vicii.last_cpu_val = READ_TOP_SHARED(addr);
+    uint16_t retval = 0;
+
+    if (mem_dma_rw) {
+        vicii.last_cpu_val = dma_bank[addr];
+    } else {
+        retval = c128_mem_mmu_wrap_read(addr);
+        if (retval == 0x100) {
+            vicii.last_cpu_val = READ_TOP_SHARED(addr);
+        } else {
+            vicii.last_cpu_val = (uint8_t)retval;
+        }
+    }
+
     return vicii.last_cpu_val;
 }
 
 void top_shared_store(uint16_t addr, uint8_t value)
 {
     vicii.last_cpu_val = value;
-    STORE_TOP_SHARED(addr, value);
+
+    if (mem_dma_rw) {
+        vicii.last_cpu_val = dma_bank[addr];
+    } else if (c128_mem_mmu_wrap_store(addr, value)) {
+        STORE_TOP_SHARED(addr, value);
+    }
 }
 
 /* ------------------------------------------------------------------------- */
@@ -857,8 +1186,8 @@ void mem_initialize_memory(void)
             mem_set_write_hook(128 + j, 0xd4, c128_c64io_d400_store);
             mem_read_tab[128 + j][0xd5] = c128_d5xx_read;
             mem_set_write_hook(128 + j, 0xd5, c128_d5xx_store);
-            mem_read_tab[128 + j][0xd6] = c128_vdc_read;
-            mem_set_write_hook(128 + j, 0xd6, c128_vdc_store);
+            mem_read_tab[128 + j][0xd6] = c128_c64io_d600_read;
+            mem_set_write_hook(128 + j, 0xd6, c128_c64io_d600_store);
             mem_read_tab[128 + j][0xd7] = c128_c64io_d700_read;
             mem_set_write_hook(128 + j, 0xd7, c128_c64io_d700_store);
             mem_read_tab[128 + j][0xd8] = c128_colorram_read;
@@ -891,9 +1220,9 @@ void mem_initialize_memory(void)
     vicii_set_chargen_addr_options(0xffff, 0xffff);
 
     mmu_reset();
-
-    keyboard_register_caps_key(mem_toggle_caps_key);
-    keyboard_register_get_caps_key(mem_get_caps_key);
+    /* CAUTION: the registered function MUST NOT call keyboard_custom_key_set() */
+    keyboard_register_custom_key(KBD_CUSTOM_CAPS, mem_caps_key_event, "CAPS (ASCII/DIN)",
+                                 &key_ctrl_caps, &key_flags_caps);
 
     top_shared_limit = 0xffff;
     bottom_shared_limit = 0x0000;
@@ -984,7 +1313,7 @@ void mem_set_basic_text(uint16_t start, uint16_t end)
 }
 
 /* this function should always read from the screen currently used by the kernal
-   for output, normally this does just return system ram - except when the 
+   for output, normally this does just return system ram - except when the
    videoram is not memory mapped.
    used by autostart to "read" the kernal messages
 */
@@ -1082,7 +1411,7 @@ void store_bank_io(uint16_t addr, uint8_t byte)
             mmu_store(addr, byte);
             break;
         case 0xd600:
-            vdc_store(addr, byte);
+            c64io_d600_store(addr, byte);
             break;
         case 0xd700:
             c64io_d700_store(addr, byte);
@@ -1125,7 +1454,7 @@ uint8_t read_bank_io(uint16_t addr)
         case 0xd500:
             return mmu_read(addr);
         case 0xd600:
-            return vdc_read(addr);
+            return c64io_d600_read(addr);
         case 0xd700:
             return c64io_d700_read(addr);
         case 0xd800:
@@ -1161,7 +1490,7 @@ static uint8_t peek_bank_io(uint16_t addr)
         case 0xd500:
             return mmu_peek(addr);
         case 0xd600:
-            return vdc_peek(addr);
+            return c64io_d600_peek(addr);
         case 0xd700:
             return c64io_d700_peek(addr);
         case 0xd800:
@@ -1182,12 +1511,12 @@ static uint8_t peek_bank_io(uint16_t addr)
 }
 
 /* Exported banked memory access functions for the monitor.  */
-#define MAXBANKS (5 + 2 + 5)
+#define MAXBANKS (5 + 2 + 5 + 2)
 
 /* FIXME: add ram00 bank, make 'ram' bank always show selected ram bank, ram00
  * and ram01 always physical ram bank */
 
-static const char *banknames[MAXBANKS + 1] = {
+static const char *banknames128[MAXBANKS + 1] = {
     "default",
     "cpu",
     "ram",
@@ -1204,37 +1533,90 @@ static const char *banknames[MAXBANKS + 1] = {
     NULL
 };
 
-enum {
-    bank_cpu = 0,
-    bank_ram,
-    bank_rom,
-    bank_io,
-    bank_ram00,
-    bank_ram01,
-    bank_intfunc,
-    bank_extfunc,
-    bank_cart,
-    bank_c64rom,
-    bank_vdc
+static const char *banknames256[MAXBANKS + 1] = {
+    "default",
+    "cpu",
+    "ram",
+    "rom",
+    "io",
+    /* by convention, a "bank array" has a 2-hex-digit bank index appended */
+    "ram00",
+    "ram01",
+    "ram02",
+    "ram03",
+    "intfunc",
+    "extfunc",
+    "cart",
+    "c64rom",
+    "vdc",
+    NULL
 };
 
-static const int banknums[MAXBANKS + 1] = {
-    bank_cpu, /* default */
-    bank_cpu,
-    bank_ram,
-    bank_rom,
-    bank_io,
-    bank_ram00,
-    bank_ram01,
-    bank_intfunc,
-    bank_extfunc,
-    bank_cart,
-    bank_c64rom,
-    bank_vdc,
+enum {
+    bank128_cpu = 0,
+    bank128_ram,
+    bank128_rom,
+    bank128_io,
+    bank128_ram00,
+    bank128_ram01,
+    bank128_intfunc,
+    bank128_extfunc,
+    bank128_cart,
+    bank128_c64rom,
+    bank128_vdc
+};
+
+enum {
+    bank256_cpu = 0,
+    bank256_ram,
+    bank256_rom,
+    bank256_io,
+    bank256_ram00,
+    bank256_ram01,
+    bank256_ram02,
+    bank256_ram03,
+    bank256_intfunc,
+    bank256_extfunc,
+    bank256_cart,
+    bank256_c64rom,
+    bank256_vdc
+};
+
+static const int banknums128[MAXBANKS + 1] = {
+    bank128_cpu, /* default */
+    bank128_cpu,
+    bank128_ram,
+    bank128_rom,
+    bank128_io,
+    bank128_ram00,
+    bank128_ram01,
+    bank128_intfunc,
+    bank128_extfunc,
+    bank128_cart,
+    bank128_c64rom,
+    bank128_vdc,
     -1
 };
 
-static const int bankindex[MAXBANKS + 1] = {
+static const int banknums256[MAXBANKS + 1] = {
+    bank256_cpu, /* default */
+    bank256_cpu,
+    bank256_ram,
+    bank256_rom,
+    bank256_io,
+    bank256_ram00,
+    bank256_ram01,
+    bank256_ram02,
+    bank256_ram03,
+    bank256_intfunc,
+    bank256_extfunc,
+    bank256_cart,
+    bank256_c64rom,
+    bank256_vdc,
+    -1
+};
+
+static const int bankindex128[MAXBANKS + 1] = {
     -1,
     -1,
     -1,
@@ -1250,7 +1632,25 @@ static const int bankindex[MAXBANKS + 1] = {
     -1
 };
 
-static const int bankflags[MAXBANKS + 1] = {
+static const int bankindex256[MAXBANKS + 1] = {
+    -1,
+    -1,
+    -1,
+    -1,
+    -1,
+    0,
+    1,
+    2,
+    3,
+    -1,
+    -1,
+    -1,
+    -1,
+    -1,
+    -1
+};
+
+static const int bankflags128[MAXBANKS + 1] = {
     0,
     0,
     0,
@@ -1266,13 +1666,31 @@ static const int bankflags[MAXBANKS + 1] = {
     -1
 };
 
+static const int bankflags256[MAXBANKS + 1] = {
+    0,
+    0,
+    0,
+    0,
+    0,
+    MEM_BANK_ISARRAY | MEM_BANK_ISARRAYFIRST,
+    MEM_BANK_ISARRAY,
+    MEM_BANK_ISARRAY,
+    MEM_BANK_ISARRAY | MEM_BANK_ISARRAYLAST,
+    0,
+    0,
+    0,
+    0,
+    0,
+    -1
+};
+
 const char **mem_bank_list(void)
 {
-    return banknames;
+    return (c128_full_banks) ? banknames256 : banknames128;
 }
 
 const int *mem_bank_list_nos(void) {
-    return banknums;
+    return (c128_full_banks) ? banknums256 : banknums128;
 }
 
 /* return bank number for a given literal bank name */
@@ -1280,11 +1698,20 @@ int mem_bank_from_name(const char *name)
 {
     int i = 0;
 
-    while (banknames[i]) {
-        if (!strcmp(name, banknames[i])) {
-            return banknums[i];
+    if (c128_full_banks) {
+        while (banknames256[i]) {
+            if (!strcmp(name, banknames256[i])) {
+                return banknums256[i];
+            }
+            i++;
+        }
+    } else {
+        while (banknames128[i]) {
+            if (!strcmp(name, banknames128[i])) {
+                return banknums128[i];
+            }
+            i++;
         }
-        i++;
     }
     return -1;
 }
@@ -1294,11 +1721,20 @@ int mem_bank_index_from_bank(int bank)
 {
     int i = 0;
 
-    while (banknums[i] > -1) {
-        if (banknums[i] == bank) {
-            return bankindex[i];
+    if (c128_full_banks) {
+        while (banknums256[i] > -1) {
+            if (banknums256[i] == bank) {
+                return bankindex256[i];
+            }
+            i++;
+        }
+    } else {
+        while (banknums128[i] > -1) {
+            if (banknums128[i] == bank) {
+                return bankindex128[i];
+            }
+            i++;
         }
-        i++;
     }
     return -1;
 }
@@ -1307,30 +1743,78 @@ int mem_bank_flags_from_bank(int bank)
 {
     int i = 0;
 
-    while (banknums[i] > -1) {
-        if (banknums[i] == bank) {
-            return bankflags[i];
+    if (c128_full_banks) {
+        while (banknums256[i] > -1) {
+            if (banknums256[i] == bank) {
+                return bankflags256[i];
+            }
+            i++;
+        }
+    } else {
+        while (banknums128[i] > -1) {
+            if (banknums128[i] == bank) {
+                return bankflags128[i];
+            }
+            i++;
         }
-        i++;
     }
     return -1;
 }
 
-uint8_t mem_bank_read(int bank, uint16_t addr, void *context)
+static int mem_bank_translate_128_to_256(int bank)
 {
     switch (bank) {
-        case bank_cpu:                   /* current */
+        case bank128_cpu:
+            return bank256_cpu;
+        case bank128_ram:
+            return bank256_ram;
+        case bank128_rom:
+            return bank256_rom;
+        case bank128_io:
+            return bank256_io;
+        case bank128_ram00:
+            return bank256_ram00;
+        case bank128_ram01:
+            return bank256_ram01;
+        case bank128_intfunc:
+            return bank256_intfunc;
+        case bank128_extfunc:
+            return bank256_extfunc;
+        case bank128_cart:
+            return bank256_cart;
+        case bank128_c64rom:
+            return bank256_c64rom;
+        case bank128_vdc:
+            return bank256_vdc;
+    }
+    return bank256_cpu;
+};
+
+uint8_t mem_bank_read(int bank, uint16_t addr, void *context)
+{
+    int real_bank = bank;
+
+    if (!c128_full_banks) {
+        real_bank = mem_bank_translate_128_to_256(bank);
+    }
+
+    switch (real_bank) {
+        case bank256_cpu:                   /* current */
             return mem_read(addr);
-        case bank_ram00:                   /* ram0 */
+        case bank256_ram00:                   /* ram0 */
             return mem_ram[addr];
-        case bank_ram01:                   /* ram1 */
+        case bank256_ram01:                   /* ram1 */
             return mem_ram[addr + 0x10000];
-        case bank_io:                   /* io */
+        case bank256_ram02:                   /* ram2 */
+            return mem_ram[addr + 0x20000];
+        case bank256_ram03:                   /* ram3 */
+            return mem_ram[addr + 0x30000];
+        case bank256_io:                   /* io */
             if (addr >= 0xd000 && addr < 0xe000) {
                 return read_bank_io(addr);
             }
             /* FALL THROUGH */
-        case bank_rom:                   /* rom */
+        case bank256_rom:                   /* rom */
             if (addr <= 0x0fff) {
                 return bios_read(addr);
             }
@@ -1344,21 +1828,21 @@ uint8_t mem_bank_read(int bank, uint16_t addr, void *context)
                 return c128memrom_kernal_rom[addr & 0x1fff];
             }
             /* FALL THROUGH */
-        case bank_ram:                   /* ram */
+        case bank256_ram:                   /* ram */
             break;
-        case bank_intfunc:
+        case bank256_intfunc:
             if (addr >= 0x8000) {
                 return int_function_rom[addr & 0x7fff];
             }
             break;
-        case bank_extfunc:
+        case bank256_extfunc:
             if (addr >= 0x8000) {
                 return ext_function_rom[addr & 0x7fff];
             }
             break;
-        case bank_cart:
+        case bank256_cart:
             return cartridge_peek_mem(addr);
-        case bank_c64rom:
+        case bank256_c64rom:
             if (addr >= 0xa000 && addr <= 0xbfff) {
                 return c64memrom_basic64_rom[addr & 0x1fff];
             }
@@ -1369,7 +1853,7 @@ uint8_t mem_bank_read(int bank, uint16_t addr, void *context)
                 return c64memrom_kernal64_rom[addr & 0x1fff];
             }
             break;
-        case bank_vdc:
+        case bank256_vdc:
             return vdc_ram_read(addr);
     }
     return mem_ram[addr];
@@ -1378,8 +1862,14 @@ uint8_t mem_bank_read(int bank, uint16_t addr, void *context)
 /* used by monitor if sfx off */
 uint8_t mem_bank_peek(int bank, uint16_t addr, void *context)
 {
-    switch (bank) {
-        case bank_cpu:                   /* current */
+    int real_bank = bank;
+
+    if (!c128_full_banks) {
+        real_bank = mem_bank_translate_128_to_256(bank);
+    }
+
+    switch (real_bank) {
+        case bank256_cpu:                   /* current */
             /* FIXME: we must check for which bank is currently active, and only use peek_bank_io
                       when needed. doing this without checking is wrong, but we do it anyways to
                       avoid side effects
@@ -1389,12 +1879,12 @@ uint8_t mem_bank_peek(int bank, uint16_t addr, void *context)
             }
             return mem_read(addr);
             break;
-        case bank_io:                   /* io */
+        case bank256_io:                   /* io */
             if (addr >= 0xd000 && addr < 0xe000) {
                 return peek_bank_io(addr);
             }
             break;
-        case bank_cart:
+        case bank256_cart:
             return cartridge_peek_mem(addr);
     }
     return mem_bank_read(bank, addr, context);
@@ -1402,23 +1892,35 @@ uint8_t mem_bank_peek(int bank, uint16_t addr, void *context)
 
 void mem_bank_write(int bank, uint16_t addr, uint8_t byte, void *context)
 {
-    switch (bank) {
-        case bank_cpu:                   /* current */
+    int real_bank = bank;
+
+    if (!c128_full_banks) {
+        real_bank = mem_bank_translate_128_to_256(bank);
+    }
+
+    switch (real_bank) {
+        case bank256_cpu:                   /* current */
             mem_store(addr, byte);
             return;
-        case bank_ram00:                   /* ram0 */
+        case bank256_ram00:                   /* ram0 */
             mem_ram[addr] = byte;
             return;
-        case bank_ram01:                   /* ram1 */
+        case bank256_ram01:                   /* ram1 */
             mem_ram[addr + 0x10000] = byte;
             return;
-        case bank_io:                   /* io */
+        case bank256_ram02:                   /* ram2 */
+            mem_ram[addr + 0x20000] = byte;
+            return;
+        case bank256_ram03:                   /* ram3 */
+            mem_ram[addr + 0x30000] = byte;
+            return;
+        case bank256_io:                   /* io */
             if (addr >= 0xd000 && addr < 0xe000) {
                 store_bank_io(addr, byte);
                 return;
             }
             /* FALL THROUGH */
-        case bank_rom:                   /* rom */
+        case bank256_rom:                   /* rom */
             if (addr >= 0x4000 && addr <= 0xcfff) {
                 return;
             }
@@ -1426,19 +1928,19 @@ void mem_bank_write(int bank, uint16_t addr, uint8_t byte, void *context)
                 return;
             }
             /* FALL THROUGH */
-        case bank_ram:                   /* ram */
+        case bank256_ram:                   /* ram */
             break;
-        case bank_intfunc:
+        case bank256_intfunc:
             if (addr >= 0x8000) {
                 return;
             }
             break;
-        case bank_extfunc:
+        case bank256_extfunc:
             if (addr >= 0x8000 && addr <= 0xbfff) {
                 return;
             }
             break;
-        case bank_cart:
+        case bank256_cart:
             if (addr >= 0x8000 && addr <= 0x9fff) {
                 return;
             }
@@ -1446,7 +1948,7 @@ void mem_bank_write(int bank, uint16_t addr, uint8_t byte, void *context)
                 return;
             }
             /* FALL THROUGH */
-        case bank_c64rom:
+        case bank256_c64rom:
             if (addr >= 0xa000 && addr <= 0xbfff) {
                 return;
             }
@@ -1457,9 +1959,9 @@ void mem_bank_write(int bank, uint16_t addr, uint8_t byte, void *context)
                 return;
             }
             break;
-        case bank_vdc:
+        case bank256_vdc:
             vdc_ram_store(addr, byte);
-            break;
+            return;
     }
     mem_ram[addr] = byte;
 }
@@ -1487,7 +1989,7 @@ mem_ioreg_list_t *mem_ioreg_list_get(void *context)
     io_source_ioreg_add_list(&mem_ioreg_list);  /* VIC-IIe, SID first so it's in address order */
 
     mon_ioreg_add_list(&mem_ioreg_list, "MMU", 0xd500, 0xd50b, mmu_dump, NULL, IO_MIRROR_NONE);
-    mon_ioreg_add_list(&mem_ioreg_list, "VDC", 0xd600, 0xd601, vdc_dump, NULL, IO_MIRROR_NONE);
+    /*mon_ioreg_add_list(&mem_ioreg_list, "VDC", 0xd600, 0xd601, vdc_dump, NULL, IO_MIRROR_NONE);*/
     mon_ioreg_add_list(&mem_ioreg_list, "CIA1", 0xdc00, 0xdc0f, mem_dump_io, NULL, IO_MIRROR_NONE);
     mon_ioreg_add_list(&mem_ioreg_list, "CIA2", 0xdd00, 0xdd0f, mem_dump_io, NULL, IO_MIRROR_NONE);
 
@@ -1504,7 +2006,11 @@ void mem_get_screen_parameter(uint16_t *base, uint8_t *rows, uint8_t *columns, i
             *base = (vdc.regs[12] << 8) | vdc.regs[13];
             *rows = vdc.regs[6];
             *columns = vdc.regs[1];
-            *bank = bank_vdc;
+            if (c128_full_banks) {
+                *bank = bank256_vdc;
+            } else {
+                *bank = bank128_vdc;
+            }
             break;
 
         case VIDEO_CHIP_VICII:
@@ -1522,7 +2028,7 @@ void mem_get_screen_parameter(uint16_t *base, uint8_t *rows, uint8_t *columns, i
 
 /* used by autostart to locate and "read" kernal output on the current screen
  * this function should return whatever the kernal currently uses, regardless
- * what is currently visible/active in the UI 
+ * what is currently visible/active in the UI
  */
 void mem_get_cursor_parameter(uint16_t *screen_addr, uint8_t *cursor_column, uint8_t *line_length, int *blinking)
 {
@@ -1554,7 +2060,7 @@ void mem_get_cursor_parameter(uint16_t *screen_addr, uint8_t *cursor_column, uin
             *cursor_column = mem_ram[0xec];
             *line_length = 40;
             *blinking = mem_ram[0xa27] ? 0 : 1;
-        } else { 
+        } else {
             /* VDC */
             int screen_base = ((vdc.regs[12] << 8) + vdc.regs[13]) & vdc.vdc_address_mask;
             int cursor_pos = ((vdc.regs[14] << 8) + vdc.regs[15]) & vdc.vdc_address_mask;
@@ -1691,18 +2197,18 @@ void c128_d5xx_store(uint16_t addr, uint8_t value)
     d5xx_store(addr, value);
 }
 
-uint8_t c128_vdc_read(uint16_t addr)
+uint8_t c128_c64io_d600_read(uint16_t addr)
 {
-    vicii.last_cpu_val = vdc_read(addr);
+    vicii.last_cpu_val = c64io_d600_read(addr);
     vicii_clock_read_stretch();
     return vicii.last_cpu_val;
 }
 
-void c128_vdc_store(uint16_t addr, uint8_t value)
+void c128_c64io_d600_store(uint16_t addr, uint8_t value)
 {
     vicii.last_cpu_val = value;
     vicii_clock_write_stretch();
-    vdc_store(addr, value);
+    c64io_d600_store(addr, value);
 }
 
 uint8_t c128_c64io_d700_read(uint16_t addr)
