@@ -295,7 +295,7 @@ uint8_t machine_tape_behaviour(void)
     return TAPE_BEHAVIOUR_NORMAL;
 }
 
-#if defined(USE_SDLUI) || defined(USE_SDLUI2)
+#if defined(USE_SDLUI) || defined(USE_SDL2UI)
 char *kbd_get_menu_keyname(void)
 {
     return NULL;
@@ -311,3 +311,8 @@ int crt_getid(const char *filename)
 void ui_hotkeys_init(void)
 {
 }
+
+int drive_get_disk_drive_type(int dnr)
+{
+    return DRIVE_TYPE_NONE;
+}
