@@ -96,7 +96,6 @@
 #include "ninja_snespad.h"
 #include "paperclip64.h"
 #include "parallel.h"
-#include "patchrom.h"
 #include "plus256k.h"
 #include "plus60k.h"
 #include "printer.h"
@@ -135,6 +134,7 @@
 #include "userport_petscii_snespad.h"
 #include "userport_rtc_58321a.h"
 #include "userport_rtc_ds1307.h"
+#include "userport_spt_joystick.h"
 #include "userport_superpad64.h"
 #include "userport_wic64.h"
 #include "vice-event.h"
@@ -267,7 +267,7 @@ static io_source_t vicii_d100_device = {
     NULL,                         /* NO poke function */
     vicii_read,                   /* read function */
     vicii_peek,                   /* peek function */
-    vicii_dump,                   /* chip state information dump function */ 
+    vicii_dump,                   /* chip state information dump function */
     IO_CART_ID_NONE,              /* not a cartridge */
     IO_PRIO_HIGH,                 /* high priority, mirrors never involved in collisions */
     0,                            /* insertion order, gets filled in by the registration function */
@@ -287,7 +287,7 @@ static io_source_t vicii_d200_device = {
     NULL,                         /* NO poke function */
     vicii_read,                   /* read function */
     vicii_peek,                   /* peek function */
-    vicii_dump,                   /* chip state information dump function */ 
+    vicii_dump,                   /* chip state information dump function */
     IO_CART_ID_NONE,              /* not a cartridge */
     IO_PRIO_HIGH,                 /* high priority, mirrors never involved in collisions */
     0,                            /* insertion order, gets filled in by the registration function */
@@ -307,7 +307,7 @@ static io_source_t vicii_d300_device = {
     NULL,                         /* NO poke function */
     vicii_read,                   /* read function */
     vicii_peek,                   /* peek function */
-    vicii_dump,                   /* chip state information dump function */ 
+    vicii_dump,                   /* chip state information dump function */
     IO_CART_ID_NONE,              /* not a cartridge */
     IO_PRIO_HIGH,                 /* high priority, mirrors never involved in collisions */
     0,                            /* insertion order, gets filled in by the registration function */
@@ -752,10 +752,6 @@ int machine_resources_init(void)
         init_resource_fail("joystick");
         return -1;
     }
-    if (gfxoutput_resources_init() < 0) {
-        init_resource_fail("gfxoutput");
-        return -1;
-    }
     if (sampler_resources_init() < 0) {
         init_resource_fail("samplerdrv");
         return -1;
@@ -853,6 +849,10 @@ int machine_resources_init(void)
         init_resource_fail("userport synergy joystick");
         return -1;
     }
+    if (userport_spt_joystick_resources_init() < 0) {
+        init_resource_fail("userport stupid pet tricks joystick");
+        return -1;
+    }
     if (userport_dac_resources_init() < 0) {
         init_resource_fail("userport dac");
         return -1;
@@ -1017,10 +1017,6 @@ int machine_cmdline_options_init(void)
         init_cmdline_options_fail("userport");
         return -1;
     }
-    if (gfxoutput_cmdline_options_init() < 0) {
-        init_cmdline_options_fail("gfxoutput");
-        return -1;
-    }
     if (sampler_cmdline_options_init() < 0) {
         init_cmdline_options_fail("samplerdrv");
         return -1;
@@ -1331,7 +1327,7 @@ void machine_specific_powerup(void)
 void machine_specific_shutdown(void)
 {
     tape_image_detach_internal(TAPEPORT_PORT_1 + 1);
-    
+
     /* and cartridge */
     cartridge_detach_image(-1);
 
@@ -1450,7 +1446,7 @@ void machine_change_timing(int timeval, int border_mode)
     serial_iec_device_set_machine_parameter(machine_timing.cycles_per_sec);
     sid_set_machine_parameter(machine_timing.cycles_per_sec);
 #ifdef HAVE_MOUSE
-    neos_mouse_set_machine_parameter(machine_timing.cycles_per_sec);
+    mouse_set_machine_parameter(machine_timing.cycles_per_sec);
 #endif
 
     vicii_change_timing(&machine_timing, border_mode);
