@@ -457,7 +457,9 @@ static int set_ieee488_enabled(int value, void *param)
             if (ieee488_filename) {
                 if (*ieee488_filename) {
                     DBG(("IEEE: attach default image\n"));
-                    if (cartridge_attach_image(CARTRIDGE_IEEE488, ieee488_filename) < 0) {
+                    /* try crt first, then binary */
+                    if ((cartridge_attach_image(CARTRIDGE_CRT, ieee488_filename) < 0) &&
+                        (cartridge_attach_image(CARTRIDGE_IEEE488, ieee488_filename) < 0)) {
                         DBG(("IEEE: set_enabled did not register\n"));
                         lib_free(tpi_rom);
                         tpi_rom = NULL;
@@ -504,7 +506,7 @@ static int set_ieee488_filename(const char *name, void *param)
     if (set_ieee488_enabled(enabled, (void*)1) < 0) {
         lib_free(ieee488_filename);
         ieee488_filename = NULL;
-        DBG(("IEEE: set_name done: %d '%s'\n", ieee488_enabled, ieee488_filename));
+        DBG(("IEEE: set_name done: %d 'NULL'\n", ieee488_enabled));
         return -1;
     }
 
@@ -619,10 +621,11 @@ int tpi_bin_attach(const char *filename, uint8_t *rawcart)
     if (util_file_load(filename, rawcart, TPI_ROM_SIZE, UTIL_FILE_LOAD_SKIP_ADDRESS) < 0) {
         return -1;
     }
+    set_ieee488_filename(filename, NULL); /* set the resource */
     return tpi_common_attach();
 }
 
-int tpi_crt_attach(FILE *fd, uint8_t *rawcart)
+int tpi_crt_attach(FILE *fd, uint8_t *rawcart, const char *filename)
 {
     crt_chip_header_t chip;
 
@@ -638,6 +641,7 @@ int tpi_crt_attach(FILE *fd, uint8_t *rawcart)
         return -1;
     }
 
+    set_ieee488_filename(filename, NULL); /* set the resource */
     return tpi_common_attach();
 }
 
