@@ -32,9 +32,9 @@
 #include "types.h"
 
 extern void dsm_config_init(void);
-extern void dsm_config_setup(BYTE *rawcart);
-extern int dsm_bin_attach(const char *filename, BYTE *rawcart);
-extern int dsm_crt_attach(FILE *fd, BYTE *rawcart);
+extern void dsm_config_setup(uint8_t *rawcart);
+extern int dsm_bin_attach(const char *filename, uint8_t *rawcart);
+extern int dsm_crt_attach(FILE *fd, uint8_t *rawcart);
 extern void dsm_detach(void);
 extern void dsm_freeze(void);
 
