@@ -304,7 +304,7 @@ int digimax_cmdline_options_init(void)
     if (machine_class == VICE_MACHINE_VIC20) {
         temp1 = util_gen_hex_address_list(0x9800, 0x9900, 0x20);
         temp2 = util_gen_hex_address_list(0x9c00, 0x9d00, 0x20);
-        digimax_address_list = util_concat("Base address of the DigiMAX cartridge. (", temp1, "/", temp2, ")", NULL);        
+        digimax_address_list = util_concat("Base address of the DigiMAX cartridge. (", temp1, "/", temp2, ")", NULL);
         lib_free(temp2);
     } else {
         temp1 = util_gen_hex_address_list(0xde00, 0xe000, 0x20);
@@ -331,7 +331,7 @@ int digimax_cmdline_options_init(void)
    BYTE  | voice 3    | voice 3 data
  */
 
-static char snap_module_name[] = "CARTDIGIMAX";
+static const char snap_module_name[] = "CARTDIGIMAX";
 #define SNAP_MAJOR   0
 #define SNAP_MINOR   0
 
