@@ -31,13 +31,20 @@
 
 #include "types.h"
 
+#define RGCD_REV_RGCD_64K  0
+#define RGCD_REV_HUCKY 1
+
 extern void rgcd_reset(void);
 extern void rgcd_config_init(void);
 extern void rgcd_config_setup(uint8_t *rawcart);
 extern int rgcd_bin_attach(const char *filename, uint8_t *rawcart);
-extern int rgcd_crt_attach(FILE *fd, uint8_t *rawcart);
+extern int rgcd_crt_attach(FILE *fd, uint8_t *rawcart, uint8_t revision);
 extern void rgcd_detach(void);
 
+extern int rgcd_cmdline_options_init(void);
+extern int rgcd_resources_init(void);
+extern void rgcd_resources_shutdown(void);
+
 struct snapshot_s;
 
 extern int rgcd_snapshot_write_module(struct snapshot_s *s);
