@@ -58,11 +58,37 @@ static log_t c64_snapshot_log = LOG_ERR;
 
 static const char snap_rom_module_name[] = "C64ROM";
 
+#define NUM_TRAP_DEVICES 9  /* FIXME: is there a better constant ? */
+static int trapfl[NUM_TRAP_DEVICES];
+static int trapdevices[NUM_TRAP_DEVICES + 1] = { 1, 4, 5, 6, 7, 8, 9, 10, 11, -1 };
+
+static void get_trapflags(void)
+{
+    int i;
+    for(i = 0; trapdevices[i] != -1; i++) {
+        resources_get_int_sprintf("VirtualDevice%d", &trapfl[i], trapdevices[i]);
+    }
+}
+
+static void clear_trapflags(void)
+{
+    int i;
+    for(i = 0; trapdevices[i] != -1; i++) {
+        resources_set_int_sprintf("VirtualDevice%d", 0, trapdevices[i]);
+    }
+}
+
+static void restore_trapflags(void)
+{
+    int i;
+    for(i = 0; trapdevices[i] != -1; i++) {
+        resources_set_int_sprintf("VirtualDevice%d", trapfl[i], trapdevices[i]);
+    }
+}
 
 static int c64dtv_snapshot_write_rom_module(snapshot_t *s)
 {
     snapshot_module_t *m;
-    int trapfl;
 
     /* Main memory module.  */
 
@@ -73,8 +99,8 @@ static int c64dtv_snapshot_write_rom_module(snapshot_t *s)
     }
 
     /* disable traps before saving the ROM */
-    resources_get_int("VirtualDevices", &trapfl);
-    resources_set_int("VirtualDevices", 0);
+    get_trapflags();
+    clear_trapflags();
 
     if (SMW_BA(m, c64dtvflash_mem, 0x200000) < 0 /* hack */
         || SMW_B(m, c64dtvflash_state) < 0
@@ -86,7 +112,7 @@ static int c64dtv_snapshot_write_rom_module(snapshot_t *s)
         goto fail;
     }
 
-    resources_set_int("VirtualDevices", trapfl);
+    restore_trapflags();
 
     return 0;
 
@@ -95,7 +121,7 @@ fail:
         snapshot_module_close(m);
     }
 
-    resources_set_int("VirtualDevices", trapfl);
+    restore_trapflags();
 
     return -1;
 }
@@ -104,7 +130,6 @@ static int c64dtv_snapshot_read_rom_module(snapshot_t *s)
 {
     uint8_t major_version, minor_version;
     snapshot_module_t *m;
-    int trapfl;
 
     /* Main memory module.  */
 
@@ -126,8 +151,8 @@ static int c64dtv_snapshot_read_rom_module(snapshot_t *s)
     }
 
     /* disable traps before loading the ROM */
-    resources_get_int("VirtualDevices", &trapfl);
-    resources_set_int("VirtualDevices", 0);
+    get_trapflags();
+    clear_trapflags();
 
     if (SMR_BA(m, c64dtvflash_mem, 0x200000) < 0 /* hack */
         || SMR_B(m, &c64dtvflash_state) < 0
@@ -141,7 +166,7 @@ static int c64dtv_snapshot_read_rom_module(snapshot_t *s)
 
     /* enable traps again when necessary */
 
-    resources_set_int("VirtualDevices", trapfl);
+    restore_trapflags();
 
     return 0;
 
@@ -149,7 +174,7 @@ fail:
     if (m != NULL) {
         snapshot_module_close(m);
     }
-    resources_set_int("VirtualDevices", trapfl);
+    restore_trapflags();
     return -1;
 }
 
