@@ -122,7 +122,7 @@ void cia1_set_ieee_dir(cia_context_t *cia_context, int isout)
 
 static void do_reset_cia(cia_context_t *cia_context)
 {
-    store_userport_pbx(0xff);
+    store_userport_pbx(0xff, USERPORT_NO_PULSE);
     store_userport_pa2(1);
 }
 
@@ -153,7 +153,7 @@ static void undump_ciapb(cia_context_t *cia_context, CLOCK rclk, uint8_t b)
 
 static void store_ciapb(cia_context_t *cia_context, CLOCK rclk, uint8_t byte)
 {
-    store_userport_pbx(byte);
+    store_userport_pbx(byte, USERPORT_NO_PULSE);
 
     store_userport_pa2(0);
     store_userport_pa2(1);
@@ -187,9 +187,8 @@ static uint8_t read_ciapb(cia_context_t *cia_context)
 {
     uint8_t byte = 0xff;
 
-    byte = read_userport_pbx((uint8_t)~cia_context->c_cia[CIA_DDRB], byte);
+    byte = read_userport_pbx(byte);
 
-    /* The functions below will gradually be removed as the functionality is added to the new userport system. */
     byte &= ((0xff & ~(cia_context->c_cia[CIA_DDRB]))
              | (cia_context->c_cia[CIA_PRB] & cia_context->c_cia[CIA_DDRB]));
     return byte;
@@ -210,7 +209,7 @@ static void store_sdr(cia_context_t *cia_context, uint8_t byte)
 void cia1_init(cia_context_t *cia_context)
 {
     ciacore_init(machine_context.cia1, maincpu_alarm_context,
-                 maincpu_int_status, maincpu_clk_guard);
+                 maincpu_int_status);
 }
 
 void cia1_set_timing(cia_context_t *cia_context, int tickspersec, int powerfreq)
