@@ -29,11 +29,11 @@
 
 extern void cbm2iec_init(void);
 
-# if (defined(DEBUG) || defined(WIN32_COMPILE) || defined(OS2_COMPILE))
+#ifdef DEBUG
 void debug_iec_drv_read(unsigned int data);
 void debug_iec_drv_write(unsigned int data);
 void debug_iec_bus_read(unsigned int data);
 void debug_iec_bus_write(unsigned int data);
-# endif
+#endif
 
 #endif
