@@ -64,11 +64,14 @@
 #define CBMDOS_IPE_BAD_TYPE                64
 #define CBMDOS_IPE_NO_BLOCK                65
 #define CBMDOS_IPE_ILLEGAL_TRACK_OR_SECTOR 66
+#define CBMDOS_IPE_ILLEGAL_SYSTEM_T_OR_S   67  /* 1581 */
 
 #define CBMDOS_IPE_NO_CHANNEL              70
+#define CBMDOS_IPE_DIRECTORY_ERROR         71
 #define CBMDOS_IPE_DISK_FULL               72
 #define CBMDOS_IPE_DOS_VERSION             73
 #define CBMDOS_IPE_NOT_READY               74
+#define CBMDOS_IPE_FORMAT_ERROR            75
 #define CBMDOS_IPE_BAD_PARTN               77  /* 1581 */
 
 #define CBMDOS_IPE_NOT_EMPTY               80  /* dir to remove not empty */
@@ -129,6 +132,31 @@ struct cbmdos_cmd_parse_s {
 };
 typedef struct cbmdos_cmd_parse_s cbmdos_cmd_parse_t;
 
+struct cbmdos_cmd_parse_plus_s {
+    const uint8_t *full; /* input: full dos-command string */
+    unsigned int fulllength; /* input: length of string */
+    unsigned int secondary; /* input */
+    int mode; /* input: decode type, 0=file, 1=command */
+
+    int drive; /* output: drive number */
+    uint8_t *command; /* output: parsed command */
+    unsigned int commandlength; /* command length */
+    uint8_t *abbrv; /* output: parsed abbreviated command */
+    unsigned int abbrvlength; /* abbreviated command length */
+    uint8_t *path; /* output: parsed path */
+    unsigned int pathlength; /* path length */
+    uint8_t *file; /* output: parsed file */
+    unsigned int filelength; /* file length */
+    uint8_t *more; /* output: command to further process */
+    unsigned int morelength; /* length of command to further process */
+
+    /* for file mode */
+    unsigned int readmode; /* output */
+    unsigned int filetype; /* output */
+    unsigned int recordlength; /* output */
+    unsigned int colon; /* output, 0=no colon found, !0=colon found */
+};
+typedef struct cbmdos_cmd_parse_plus_s cbmdos_cmd_parse_plus_t;
 
 extern const char *cbmdos_errortext(unsigned int code);
 extern const char *cbmdos_filetype_get(unsigned int filetype);
@@ -138,5 +166,6 @@ extern unsigned int cbmdos_parse_wildcard_compare(const uint8_t *name1, const ui
 extern uint8_t *cbmdos_dir_slot_create(const char *name, unsigned int len);
 
 extern unsigned int cbmdos_command_parse(cbmdos_cmd_parse_t *cmd_parse);
+extern unsigned int cbmdos_command_parse_plus(cbmdos_cmd_parse_plus_t *cmd_parse);
 
 #endif
