@@ -83,9 +83,6 @@ Revision History:
 #include "maincpu.h"
 #include "snapshot.h"
 
-#ifndef M_PI
-#define M_PI 3.14159265358979323846
-#endif
 
 #define FINAL_SH (0)
 #define MAXOUT   (+32767)
