@@ -49,9 +49,6 @@
 
 */
 
-#ifndef M_PI
-#define M_PI 3.14159265358979323846
-#endif
 
 /* #define T6721DEBUG */
 
