@@ -75,9 +75,11 @@ static cmdline_option_t cmd_drive[] =
 
 int c64exp_cmdline_options_init(void)
 {
-    unsigned int dnr, i;
+    int dnr;
 
     for (dnr = 0; dnr < NUM_DISK_UNITS; dnr++) {
+        int i;
+
         cmd_drive[0].name = lib_msprintf("-parallel%i", dnr + 8);
         cmd_drive[0].resource_name
             = lib_msprintf("Drive%iParallelCable", dnr + 8);
