@@ -29,15 +29,15 @@
 
 #include "types.h"
 
-struct drive_context_s;
+struct diskunit_context_s;
 
 extern int stardos_exp_cmdline_options_init(void);
 
-extern void stardos_exp_init(struct drive_context_s *drv);
-extern void stardos_exp_reset(struct drive_context_s *drv);
+extern void stardos_exp_init(struct diskunit_context_s *drv);
+extern void stardos_exp_reset(struct diskunit_context_s *drv);
 
 extern int stardos_exp_load(const char *name);
 
-extern void stardos_exp_mem_init(struct drive_context_s *drv, unsigned int type);
+extern void stardos_exp_mem_init(struct diskunit_context_s *drv, unsigned int type);
 
 #endif
