@@ -34,7 +34,6 @@
 
 #include "alarm.h"
 #include "attach.h"
-#include "clkguard.h"
 #include "diskimage.h"
 #include "drive-check.h"
 #include "drive.h"
@@ -77,7 +76,7 @@ typedef struct fdc_t {
 
 /*
  * The fdc[] array contains an fdc_t struct for every drive, i.e. two structs
- * for every unit, as each unit could be dual drive. 
+ * for every unit, as each unit could be dual drive.
  */
 static fdc_t fdc[NUM_FDC][2];
 
@@ -490,12 +489,13 @@ static uint8_t fdc_do_job_(unsigned int fnum, int buf,
     file_system_bam_get_disk_id(fnum + 8, drv, disk_id);
 #ifdef FDC_DEBUG
     log_message(fdc_log, "fdc_do_job_: header '%c%c', disk_id '%c%c'",
-	        header[0], header[1], disk_id[0], disk_id[1]);
+        header[0], header[1], disk_id[0], disk_id[1]);
 #endif
 
     switch (job) {
         case 0x80:        /* read */
             if (DOS_IS_90(sysfdc->drive_type)) {
+                rc = FDC_ERR_OK;
                 /* the HD fdc can transfer more than one block */
                 for (i = sysfdc->buffer[0xa0]; i>0; i--) {
                     if (dadr.track > imgfdc->image->tracks) {
@@ -532,26 +532,25 @@ static uint8_t fdc_do_job_(unsigned int fnum, int buf,
                         base = &(sysfdc->buffer[(buf + 1) << 8]);
                     }
                 }
-                rc = FDC_ERR_OK;
-                break;
-            }
-            if (header[0] != disk_id[0] || header[1] != disk_id[1]) {
-#ifdef FDC_DEBUG
-		log_message(fdc_log, "do job read: header '%c%c' != disk_id '%c%c'",
-			header[0], header[1], disk_id[0], disk_id[1]);
-#endif
-                rc = FDC_ERR_ID;
-                break;
-            }
-            ret = disk_image_read_sector(imgfdc->image, sector_data, &dadr);
-            if (ret < 0) {
-                log_error(LOG_DEFAULT,
-                          "Cannot read T:%u S:%u from disk image.",
-                          dadr.track, dadr.sector);
-                rc = FDC_ERR_DRIVE;
             } else {
-                memcpy(base, sector_data, 256);
-                rc = FDC_ERR_OK;
+                if (header[0] != disk_id[0] || header[1] != disk_id[1]) {
+#ifdef FDC_DEBUG
+                    log_message(fdc_log, "do job read: header '%c%c' != disk_id '%c%c'",
+                        header[0], header[1], disk_id[0], disk_id[1]);
+#endif
+                    rc = FDC_ERR_ID;
+                    break;
+                }
+                ret = disk_image_read_sector(imgfdc->image, sector_data, &dadr);
+                if (ret < 0) {
+                    log_error(LOG_DEFAULT,
+                              "Cannot read T:%u S:%u from disk image.",
+                              dadr.track, dadr.sector);
+                    rc = FDC_ERR_DRIVE;
+                } else {
+                    memcpy(base, sector_data, 256);
+                    rc = FDC_ERR_OK;
+                }
             }
             break;
         case 0x90:        /* write */
@@ -560,6 +559,7 @@ static uint8_t fdc_do_job_(unsigned int fnum, int buf,
                     rc = FDC_ERR_WPROT;
                     break;
                 }
+                rc = FDC_ERR_OK;
                 /* the HD fdc can transfer more than one block */
                 for (i = sysfdc->buffer[0xa0]; i>0; i--) {
                     if (dadr.track > imgfdc->image->tracks) {
@@ -595,30 +595,29 @@ static uint8_t fdc_do_job_(unsigned int fnum, int buf,
                         base = &(sysfdc->buffer[(buf + 1) << 8]);
                     }
                 }
-                rc = FDC_ERR_OK;
-                break;
-            }
-            if (header[0] != disk_id[0] || header[1] != disk_id[1]) {
-#ifdef FDC_DEBUG
-		log_message(fdc_log, "do job write: header '%c%c' != disk_id '%c%c'",
-			header[0], header[1], disk_id[0], disk_id[1]);
-#endif
-                rc = FDC_ERR_ID;
-                break;
-            }
-            if (imgfdc->image->read_only) {
-                rc = FDC_ERR_WPROT;
-                break;
-            }
-            memcpy(sector_data, base, 256);
-            ret = disk_image_write_sector(imgfdc->image, sector_data, &dadr);
-            if (ret < 0) {
-                log_error(LOG_DEFAULT,
-                          "Could not update T:%u S:%u on disk image.",
-                          dadr.track, dadr.sector);
-                rc = FDC_ERR_DRIVE;
             } else {
-                rc = FDC_ERR_OK;
+                if (header[0] != disk_id[0] || header[1] != disk_id[1]) {
+#ifdef FDC_DEBUG
+                    log_message(fdc_log, "do job write: header '%c%c' != disk_id '%c%c'",
+                        header[0], header[1], disk_id[0], disk_id[1]);
+#endif
+                    rc = FDC_ERR_ID;
+                    break;
+                }
+                if (imgfdc->image->read_only) {
+                    rc = FDC_ERR_WPROT;
+                    break;
+                }
+                memcpy(sector_data, base, 256);
+                ret = disk_image_write_sector(imgfdc->image, sector_data, &dadr);
+                if (ret < 0) {
+                    log_error(LOG_DEFAULT,
+                              "Could not update T:%u S:%u on disk image.",
+                              dadr.track, dadr.sector);
+                    rc = FDC_ERR_DRIVE;
+                } else {
+                    rc = FDC_ERR_OK;
+                }
             }
             break;
         case 0xA0:        /* verify */
@@ -629,8 +628,8 @@ static uint8_t fdc_do_job_(unsigned int fnum, int buf,
             }
             if (header[0] != disk_id[0] || header[1] != disk_id[1]) {
 #ifdef FDC_DEBUG
-		log_message(fdc_log, "do job verify: header '%c%c' != disk_id '%c%c'",
-			header[0], header[1], disk_id[0], disk_id[1]);
+                log_message(fdc_log, "do job verify: header '%c%c' != disk_id '%c%c'",
+                    header[0], header[1], disk_id[0], disk_id[1]);
 #endif
                 rc = FDC_ERR_ID;
                 break;
@@ -658,8 +657,8 @@ static uint8_t fdc_do_job_(unsigned int fnum, int buf,
             break;
         case 0xB0:        /* seek - move to track and read ID(?) */
 #ifdef FDC_DEBUG
-		log_message(fdc_log, "do job seek: header was '%c%c' becomes disk_id '%c%c'",
-			header[0], header[1], disk_id[0], disk_id[1]);
+                log_message(fdc_log, "do job seek: header was '%c%c' becomes disk_id '%c%c'",
+                    header[0], header[1], disk_id[0], disk_id[1]);
 #endif
             header[0] = disk_id[0];
             header[1] = disk_id[1];
@@ -722,8 +721,8 @@ static uint8_t fdc_do_job_(unsigned int fnum, int buf,
         case 0xF0:
             if (header[0] != disk_id[0] || header[1] != disk_id[1]) {
 #ifdef FDC_DEBUG
-		log_message(fdc_log, "do job F0: header '%c%c' != disk_id '%c%c'",
-			header[0], header[1], disk_id[0], disk_id[1]);
+                log_message(fdc_log, "do job F0: header '%c%c' != disk_id '%c%c'",
+                    header[0], header[1], disk_id[0], disk_id[1]);
 #endif
                 rc = FDC_ERR_ID;
                 break;
@@ -948,21 +947,6 @@ static void int_fdc(CLOCK offset, void *data)
     alarm_set(sysfdc->fdc_alarm, sysfdc->alarm_clk);
 }
 
-static void clk_overflow_callback(CLOCK sub, void *data)
-{
-    unsigned int fnum = vice_ptr_to_uint(data);
-
-    fdc_t *sysfdc = &fdc[fnum][0];
-
-    if (sysfdc->fdc_state != FDC_UNUSED) {
-        if (sysfdc->alarm_clk > sub) {
-            sysfdc->alarm_clk -= sub;
-        } else {
-            sysfdc->alarm_clk = 0;
-        }
-    }
-}
-
 /* FIXME: hack, because 0x4000 is only ok for 1001/8050/8250.
    fdc.c:fdc_do_job() adds an offset for 2040/3040/4040 by itself :-(
    Why donlly get a table for that...! */
@@ -995,9 +979,6 @@ void fdc_init(diskunit_context_t *drv)
     sysfdc->fdc_alarm = alarm_new(drv->cpu->alarm_context, buffer, int_fdc,
                                     drv);
     lib_free(buffer);
-
-    clk_guard_add_callback(drv->cpu->clk_guard, clk_overflow_callback,
-                           uint_to_void_ptr(drv->mynumber));
 }
 
 /************************************************************************/
