@@ -29,14 +29,14 @@
 
 #include "types.h"
 
-struct drive_context_s;
+struct diskunit_context_s;
 
-extern uint8_t glue1551_port0_read(struct drive_context_s *drv);
-extern uint8_t glue1551_port1_read(struct drive_context_s *drv);
-extern void glue1551_port0_store(struct drive_context_s *drv, uint8_t value);
-extern void glue1551_port1_store(struct drive_context_s *drv, uint8_t value);
+extern uint8_t glue1551_port0_read(struct diskunit_context_s *drv);
+extern uint8_t glue1551_port1_read(struct diskunit_context_s *drv);
+extern void glue1551_port0_store(struct diskunit_context_s *drv, uint8_t value);
+extern void glue1551_port1_store(struct diskunit_context_s *drv, uint8_t value);
 
-extern void glue1551_init(struct drive_context_s *drv);
-extern void glue1551_reset(struct drive_context_s *drv);
+extern void glue1551_init(struct diskunit_context_s *drv);
+extern void glue1551_reset(struct diskunit_context_s *drv);
 
 #endif
