@@ -34,22 +34,22 @@
 #include "types.h"
 
 
-static uint8_t drive_read_rom(drive_context_t *drv, uint16_t address)
+static uint8_t drive_read_rom(diskunit_context_t *drv, uint16_t address)
 {
-    return drv->drive->rom[address & 0x7fff];
+    return drv->rom[address & 0x7fff];
 }
 
-static uint8_t drive_read_1551ram(drive_context_t *drv, uint16_t address)
+static uint8_t drive_read_1551ram(diskunit_context_t *drv, uint16_t address)
 {
-    return drv->drive->drive_ram[address & 0x7ff];
+    return drv->drive_ram[address & 0x7ff];
 }
 
-static void drive_store_1551ram(drive_context_t *drv, uint16_t address, uint8_t value)
+static void drive_store_1551ram(diskunit_context_t *drv, uint16_t address, uint8_t value)
 {
-    drv->drive->drive_ram[address & 0x7ff] = value;
+    drv->drive_ram[address & 0x7ff] = value;
 }
 
-static uint8_t drive_read_zero(drive_context_t *drv, uint16_t address)
+static uint8_t drive_read_zero(diskunit_context_t *drv, uint16_t address)
 {
     switch (address & 0xff) {
         case 0:
@@ -58,10 +58,10 @@ static uint8_t drive_read_zero(drive_context_t *drv, uint16_t address)
             return glue1551_port1_read(drv);
     }
 
-    return drv->drive->drive_ram[address & 0xff];
+    return drv->drive_ram[address & 0xff];
 }
 
-static void drive_store_zero(drive_context_t *drv, uint16_t address, uint8_t value)
+static void drive_store_zero(diskunit_context_t *drv, uint16_t address, uint8_t value)
 {
     switch (address & 0xff) {
         case 0:
@@ -72,20 +72,20 @@ static void drive_store_zero(drive_context_t *drv, uint16_t address, uint8_t val
             return;
     }
 
-    drv->drive->drive_ram[address & 0xff] = value;
+    drv->drive_ram[address & 0xff] = value;
 }
 
-void mem1551_init(struct drive_context_s *drv, unsigned int type)
+void mem1551_init(struct diskunit_context_s *drv, unsigned int type)
 {
     drivecpud_context_t *cpud = drv->cpud;
 
     switch (type) {
     case DRIVE_TYPE_1551:
-        drv->cpu->pageone = drv->drive->drive_ram + 0x100;
-        drivemem_set_func(cpud, 0x00, 0x01, drive_read_zero, drive_store_zero, NULL, drv->drive->drive_ram, 0x000207fd);
-        drivemem_set_func(cpud, 0x01, 0x08, drive_read_1551ram, drive_store_1551ram, NULL, &drv->drive->drive_ram[0x0100], 0x000207fd);
+        drv->cpu->pageone = drv->drive_ram + 0x100;
+        drivemem_set_func(cpud, 0x00, 0x01, drive_read_zero, drive_store_zero, NULL, drv->drive_ram, 0x000207fd);
+        drivemem_set_func(cpud, 0x01, 0x08, drive_read_1551ram, drive_store_1551ram, NULL, &drv->drive_ram[0x0100], 0x000207fd);
         drivemem_set_func(cpud, 0x40, 0x80, tpid_read, tpid_store, tpid_peek, NULL, 0);
-        drivemem_set_func(cpud, 0xc0, 0x100, drive_read_rom, NULL, NULL, &drv->drive->trap_rom[0x4000], 0xc000fffd);
+        drivemem_set_func(cpud, 0xc0, 0x100, drive_read_rom, NULL, NULL, &drv->trap_rom[0x4000], 0xc000fffd);
         break;
     default:
         break;
