@@ -29,15 +29,15 @@
 
 #include "types.h"
 
-struct drive_context_s;
+struct diskunit_context_s;
 struct tpi_context_s;
 
-extern void tpid_setup_context(struct drive_context_s *ctxptr);
+extern void tpid_setup_context(struct diskunit_context_s *ctxptr);
 
-extern void tpid_init(struct drive_context_s *ctxptr);
-extern void tpid_store(struct drive_context_s *ctxptr, uint16_t addr, uint8_t byte);
-extern uint8_t tpid_read(struct drive_context_s *ctxptr, uint16_t addr);
-extern uint8_t tpid_peek(struct drive_context_s *ctxptr, uint16_t addr);
-extern int tpid_dump(drive_context_t *ctxptr, uint16_t addr);
+extern void tpid_init(struct diskunit_context_s *ctxptr);
+extern void tpid_store(struct diskunit_context_s *ctxptr, uint16_t addr, uint8_t byte);
+extern uint8_t tpid_read(struct diskunit_context_s *ctxptr, uint16_t addr);
+extern uint8_t tpid_peek(struct diskunit_context_s *ctxptr, uint16_t addr);
+extern int tpid_dump(diskunit_context_t *ctxptr, uint16_t addr);
 
 #endif
