@@ -45,5 +45,7 @@ extern unsigned int cbmfile_rename(const char *src_name, const char *dst_name,
                                    const char *path);
 extern unsigned int cbmfile_scratch(const char *file_name, const char *path);
 extern unsigned int cbmfile_get_bytes_left(struct fileio_info_s *info);
+extern unsigned int cbmfile_seek(struct fileio_info_s *info, off_t offset, int whence);
+extern unsigned int cbmfile_tell(struct fileio_info_s *info);
 
 #endif
