@@ -68,7 +68,7 @@ static gfxoutputdrv_codec_t avi_audio_codeclist[] = {
 
 static gfxoutputdrv_codec_t mp4_audio_codeclist[] = {
     { AV_CODEC_ID_AAC, "AAC" },
-    { AV_CODEC_ID_MP3, "MP3" },    
+    { AV_CODEC_ID_MP3, "MP3" },
     { AV_CODEC_ID_AC3, "AC3" },
     { 0, NULL }
 };
@@ -111,8 +111,8 @@ gfxoutputdrv_format_t formats_to_test[] =
 {
     { "mp4", mp4_audio_codeclist, mp4_video_codeclist },
     { "ogg", ogg_audio_codeclist, ogg_video_codeclist },
-    { "avi", avi_audio_codeclist, avi_video_codeclist },    
-    { "matroska", mp4_audio_codeclist, mp4_video_codeclist },    
+    { "avi", avi_audio_codeclist, avi_video_codeclist },
+    { "matroska", mp4_audio_codeclist, mp4_video_codeclist },
     { "wav", NULL, NULL },
     { "mp3", NULL, none_codeclist }, /* formats expects png which fails in VICE */
     { "mp2", NULL, NULL },
@@ -172,12 +172,10 @@ static int set_container_format(const char *val, void *param)
 {
     int i;
 
-/* kludges to prevent crash at startup when using --help on the commandline */
-#ifndef STATIC_FFMPEG
+    /* kludge to prevent crash at startup when using --help on the commandline */
     if (ffmpegdrv_formatlist == NULL) {
         return 0;
     }
-#endif
 
     format_index = -1;
 
@@ -318,7 +316,7 @@ static void close_stream(OutputStream *ost)
 /* audio stream encoding */
 /*-----------------------*/
 
-static AVFrame *alloc_audio_frame(enum AVSampleFormat sample_fmt, 
+static AVFrame *alloc_audio_frame(enum AVSampleFormat sample_fmt,
     uint64_t channel_layout,
     int sample_rate, int nb_samples)
 {
@@ -740,10 +738,10 @@ static void ffmpegdrv_init_video(screenshot_t *screenshot)
     video_width = c->width = screenshot->width & ~0xf;
     video_height = c->height = screenshot->height & ~0xf;
     /* frames per second */
-    st->time_base = VICE_P_AV_D2Q(machine_get_cycles_per_frame() 
-                                    / (double)(video_halve_framerate ? 
+    st->time_base = VICE_P_AV_D2Q(machine_get_cycles_per_frame()
+                                    / (double)(video_halve_framerate ?
                                         machine_get_cycles_per_second() / 2 :
-                                        machine_get_cycles_per_second()), 
+                                        machine_get_cycles_per_second()),
                                   (1 << 16) - 1);
     c->time_base = st->time_base;
 
@@ -957,11 +955,7 @@ static int ffmpegdrv_record(screenshot_t *screenshot)
 
         if (sws_ctx != NULL) {
             VICE_P_SWS_SCALE(sws_ctx,
-#if defined(STATIC_FFMPEG) || defined(SHARED_FFMPEG)
-                (const uint8_t * const *)video_st.tmp_frame->data,
-#else
                 video_st.tmp_frame->data,
-#endif
                 video_st.tmp_frame->linesize, 0, c->height,
                 video_st.frame->data, video_st.frame->linesize);
         }
@@ -1118,12 +1112,10 @@ static void ffmpeg_get_formats_and_codecs(void)
 
 void gfxoutput_init_ffmpeg(int help)
 {
-#ifndef STATIC_FFMPEG
     if (help) {
         gfxoutput_register(&ffmpeg_drv);
         return;
     }
-#endif
 
     if (ffmpeglib_open(&ffmpeglib) < 0) {
         return;
