@@ -6,7 +6,7 @@
 
 /*
  *  HVSClib - a library to work with High Voltage SID Collection files
- *  Copyright (C) 2018-2021  Bas Wassink <b.wassink@ziggo.nl>
+ *  Copyright (C) 2018-2022  Bas Wassink <b.wassink@ziggo.nl>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,15 +23,21 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.*
  */
 
+#ifndef HVSC_STANDALONE
+# include "vice.h"
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
+#include <stdbool.h>
 #include <inttypes.h>
 #include <string.h>
 #include <ctype.h>
-#include "log.h"
 
+#ifndef HVSC_STANDALONE
+# include "log.h"
+#endif
 #include "hvsc.h"
-
 #include "hvsc_defs.h"
 #include "base.h"
 
@@ -53,7 +59,7 @@ static hvsc_stil_field_t *  stil_field_dup(const hvsc_stil_field_t *field);
 static void                 stil_block_init(hvsc_stil_block_t *block);
 static hvsc_stil_block_t *  stil_block_new(void);
 static void                 stil_block_free(hvsc_stil_block_t *block);
-static int                  stil_block_add_field(hvsc_stil_block_t *block,
+static void                 stil_block_add_field(hvsc_stil_block_t *block,
                                                  hvsc_stil_field_t *field);
 static hvsc_stil_block_t *  stil_block_dup(const hvsc_stil_block_t *block);
 
@@ -200,28 +206,15 @@ static hvsc_stil_field_t *stil_field_new(int type,
                                          long ts_from, long ts_to,
                                          const char *album, size_t alen)
 {
-    hvsc_stil_field_t *field = malloc(sizeof *field);
-
-    if (field == NULL) {
-        hvsc_errno = HVSC_ERR_OOM;
-    } else {
-        stil_field_init(field);
-        field->type = type;
-        field->timestamp.from = ts_from;
-        field->timestamp.to = ts_to;
-        field->text = hvsc_strndup(text, tlen);
-        if (field->text == NULL) {
-            stil_field_free(field);
-            return NULL;
-        }
-        if (album != NULL && *album != '\0') {
-            field->album = hvsc_strndup(album, alen);
-            if (field->album == NULL) {
-                stil_field_free(field);
-                return NULL;
-            }
-        }
+    hvsc_stil_field_t *field = hvsc_malloc(sizeof *field);
 
+    stil_field_init(field);
+    field->type = type;
+    field->timestamp.from = ts_from;
+    field->timestamp.to = ts_to;
+    field->text = hvsc_strndup(text, tlen);
+    if (album != NULL && *album != '\0') {
+        field->album = hvsc_strndup(album, alen);
     }
     return field;
 }
@@ -234,12 +227,12 @@ static hvsc_stil_field_t *stil_field_new(int type,
 static void stil_field_free(hvsc_stil_field_t *field)
 {
     if (field->text != NULL) {
-        free(field->text);
+        hvsc_free(field->text);
     }
     if (field->album != NULL) {
-        free(field->album);
+        hvsc_free(field->album);
     }
-    free(field);
+    hvsc_free(field);
 }
 
 
@@ -271,19 +264,10 @@ static hvsc_stil_block_t *stil_block_new(void)
     hvsc_stil_block_t *block;
     size_t i;
 
-    block = malloc(sizeof *block);
-    if (block == NULL) {
-        hvsc_errno = HVSC_ERR_OOM;
-        return NULL;
-    }
+    block = hvsc_malloc(sizeof *block);
     stil_block_init(block);
 
-    block->fields = malloc(HVSC_STIL_BLOCK_FIELDS_INIT * sizeof *(block->fields));
-    if (block->fields == NULL) {
-        hvsc_errno = HVSC_ERR_OOM;
-        stil_block_free(block);
-        return NULL;
-    }
+    block->fields = hvsc_malloc(HVSC_STIL_BLOCK_FIELDS_INIT * sizeof *(block->fields));
     block->fields_max = HVSC_STIL_BLOCK_FIELDS_INIT;
     for (i = 0; i < HVSC_STIL_BLOCK_FIELDS_INIT; i++) {
         block->fields[i] = NULL;
@@ -296,7 +280,7 @@ static hvsc_stil_block_t *stil_block_new(void)
  *
  * \param[in]   field   STIL field
  *
- * \return  copy of \a field or `NULL` on error
+ * \return  copy of \a field
  */
 static hvsc_stil_field_t *stil_field_dup(const hvsc_stil_field_t *field)
 {
@@ -310,29 +294,22 @@ static hvsc_stil_field_t *stil_field_dup(const hvsc_stil_field_t *field)
  *
  * \param[in]   block   STIL block
  *
- * \return  copy of \a block or `NULL` or error
+ * \return  copy of \a block
  */
 static hvsc_stil_block_t *stil_block_dup(const hvsc_stil_block_t *block)
 {
     hvsc_stil_block_t *copy;
     size_t i;
 
-    copy = malloc(sizeof *copy);
-    if (copy == NULL) {
-        return 0;
-    }
+    copy = hvsc_malloc(sizeof *copy);
     stil_block_init(copy);
 
     copy->tune = block->tune;
     copy->fields_max = block->fields_max;
     copy->fields_used = block->fields_used;
-    copy->fields = malloc(block->fields_max * sizeof *(copy->fields));
+    copy->fields = hvsc_malloc(block->fields_max * sizeof *(copy->fields));
     for (i = 0; i < copy->fields_used; i++) {
         copy->fields[i] = stil_field_dup(block->fields[i]);
-        if (copy->fields[i] == NULL) {
-            stil_block_free(copy);
-            return 0;
-        }
     }
     return copy;
 }
@@ -349,8 +326,8 @@ static void stil_block_free(hvsc_stil_block_t *block)
     for (i = 0; i < block->fields_used; i++) {
         stil_field_free(block->fields[i]);
     }
-    free(block->fields);
-    free(block);
+    hvsc_free(block->fields);
+    hvsc_free(block);
 }
 
 
@@ -358,10 +335,8 @@ static void stil_block_free(hvsc_stil_block_t *block)
  *
  * \param[in,out]   block   STIL block
  * \param[in]       field   STIL field
- *
- * \return  bool
  */
-static int stil_block_add_field(hvsc_stil_block_t *block,
+static void stil_block_add_field(hvsc_stil_block_t *block,
                                  hvsc_stil_field_t *field)
 {
     hvsc_dbg("max = %" PRI_SIZE_T ", used = %" PRI_SIZE_T "\n",
@@ -369,24 +344,14 @@ static int stil_block_add_field(hvsc_stil_block_t *block,
     /* do we need to resize the array? */
     if (block->fields_max == block->fields_used) {
         /* yep */
-        hvsc_stil_field_t **tmp;
-
-        tmp = realloc(block->fields,
-                block->fields_max * 2 * sizeof *(block->fields));
-        if (tmp == NULL) {
-            hvsc_errno = HVSC_ERR_OOM;
-            return 0;
-        }
-        block->fields = tmp;
         block->fields_max *= 2;
+        block->fields = hvsc_realloc(block->fields,
+                                     block->fields_max * sizeof *(block->fields));
     }
     block->fields[block->fields_used++] = field;
-    return 1;
 }
 
 
-
-
 /** \brief  Initialize STIL \a handle for use
  *
  * \param[in,out]   handle  STIL handle
@@ -410,24 +375,17 @@ static void stil_init_handle(hvsc_stil_t *handle)
  * All block pointers are initialized to `NULL`
  *
  * \param[in,out]   handle  STIL handle
- *
- * \return  bool
  */
-static int stil_handle_init_blocks(hvsc_stil_t *handle)
+static void stil_handle_init_blocks(hvsc_stil_t *handle)
 {
     size_t i;
 
-    handle->blocks = malloc(HVSC_HANDLE_BLOCKS_INIT * sizeof *(handle->blocks));
-    if (handle->blocks == NULL) {
-        hvsc_errno = HVSC_ERR_OOM;
-        return 0;
-    }
+    handle->blocks = hvsc_malloc(HVSC_HANDLE_BLOCKS_INIT * sizeof *(handle->blocks));
     for (i = 0; i < HVSC_HANDLE_BLOCKS_INIT; i++) {
         handle->blocks[i] = NULL;
     }
     handle->blocks_used = 0;
     handle->blocks_max = HVSC_HANDLE_BLOCKS_INIT;
-    return 1;
 }
 
 
@@ -443,7 +401,7 @@ static void stil_handle_free_blocks(hvsc_stil_t *handle)
         for (i = 0; i < handle->blocks_used; i++) {
             stil_block_free(handle->blocks[i]);
         }
-        free(handle->blocks);
+        hvsc_free(handle->blocks);
         handle->blocks = NULL;
     }
 }
@@ -453,39 +411,21 @@ static void stil_handle_free_blocks(hvsc_stil_t *handle)
  *
  * \param[in,out]   handle  STIL handle
  * \param[in]       block   STIL block
- *
- * \return  bool
  */
-static int stil_handle_add_block(hvsc_stil_t *handle, hvsc_stil_block_t *block)
+static void stil_handle_add_block(hvsc_stil_t *handle, hvsc_stil_block_t *block)
 {
-    hvsc_stil_block_t *copy;
-
     /* do we need to resize the array? */
     if (handle->blocks_max == handle->blocks_used) {
         /* yep */
-        hvsc_stil_block_t **tmp;
-
-        tmp = realloc(handle->blocks,
-                handle->blocks_max * 2 * sizeof *(handle->blocks));
-        if (tmp == NULL) {
-            hvsc_errno = HVSC_ERR_OOM;
-            return 0;
-        }
-        handle->blocks = tmp;
         handle->blocks_max *= 2;
+        handle->blocks = hvsc_realloc(handle->blocks,
+                                      handle->blocks_max * sizeof *(handle->blocks));
     }
-
     /* make a copy */
-    copy = stil_block_dup(block);
-    if (copy == NULL) {
-        return 0;
-    }
-    handle->blocks[handle->blocks_used++] = copy;
-    return 1;
+    handle->blocks[handle->blocks_used++] = stil_block_dup(block);
 }
 
 
-
 /** \brief  Open STIL and look for PSID file \a psid
  *
  * \param[in]       psid    path to PSID file
@@ -493,69 +433,60 @@ static int stil_handle_add_block(hvsc_stil_t *handle, hvsc_stil_block_t *block)
  *
  * \return  bool
  */
-int hvsc_stil_open(const char *psid, hvsc_stil_t *handle)
+bool hvsc_stil_open(const char *psid, hvsc_stil_t *handle)
 {
     const char *line;
 
     stil_init_handle(handle);
 
-    handle->entry_buffer = malloc(HVSC_STIL_BUFFER_INIT *
-            sizeof *(handle->entry_buffer));
-    if (handle->entry_buffer == NULL) {
-        hvsc_errno = HVSC_ERR_OOM;
-        return 0;
-    }
+    handle->entry_buffer = hvsc_malloc(HVSC_STIL_BUFFER_INIT *
+                                       sizeof *(handle->entry_buffer));
     handle->entry_bufmax = HVSC_STIL_BUFFER_INIT;
     handle->entry_bufused = 0;
 
+#ifndef HVSC_STANDALONE
     log_message(LOG_DEFAULT, "Vsid: Opening '%s'.", hvsc_stil_path);
+#endif
     if (!hvsc_text_file_open(hvsc_stil_path, &(handle->stil))) {
+#ifndef HVSC_STANDALONE
         log_warning(LOG_DEFAULT, "Vsid: Failed to open STIL.");
+#endif
         hvsc_stil_close(handle);
-        return 0;
+        return false;
     }
 
-
     /* make copy of psid, ripping off the HVSC root directory */
     handle->psid_path = hvsc_path_strip_root(psid);
-#if defined(_WIN32) || defined(_WIN64)
+#ifdef WINDOWS_COMPILE
     /* fix directory separators */
     hvsc_path_fix_separators(handle->psid_path);
 #endif
-
     hvsc_dbg("stripped path is '%s'\n", handle->psid_path);
-    if (handle->psid_path == NULL) {
-        hvsc_stil_close(handle);
-        return 0;
-    }
 
     /* find the entry */
-    while (1) {
+    while (true) {
         line = hvsc_text_file_read(&(handle->stil));
         if (line == NULL) {
             if (feof(handle->stil.fp)) {
                 /* EOF, so simply not found */
                 hvsc_errno = HVSC_ERR_NOT_FOUND;
+#ifndef HVSC_STANDALONE
                 log_message(LOG_DEFAULT, "Vsid: No STIL entry found.");
+#endif
             }
             hvsc_stil_close(handle);
             /* I/O error is already set */
-            return 0;
+            return false;
         }
 
         if (strcmp(line, handle->psid_path) == 0) {
+#ifndef HVSC_STANDALONE
             log_message(LOG_DEFAULT,
                     "Vsid: Found '%s' at line %ld.", line, handle->stil.lineno);
-            return 1;
+#endif
+            return true;
         }
     }
-
-#if 0 /* above loop never breaks - following code can never execute */
-    /* not found */
-    hvsc_errno = HVSC_ERR_NOT_FOUND;
-    hvsc_stil_close(handle);
-    return 1;
-#endif
 }
 
 
@@ -568,18 +499,18 @@ int hvsc_stil_open(const char *psid, hvsc_stil_t *handle)
 void hvsc_stil_close(hvsc_stil_t *handle)
 {
     hvsc_text_file_close(&(handle->stil));
-    free(handle->psid_path);
+    hvsc_free(handle->psid_path);
 
     if (handle->entry_buffer != NULL) {
         size_t i;
         for (i = 0; i < handle->entry_bufused; i++){
-            free(handle->entry_buffer[i]);
+            hvsc_free(handle->entry_buffer[i]);
         }
-        free(handle->entry_buffer);
+        hvsc_free(handle->entry_buffer);
     }
 
     if (handle->sid_comment != NULL) {
-        free(handle->sid_comment);
+        hvsc_free(handle->sid_comment);
     }
     if (handle->blocks != NULL) {
         stil_handle_free_blocks(handle);
@@ -596,31 +527,16 @@ void hvsc_stil_close(hvsc_stil_t *handle)
  *
  * \return  bool
  */
-static int hvsc_stil_entry_add_line(hvsc_stil_t *handle, const char *line)
+static void hvsc_stil_entry_add_line(hvsc_stil_t *handle, const char *line)
 {
-    char **buffer;
-    char *tmp;
-
     if (handle->entry_bufmax == handle->entry_bufused) {
-        hvsc_dbg("resizing line buffer to %" PRI_SIZE_T " entries\n",
-                handle->entry_bufmax * 2);
-        buffer = realloc(handle->entry_buffer,
-                (handle->entry_bufmax * 2) * sizeof *(handle->entry_buffer));
-        if (buffer == NULL) {
-            hvsc_errno = HVSC_ERR_OOM;
-            return 0;
-        }
-        handle->entry_buffer = buffer;
         handle->entry_bufmax *= 2;
+        hvsc_dbg("resizing line buffer to %" PRI_SIZE_T " entries\n",
+                  handle->entry_bufmax);
+        handle->entry_buffer = hvsc_realloc(handle->entry_buffer,
+                handle->entry_bufmax * sizeof *(handle->entry_buffer));
     }
-
-    tmp = hvsc_strdup(line);
-    if (tmp == NULL) {
-        return 0;
-    }
-
-    handle->entry_buffer[handle->entry_bufused++] = tmp;
-    return 1;
+    handle->entry_buffer[handle->entry_bufused++] = hvsc_strdup(line);
 }
 
 
@@ -632,33 +548,30 @@ static int hvsc_stil_entry_add_line(hvsc_stil_t *handle, const char *line)
  *
  * \return  bool
  */
-int hvsc_stil_read_entry(hvsc_stil_t *handle)
+bool hvsc_stil_read_entry(hvsc_stil_t *handle)
 {
     const char *line;
 
-
-    while (1) {
+    while (true) {
         line = hvsc_text_file_read(&(handle->stil));
         if (line == NULL) {
             /* EOF ? */
             if (feof(handle->stil.fp)) {
                 /* EOF, so end of entry */
-                return 1;
+                return true;
             }
             /* I/O error is already set */
-            return 0;
+            return false;
         }
 
         /* check for end of entry */
         if (hvsc_string_is_empty(line)) {
             hvsc_dbg("got empty line -> end-of-entry\n");
-            return 1;
+            return true;
         }
 
         hvsc_dbg("line %ld: '%s'\n", handle->stil.lineno, line);
-        if (!hvsc_stil_entry_add_line(handle, line)) {
-            return 0;
-        }
+        hvsc_stil_entry_add_line(handle, line);
     }
 }
 
@@ -691,22 +604,17 @@ void hvsc_stil_dump_entry(hvsc_stil_t *handle)
  *
  * \param[in]   state   parser state
  *
- * \return  comment, or `NULL` on failure
+ * \return  comment
  */
 static char *stil_parse_comment(hvsc_stil_parser_state_t *state)
 {
     char *comment;
-    char *tmp;
     size_t len;     /* len per line, excluding '\0' */
     size_t total;   /* total line of comment, excluding '\0' */
     const char *line = state->handle->entry_buffer[state->lineno];
 
     /* first line is 'COMMENT: <text>' */
     comment = hvsc_strdup(line + 9);
-    if (comment == NULL) {
-        /* error */
-        return NULL;
-    }
     total = strlen(line) - 9;
     state->lineno++;
 
@@ -718,21 +626,13 @@ static char *stil_parse_comment(hvsc_stil_parser_state_t *state)
             return comment;
         }
         /* realloc to add new line */
-        tmp = realloc(comment, total + len - 8 + 1);
-        if (tmp == NULL) {
-            hvsc_errno = HVSC_ERR_OOM;
-            free(comment);
-            return NULL;
-        }
-        comment = tmp;
+        comment = hvsc_realloc(comment, total + len - 8 + 1);
         /* add line to comment, adding a space from the nine spaces indent to
          * get a proper separating space in the final comment text */
         memcpy(comment + total, line + 8, len - 8 + 1);
         total += (len - 8);
-
         state->lineno++;
     }
-
     return comment;
 }
 
@@ -744,10 +644,8 @@ static char *stil_parse_comment(hvsc_stil_parser_state_t *state)
  *
  * \param[in,out]   parser  STIL parser state
  * \param[in]       handle  STIL handle
- *
- * \return  bool
  */
-static int stil_parser_init(hvsc_stil_parser_state_t *parser,
+static void stil_parser_init(hvsc_stil_parser_state_t *parser,
                              hvsc_stil_t *handle)
 {
     parser->handle = handle;
@@ -762,10 +660,6 @@ static int stil_parser_init(hvsc_stil_parser_state_t *parser,
 
     /* add block for tune #1 */
     parser->block = stil_block_new();
-    if (parser->block == NULL) {
-        return 0;
-    }
-    return 1;
 }
 
 
@@ -783,7 +677,7 @@ static void stil_parser_free(hvsc_stil_parser_state_t *parser)
         stil_block_free(parser->block);
     }
     if (parser->album != NULL) {
-        free(parser->album);
+        hvsc_free(parser->album);
         parser->album = NULL;
     }
 }
@@ -795,23 +689,17 @@ static void stil_parser_free(hvsc_stil_parser_state_t *parser)
  *
  * \param[in,out]   handle  STIL entry handle
  *
- * \return  bool
- *
  * \todo    Refactor, this function is too long and complex
  */
-int hvsc_stil_parse_entry(hvsc_stil_t *handle)
+void hvsc_stil_parse_entry(hvsc_stil_t *handle)
 {
     hvsc_stil_parser_state_t state;
 
     /* init parser state */
-    if (!stil_parser_init(&state, handle)) {
-        return 0;
-    }
+    stil_parser_init(&state, handle);
 
     /* allocate array for STIL blocks */
-    if (!stil_handle_init_blocks(handle)) {
-        return 0;
-    }
+    stil_handle_init_blocks(handle);
 
     while (state.lineno < state.handle->entry_bufused) {
         char *line = handle->entry_buffer[state.lineno];
@@ -841,14 +729,9 @@ int hvsc_stil_parse_entry(hvsc_stil_t *handle)
              * have a block)
              */
             if (state.tune > 1) {
-                if (!stil_handle_add_block(state.handle, state.block)) {
-                    return 0;
-                }
+                stil_handle_add_block(state.handle, state.block);
                 stil_block_free(state.block);
                 state.block = stil_block_new();
-                if (state.block == NULL) {
-                    return 0;
-                }
                 state.block->tune = num;
             }
 
@@ -865,9 +748,6 @@ int hvsc_stil_parse_entry(hvsc_stil_t *handle)
                 /* COMMENT: field */
                 case HVSC_FIELD_COMMENT:
                     comment = stil_parse_comment(&state);
-                    if (comment == NULL) {
-                        return 0;
-                    }
                     if (state.tune == 0) {
                         /* SID-wide comment */
                         state.handle->sid_comment = comment;
@@ -927,13 +807,6 @@ int hvsc_stil_parse_entry(hvsc_stil_t *handle)
                         char *album;
                         hvsc_dbg("found possible album\n");
 
-                        /*
-                         * stil_parse_album() can return NULL on OOM, so set
-                         * err code to 0 here to catch it later
-                         * (Yes, I know, it's a design flaw, I'll fix that)
-                         */
-                        hvsc_errno = 0;
-
                         album = stil_parse_album(line, state.linelen);
                         if (album != NULL) {
                             hvsc_dbg("got album: '%s'\n", album);
@@ -942,11 +815,8 @@ int hvsc_stil_parse_entry(hvsc_stil_t *handle)
 
                             /* adjust line len (+3 for '[', ']' and space */
                             state.linelen -= (state.album_len + 3);
-                        } else if (hvsc_errno != 0) {
-                            return 0;
                         }
                     }
-
                     break;
 
                 /* Other fields without special meaning/sub fields */
@@ -974,24 +844,16 @@ int hvsc_stil_parse_entry(hvsc_stil_t *handle)
                         line, state.linelen,
                         state.ts.from, state.ts.to,
                         state.album, state.album_len);
-                if (state.field == NULL) {
-                    hvsc_dbg("failed to allocate field object\n");
-                    return 0;
-                }
-                if (!stil_block_add_field(state.block, state.field)) {
-                    hvsc_dbg("failed to add field to block\n");
-                    free(state.field);
-                    return 0;
-                }
+                stil_block_add_field(state.block, state.field);
 
                 /* if the line was a comment, free the comment */
                 if (type == HVSC_FIELD_COMMENT) {
-                    free(comment);
+                    hvsc_free(comment);
                     comment = NULL;
                 }
                 /* free album, if present */
                 if (state.album != NULL) {
-                    free(state.album);
+                    hvsc_free(state.album);
                     state.album = NULL;
                 }
             } else {
@@ -1005,16 +867,12 @@ int hvsc_stil_parse_entry(hvsc_stil_t *handle)
     }
 
     /* add last block */
-    if (!stil_handle_add_block(state.handle, state.block)) {
-        return 0;
-    }
+    stil_handle_add_block(state.handle, state.block);
 
     stil_parser_free(&state);
-    return 1;
 }
 
 
-
 /** \brief  Temp: dump parsed entries
  *
  * \param[in]   handle  STIL handle
@@ -1063,7 +921,7 @@ void hvsc_stil_dump(hvsc_stil_t *handle)
 /** \brief  Get a STIL entry for \a tune
  *
  * Gets a STIL entry for \a tune from \a handle and store it in \a entry.
- * Please note that both hvsc_read_entry() and hvsc_parse_entry() need yo have
+ * Please note that both hvsc_read_entry() and hvsc_parse_entry() need to have
  * been successfully called in order for this function to succeed.
  * The data in \a entry should not be manipulated or freed.
  *
@@ -1073,7 +931,7 @@ void hvsc_stil_dump(hvsc_stil_t *handle)
  *
  * \return  bool
  */
-int hvsc_stil_get_tune_entry(const hvsc_stil_t *handle,
+bool hvsc_stil_get_tune_entry(const hvsc_stil_t *handle,
                              hvsc_stil_tune_entry_t *entry,
                              int tune)
 {
@@ -1081,7 +939,7 @@ int hvsc_stil_get_tune_entry(const hvsc_stil_t *handle,
 
     if (handle->blocks == NULL) {
         hvsc_errno = HVSC_ERR_INVALID;
-        return 0;
+        return false;
     }
 
     for (n = 0; n < handle->blocks_used; n++) {
@@ -1091,12 +949,12 @@ int hvsc_stil_get_tune_entry(const hvsc_stil_t *handle,
             entry->tune = block->tune;
             entry->fields = block->fields;
             entry->field_count = block->fields_used;
-            return 1;
+            return true;
         }
     }
     hvsc_dbg("Could not find entry for tune #%d\n", tune);
     hvsc_errno = HVSC_ERR_NOT_FOUND;
-    return 0;
+    return false;
 }
 
 
@@ -1148,26 +1006,20 @@ void hvsc_stil_dump_tune_entry(const hvsc_stil_tune_entry_t *entry)
  *
  * \return  true if STIL info found and parsed
  */
-int hvsc_stil_get(hvsc_stil_t *stil, const char *path)
+bool hvsc_stil_get(hvsc_stil_t *stil, const char *path)
 {
     /* find STIL.txt entry */
     if (!hvsc_stil_open(path, stil)) {
-        return 0;
+        return false;
     }
 
     /* read all text lines related to the entry */
     if (!hvsc_stil_read_entry(stil)) {
         hvsc_stil_close(stil);
-        return 0;
+        return false;
     }
 
     /* parse text */
-    if (!hvsc_stil_parse_entry(stil)) {
-        hvsc_stil_close(stil);
-        return 0;
-    }
-
-    return 1;
+    hvsc_stil_parse_entry(stil);
+    return true;
 }
-
-
