@@ -30,6 +30,7 @@
 struct image_contents_s;
 struct vdrive_s;
 
-extern struct image_contents_s *diskcontents_block_read(struct vdrive_s *vdrive);
+extern struct image_contents_s *diskcontents_block_read(struct vdrive_s *vdrive,
+                                    int part);
 
 #endif
