@@ -69,24 +69,27 @@ static uint8_t rst_line[JOYPORT_MAX_PORTS] = {1};
 static uint8_t clk_line[JOYPORT_MAX_PORTS] = {1};
 static uint8_t data_line[JOYPORT_MAX_PORTS] = {1};
 
-static int joyport_bbrtc_enable(int port, int value)
+static int joyport_bbrtc_set_enabled(int port, int enabled)
 {
-    int val = value ? 1 : 0;
+    int new_state = enabled ? 1 : 0;
 
-    if (val == bbrtc_enabled[port]) {
+    if (new_state == bbrtc_enabled[port]) {
         return 0;
     }
 
-    if (val) {
+    if (new_state) {
+        /* enabled, create new DS1602 RTC context for the RTC on this port */
         bbrtc_context[port] = ds1602_init("BBRTC", 220953600);
     } else {
+        /* disabled, if there is a DS1602 RTC context for this port, destroy it */
         if (bbrtc_context[port]) {
             ds1602_destroy(bbrtc_context[port], bbrtc_save);
             bbrtc_context[port] = NULL;
         }
     }
 
-    bbrtc_enabled[port] = val;
+    /* set current enabled state */
+    bbrtc_enabled[port] = new_state;
 
     return 0;
 }
@@ -95,7 +98,11 @@ static uint8_t bbrtc_read(int port)
 {
     uint8_t retval;
 
+    /* get data line value from the DS1602 RTC */
     retval = (ds1602_read_data_line(bbrtc_context[port]) ? 0 : 1) << 1;
+
+    joyport_display_joyport(port, JOYPORT_ID_BBRTC, (uint16_t)~retval);
+
     return (uint8_t)(~retval);
 }
 
@@ -105,16 +112,19 @@ static void bbrtc_store(int port, uint8_t val)
     uint8_t data_val = JOYPORT_BIT_BOOL(val, JOYPORT_DOWN_BIT);    /* data line is on the joyport 'down' pin */
     uint8_t clk_val = JOYPORT_BIT_BOOL(val, JOYPORT_RIGHT_BIT);    /* clock line is on the joyport 'right' pin */
 
+    /* check if the reset line has changed and pass to DS1602 RTC reset line */
     if (rst_val != rst_line[port]) {
         ds1602_set_reset_line(bbrtc_context[port], rst_val);
         rst_line[port] = rst_val;
     }
 
+    /* check if the clock line has changed and pass to DS1602 RTC clock line */
     if (clk_val != clk_line[port]) {
         ds1602_set_clk_line(bbrtc_context[port], clk_val);
         clk_line[port] = clk_val;
     }
 
+    /* check if the data line has changed and pass to DS1602 RTC data line */
     if (data_val != data_line[port]) {
         ds1602_set_data_line(bbrtc_context[port], data_val);
         data_line[port] = data_val;
@@ -128,30 +138,30 @@ static int bbrtc_write_snapshot(struct snapshot_s *s, int port);
 static int bbrtc_read_snapshot(struct snapshot_s *s, int port);
 
 static joyport_t joyport_bbrtc_device = {
-    "RTC (BBRTC)",            /* name of the device */
-    JOYPORT_RES_ID_NONE,      /* device can be used in multiple ports at the same time */
-    JOYPORT_IS_NOT_LIGHTPEN,  /* device is NOT a lightpen */
-    JOYPORT_POT_OPTIONAL,     /* device does NOT use the potentiometer lines */
-    JOYSTICK_ADAPTER_ID_NONE, /* device is NOT a joystick adapter */
-    JOYPORT_DEVICE_RTC,       /* device is an RTC */
-    0x0B,                     /* bits 3, 1 and 0 are output */
-    joyport_bbrtc_enable,     /* device enable function */
-    bbrtc_read,               /* digital line read function */
-    bbrtc_store,              /* digital line store function */
-    NULL,                     /* NO pot-x read function */
-    NULL,                     /* NO pot-y read function */
-    NULL,                     /* NO powerup function */
-    bbrtc_write_snapshot,     /* device snapshot write function */
-    bbrtc_read_snapshot,      /* device snapshot read function */
-    NULL,                     /* NO device hook function */
-    0                         /* NO device hook function mask */
+    "RTC (BBRTC)",             /* name of the device */
+    JOYPORT_RES_ID_NONE,       /* device can be used in multiple ports at the same time */
+    JOYPORT_IS_NOT_LIGHTPEN,   /* device is NOT a lightpen */
+    JOYPORT_POT_OPTIONAL,      /* device does NOT use the potentiometer lines */
+    JOYSTICK_ADAPTER_ID_NONE,  /* device is NOT a joystick adapter */
+    JOYPORT_DEVICE_RTC,        /* device is an RTC */
+    0x0B,                      /* bits 3, 1 and 0 are output */
+    joyport_bbrtc_set_enabled, /* device enable/disable function */
+    bbrtc_read,                /* digital line read function */
+    bbrtc_store,               /* digital line store function */
+    NULL,                      /* NO pot-x read function */
+    NULL,                      /* NO pot-y read function */
+    NULL,                      /* NO powerup function */
+    bbrtc_write_snapshot,      /* device snapshot write function */
+    bbrtc_read_snapshot,       /* device snapshot read function */
+    NULL,                      /* NO device hook function */
+    0                          /* NO device hook function mask */
 };
 
 /* ------------------------------------------------------------------------- */
 
-static int set_bbrtc_save(int val, void *param)
+static int set_bbrtc_save(int enabled, void *param)
 {
-    bbrtc_save = val ? 1 : 0;
+    bbrtc_save = enabled ? 1 : 0;
 
     return 0;
 }
@@ -177,6 +187,7 @@ void joyport_bbrtc_resources_shutdown(void)
 {
     int i;
 
+    /* destroy any DS1602 RTC contexts */
     for (i = 0; i < JOYPORT_MAX_PORTS; i++) {
         if (bbrtc_context[i]) {
             ds1602_destroy(bbrtc_context[i], bbrtc_save);
@@ -228,7 +239,7 @@ static int bbrtc_write_snapshot(struct snapshot_s *s, int port)
         return -1;
     }
 
-    if (0 
+    if (0
         || SMW_B(m, rst_line[port]) < 0
         || SMW_B(m, clk_line[port]) < 0
         || SMW_B(m, data_line[port]) < 0) {
