@@ -1,13 +1,10 @@
 /*
- * mouse.h - Common mouse handling
+ * mouse.h - Common mouse handling (header)
  *
  * Written by
  *  Marco van den Heuvel <blackystardust68@yahoo.com>
  *  Andreas Boose <viceteam@t-online.de>
  *
- * NEOS and Amiga mouse support by
- *  Hannu Nuotio <hannu.nuotio@tut.fi>
- *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
  *
@@ -34,6 +31,7 @@
 #include <stdbool.h>
 
 #include "types.h"
+#include "snapshot.h"
 
 typedef struct mouse_func_s {
     void (*mbl)(int pressed);
@@ -46,22 +44,25 @@ typedef struct mouse_func_s {
 extern int mouse_resources_init(void);
 extern int mouse_cmdline_options_init(void);
 extern void mouse_init(void);
+extern void mouse_reset(void);
 extern void mouse_shutdown(void);
 
 extern int _mouse_enabled;
-extern int _mouse_still_frames;
 extern int mouse_type;
 
-extern void mouse_move(float dx, float dy);
-extern void mouse_get_int16(int16_t *x, int16_t *y);
+extern void mouse_set_machine_parameter(long clock_rate);
 
-extern void neos_mouse_set_machine_parameter(long clock_rate);
-extern void neos_mouse_store(int port, uint8_t val);
-extern uint8_t neos_mouse_read(void);
-extern uint8_t mouse_poll(void);
-extern void smart_mouse_store(int port, uint8_t val);
-extern uint8_t smart_mouse_read(void);
-extern uint8_t micromys_mouse_read(void);
+extern void mouse_move(float dx, float dy);
+extern void mouse_poll(void);
+
+extern void mouse_get_raw_int16(int16_t *x, int16_t *y);
+extern void mouse_get_last_int16(int16_t *x, int16_t *y);
+
+extern int mouse_get_mouse_sx(void);
+extern int mouse_get_mouse_sy(void);
+
+extern int read_mouse_common_snapshot(snapshot_module_t *m);
+extern int write_mouse_common_snapshot(snapshot_module_t *m);
 
 #define MOUSE_TYPE_1351     0
 #define MOUSE_TYPE_NEOS     1
@@ -78,4 +79,7 @@ extern uint8_t micromys_mouse_read(void);
 #define PADDLES_INPUT_MOUSE    0
 #define PADDLES_INPUT_JOY_AXIS 1
 
+extern int mouse_type_to_id(int mt);
+extern int mouse_id_to_type(int id);
+
 #endif
