@@ -54,11 +54,11 @@
 
 static int joyport_script64_dongle_enabled[JOYPORT_MAX_PORTS] = {0};
 
-static int joyport_script64_dongle_enable(int port, int value)
+static int joyport_script64_dongle_set_enabled(int port, int enabled)
 {
-    int val = value ? 1 : 0;
+    int new_state = enabled ? 1 : 0;
 
-    joyport_script64_dongle_enabled[port] = val;
+    joyport_script64_dongle_enabled[port] = new_state;
 
     return 0;
 }
@@ -76,23 +76,23 @@ static uint8_t script64_dongle_read_poty(int port)
 /* ------------------------------------------------------------------------- */
 
 static joyport_t joyport_script64_dongle_device = {
-    "Dongle (Script 64)",           /* name of the device */
-    JOYPORT_RES_ID_NONE,            /* device can be used in multiple ports at the same time */
-    JOYPORT_IS_NOT_LIGHTPEN,        /* device is NOT a lightpen */
-    JOYPORT_POT_REQUIRED,           /* device uses the potentiometer lines */
-    JOYSTICK_ADAPTER_ID_NONE,       /* device is NOT a joystick adapter */
-    JOYPORT_DEVICE_C64_DONGLE,      /* device is a C64 Dongle */
-    0,                              /* NO output bits */
-    joyport_script64_dongle_enable, /* device enable function */
-    NULL,                           /* NO digital line read function */
-    NULL,                           /* NO digital line store function */
-    script64_dongle_read_potx,      /* pot-x read function */
-    script64_dongle_read_poty,      /* pot-y read function */
-    NULL,                           /* NO powerup function */
-    NULL,                           /* NO device write snapshot function */
-    NULL,                           /* NO device read snapshot function */
-    NULL,                           /* NO device hook function */
-    0                               /* NO device hook function mask */
+    "Dongle (Script 64)",                /* name of the device */
+    JOYPORT_RES_ID_NONE,                 /* device can be used in multiple ports at the same time */
+    JOYPORT_IS_NOT_LIGHTPEN,             /* device is NOT a lightpen */
+    JOYPORT_POT_REQUIRED,                /* device uses the potentiometer lines */
+    JOYSTICK_ADAPTER_ID_NONE,            /* device is NOT a joystick adapter */
+    JOYPORT_DEVICE_C64_DONGLE,           /* device is a C64 Dongle */
+    0,                                   /* NO output bits */
+    joyport_script64_dongle_set_enabled, /* device enable/disable function */
+    NULL,                                /* NO digital line read function */
+    NULL,                                /* NO digital line store function */
+    script64_dongle_read_potx,           /* pot-x read function */
+    script64_dongle_read_poty,           /* pot-y read function */
+    NULL,                                /* NO powerup function */
+    NULL,                                /* NO device write snapshot function */
+    NULL,                                /* NO device read snapshot function */
+    NULL,                                /* NO device hook function */
+    0                                    /* NO device hook function mask */
 };
 
 /* ------------------------------------------------------------------------- */
