@@ -64,12 +64,11 @@ static void log_file_open(void)
     if (log_file_name == NULL || *log_file_name == 0) {
         log_file = archdep_open_default_log_file();
     } else {
-#ifndef __OS2__
         if (strcmp(log_file_name, "-") == 0) {
             log_file = stdout;
-        } else
-#endif
-        log_file = fopen(log_file_name, MODE_WRITE_TEXT);
+        } else {
+            log_file = fopen(log_file_name, MODE_WRITE_TEXT);
+        }
     }
     /* flush all data direct to the output stream. */
     if (log_file) {
