@@ -65,10 +65,12 @@
 */
 
 /* ------------------------------------------------------------------------- */
-#ifdef DEBUG
+#if defined (DEBUG) || defined (FEATURE_CPUMEMHISTORY)
 CLOCK debug_clk;
 #endif
 
+static int reu_dma_triggered = 0;
+
 #define NEED_REG_PC
 
 /* ------------------------------------------------------------------------- */
@@ -186,11 +188,11 @@ static void maincpu_steal_cycles(void)
 inline static void check_ba(void)
 {
     if (maincpu_ba_low_flags) {
-#ifdef DEBUG
+#if defined (DEBUG) || defined (FEATURE_CPUMEMHISTORY)
         CLOCK old_maincpu_clk = maincpu_clk;
 #endif
         maincpu_steal_cycles();
-#ifdef DEBUG
+#if defined (DEBUG) || defined (FEATURE_CPUMEMHISTORY)
         if (debug_clk == old_maincpu_clk) {
             debug_clk = maincpu_clk;
         }
@@ -272,12 +274,21 @@ static uint8_t memmap_mem_read_dummy(unsigned int addr)
 
 #ifndef STORE
 #define STORE(addr, value) \
-    memmap_mem_store(addr, value)
+    if (reu_dma_triggered == 0) { \
+        memmap_mem_store(addr, value); \
+        if (addr == 0xff00) { \
+            reu_dma(-1); \
+        } \
+    } \
+    reu_dma_triggered = 0
 #endif
 
 #ifndef STORE_DUMMY
 #define STORE_DUMMY(addr, value) \
-    memmap_mem_store_dummy(addr, value)
+    memmap_mem_store_dummy(addr, value); \
+    if (addr == 0xff00) { \
+        reu_dma_triggered = reu_dma(-1); \
+    }
 #endif
 
 #ifndef LOAD
@@ -346,12 +357,21 @@ inline static uint8_t mem_read_check_ba_dummy(unsigned int addr)
 
 #ifndef STORE
 #define STORE(addr, value) \
-    (*_mem_write_tab_ptr[(addr) >> 8])((uint16_t)(addr), (uint8_t)(value))
+    if (reu_dma_triggered == 0) { \
+        (*_mem_write_tab_ptr[(addr) >> 8])((uint16_t)(addr), (uint8_t)(value)); \
+        if (addr == 0xff00) { \
+            reu_dma(-1); \
+        } \
+    } \
+    reu_dma_triggered = 0
 #endif
 
 #ifndef STORE_DUMMY
 #define STORE_DUMMY(addr, value) \
-    (*_mem_write_tab_ptr_dummy[(addr) >> 8])((uint16_t)(addr), (uint8_t)(value))
+    (*_mem_write_tab_ptr_dummy[(addr) >> 8])((uint16_t)(addr), (uint8_t)(value)); \
+    if (addr == 0xff00) { \
+        reu_dma_triggered = reu_dma(-1); \
+    }
 #endif
 
 #ifndef LOAD
