@@ -46,32 +46,37 @@
 #include "log.h"
 #include "machine.h"
 #include "mainlock.h"
-#include "tick.h"
 #include "vsyncapi.h"
 
-static volatile bool vice_thread_keepalive = true;
+/* This is lock coordinates access to VICE data structures */
+static pthread_mutex_t  main_lock        = PTHREAD_MUTEX_INITIALIZER;
 
-static pthread_mutex_t lock;
+/* How many times the UI has recursively obtained the main lock*/
+static int              main_lock_obtain_depth;
 
-static pthread_t vice_thread;
-static bool vice_thread_is_running = false;
+/* Used to coordinate access to data within mainlock.c */
+static pthread_mutex_t  internal_lock    = PTHREAD_MUTEX_INITIALIZER;
+static pthread_cond_t   ui_waiting_cond  = PTHREAD_COND_INITIALIZER;
+static pthread_cond_t   ui_has_lock_cond = PTHREAD_COND_INITIALIZER;
+static bool             ui_is_waiting    = false;
+static pthread_t        vice_thread;
+static bool             vice_thread_keepalive  = true;
+static bool             vice_thread_is_running = false;
 
 void mainlock_init(void)
 {
-    pthread_mutexattr_t lock_attributes;
-    pthread_mutexattr_init(&lock_attributes);
-    pthread_mutexattr_settype(&lock_attributes, PTHREAD_MUTEX_RECURSIVE);
-    pthread_mutex_init(&lock, &lock_attributes);
 }
 
 
 void mainlock_set_vice_thread(void)
 {
-    /* The vice thread owns this lock except when explicitly releasing it */
-    pthread_mutex_lock(&lock);
-
+    pthread_mutex_lock(&internal_lock);
     vice_thread = pthread_self();
     vice_thread_is_running = true;
+    pthread_mutex_unlock(&internal_lock);
+
+    /* The vice thread owns this lock except when explicitly releasing it */
+    pthread_mutex_lock(&main_lock);
 }
 
 
@@ -83,38 +88,55 @@ static void consider_exit(void)
     }
 
     /* Check if the vice thread has been told to die. */
+    pthread_mutex_lock(&internal_lock);
     if (!vice_thread_keepalive) {
-        
-        /* This needs to be set before unlocking to avoid a shutdown race condition */
+
+        /*
+         * The VICE thread will exit!
+         */
+
+        /* Setting this lets the UI thread know not to wait for signals in future mainlock_obtain() calls */
         vice_thread_is_running = false;
-        
-        pthread_mutex_unlock(&lock);
-        
+
+        if (ui_is_waiting) {
+            /* Wake up the UI thread, otherwise it will be waiting forever */
+            pthread_cond_signal(&ui_waiting_cond);
+        }
+
+        pthread_mutex_unlock(&internal_lock);
+        pthread_mutex_unlock(&main_lock);
+
         log_message(LOG_DEFAULT, "VICE thread is exiting");
 
         archdep_thread_shutdown();
 
-        /* Execution ends here - this function does not return. */
         pthread_exit(NULL);
+
+        /*
+         * EXECUTION DOES NOT REACH HERE - pthread_exit() does not return
+         */
+
+        assert(false);
+
+    } else {
+        pthread_mutex_unlock(&internal_lock);
     }
 }
 
 
 void mainlock_initiate_shutdown(void)
 {
-    pthread_mutex_lock(&lock);
-
+    pthread_mutex_lock(&internal_lock);
     if (!vice_thread_keepalive) {
-        pthread_mutex_unlock(&lock);
+        /* Already initiated */
+        pthread_mutex_unlock(&internal_lock);
         return;
     }
+    vice_thread_keepalive = false;
+    pthread_mutex_unlock(&internal_lock);
 
     log_message(LOG_DEFAULT, "VICE thread initiating shutdown");
 
-    vice_thread_keepalive = false;
-
-    pthread_mutex_unlock(&lock);
-
     /* If called on the vice thread itself, run the exit code immediately */
     if (pthread_equal(pthread_self(), vice_thread)) {
         consider_exit();
@@ -136,7 +158,22 @@ void mainlock_yield(void)
  */
 void mainlock_yield_begin(void)
 {
-    pthread_mutex_unlock(&lock);
+    pthread_mutex_unlock(&main_lock);
+
+    /*
+     * If the UI thread is already waiting for the mainlock, attempt
+     * to wake it immediately and block until it has it. This ensures
+     * that thread priorities don't affect sharing of this lock.
+     */
+
+    pthread_mutex_lock(&internal_lock);
+    if (ui_is_waiting) {
+        /* Wake up the UI thread */
+        pthread_cond_signal(&ui_waiting_cond);
+        /* Block until the UI has the main lock */
+        pthread_cond_wait(&ui_has_lock_cond, &internal_lock);
+    }
+    pthread_mutex_unlock(&internal_lock);
 }
 
 
@@ -144,12 +181,21 @@ void mainlock_yield_begin(void)
  */
 void mainlock_yield_end(void)
 {
-    pthread_mutex_lock(&lock);
-    
+    pthread_mutex_lock(&main_lock);
+
     /* After the UI *might* have had the lock, check if we should exit. */
     consider_exit();
 }
 
+/** \brief Release the mainlock and sleep
+ */
+void mainlock_yield_and_sleep(tick_t ticks)
+{
+    mainlock_yield_begin();
+    tick_sleep(ticks);
+    mainlock_yield_end();
+}
+
 /****/
 
 void mainlock_obtain(void)
@@ -160,7 +206,7 @@ void mainlock_obtain(void)
          * Bad - likely the vice thread directly triggered some UI code.
          * That UI code then generated a signal which is then synchronously
          * pushed through to the handler, which tries to obtain the lock.
-         * 
+         *
          * The solution is ALWAYS to make VICE asynchronously trigger the
          * UI code.
          */
@@ -169,7 +215,34 @@ void mainlock_obtain(void)
     }
 #endif
 
-    pthread_mutex_lock(&lock);
+    /*
+     * The UI may attempt to recursively obtain the mainlock during shutdown
+     * and other cases where gtk event handlers recursively trigger other gtk
+     * event handlers. This would be fine normally (if using a recursive mutex)
+     * however during shutdown we can't be sure that the vice thread is there
+     * to signal the condition we are about to block on.
+     */
+
+    if (main_lock_obtain_depth++ > 0) {
+        return;
+    }
+
+    pthread_mutex_lock(&internal_lock);
+
+    if (vice_thread_is_running) {
+        /* Block until the VICE thread signals us */
+        ui_is_waiting = true;
+        pthread_cond_wait(&ui_waiting_cond, &internal_lock);
+        ui_is_waiting = false;
+    }
+
+    pthread_mutex_unlock(&internal_lock);
+
+    /* Get the main lock */
+    pthread_mutex_lock(&main_lock);
+
+    /* Let the VICE thread know we have the mainlock now */
+    pthread_cond_signal(&ui_has_lock_cond);
 }
 
 
@@ -188,8 +261,10 @@ void mainlock_release(void)
         return;
     }
 #endif
-    
-    pthread_mutex_unlock(&lock);
+
+    pthread_mutex_unlock(&main_lock);
+
+    main_lock_obtain_depth--;
 }
 
 #endif /* #ifdef USE_VICE_THREAD */
