@@ -28,6 +28,7 @@
 #define VICE_MON_COMMAND_H
 
 extern void mon_command_print_help(const char *cmd);
-extern int mon_get_nth_command(int index, const char** full_name, const char **short_name, int *takes_filename_as_arg);
+extern int mon_get_nth_command(int index, char **full_name, char **short_name,
+        int *takes_filename_as_arg);
 
 #endif
