@@ -33,4 +33,9 @@ extern void mon_drive_block_cmd(int op, int track, int sector, MON_ADDR addr);
 extern void mon_drive_execute_disk_cmd(char *cmd);
 extern void mon_drive_list(int drive_number);
 
+/* FIXME: this function should perhaps live elsewhere */
+extern int mon_drive_is_fsdevice(int drive_unit);
+/* FIXME: this function should perhaps live elsewhere */
+extern const char *mon_drive_get_fsdevice_path(int drive_unit);
+
 #endif
