@@ -73,7 +73,7 @@ static io_source_list_t *debugcart_list_item = NULL;
 static void debugcart_store(uint16_t addr, uint8_t value)
 {
     int n = (int)value;
-    fprintf(stdout, "DBGCART: exit(%d) cycles elapsed: %u\n", n, maincpu_clk);
+    fprintf(stdout, "DBGCART: exit(%d) cycles elapsed: %"PRIu64"\n", n, maincpu_clk);
 
     archdep_vice_exit(n);
 }
