@@ -280,7 +280,7 @@ static const cmdline_option_t cmdline_options[] =
       "<Name>", "Specify name of PET Ram and Expansion Unit image" },
     { "-petreuramsize", SET_RESOURCE, CMDLINE_ATTRIB_NEED_ARGS,
       NULL, NULL, "PETREUsize", NULL,
-      "<size in KB>", "Size of the PET Ram and Expansion Unit. (128/512/1024/2048)" },
+      "<size in KiB>", "Size of the PET Ram and Expansion Unit. (128/512/1024/2048)" },
     CMDLINE_LIST_END
 };
 
@@ -318,7 +318,7 @@ static int petreu_activate(void)
 
     old_petreu_ram_size = petreu_size;
 
-    log_message(petreu_log, "%dKB unit installed.", petreu_size >> 10);
+    log_message(petreu_log, "%dKiB unit installed.", petreu_size >> 10);
 
     if (!util_check_null_string(petreu_filename)) {
         if (util_file_load(petreu_filename, petreu_ram, (size_t)petreu_size,
@@ -576,7 +576,7 @@ static int petreu_dump(void)
         real_bank = (real_bank & ((petreu_size_kb >> 4) - 1));
     }
 
-    mon_out("RAM size: %dKB, Bank: %d\n", petreu_size_kb, real_bank);
+    mon_out("RAM size: %dKiB, Bank: %d\n", petreu_size_kb, real_bank);
 
     return 0;
 }
