@@ -29,32 +29,6 @@
 
 #include "types.h"
 
-#define PET_CHARGEN_NAME        "characters-2.901447-10.bin"
-#define SUPERPET_CHARGEN_NAME   "characters.901640-01.bin"
-
-#define PET_KERNAL1NAME  "kernal-1.901439-04-07.bin"
-#define PET_KERNAL2NAME  "kernal-2.901465-03.bin"
-#define PET_KERNAL4NAME  "kernal-4.901465-22.bin"
-
-#define PET_BASIC1NAME  "basic-1.901439-09-05-02-06.bin"
-#define PET_BASIC2NAME  "basic-2.901465-01-02.bin"
-#define PET_BASIC4NAME  "basic-4.901465-23-20-21.bin"
-
-#define PET_EDITOR1G40NAME  "edit-1-n.901439-03.bin"
-#define PET_EDITOR2G40NAME  "edit-2-n.901447-24.bin"
-#define PET_EDITOR2B40NAME  "edit-2-b.901474-01.bin"
-#define PET_EDITOR4G40NAME  "edit-4-40-n-50Hz.901498-01.bin"
-#define PET_EDITOR4B80NAME  "edit-4-80-b-50Hz.901474-04_.bin"
-/* #define PET_EDITOR4B40NAME  "edit-4-b-noCRTC.901474-02.bin" */ /* no CRTC */
-#define PET_EDITOR4B40NAME  "edit-4-40-b-50Hz.ts.bin"
-
-#define SUPERPET_6809_A_NAME "waterloo-a000.901898-01.bin"
-#define SUPERPET_6809_B_NAME "waterloo-b000.901898-02.bin"
-#define SUPERPET_6809_C_NAME "waterloo-c000.901898-03.bin"
-#define SUPERPET_6809_D_NAME "waterloo-d000.901898-04.bin"
-#define SUPERPET_6809_E_NAME "waterloo-e000.901897-01.bin"
-#define SUPERPET_6809_F_NAME "waterloo-f000.901898-05.bin"
-
 #define PET_COLS                80
 #define PET_MAP_LINEAR          0
 #define PET_MAP_8096            1
@@ -115,7 +89,6 @@ typedef struct petinfo_s {
     int ramselA;                /* 0 = open/ROM, 1 = RAM: 8296 JU1*/
     int kbd_type;               /* see pet-resources.h */
     int pet2k;                  /* 1 = do PET 2001 kernal patches */
-    int pet2kchar;              /* 1 = do PET 2001 chargen patches */
     int eoiblank;               /* 1 = EOI blanks screen */
     int screenmirrors2001;      /* 1 = 4x1K screen mirrors all over $8*** */
     int superpet;               /* 1 = enable SuperPET I/O */
@@ -143,7 +116,6 @@ typedef struct petres_s {
     int ramselA;                /* 0 = open/ROM, 1 = RAM: 8296 JU1*/
     int kbd_type;               /* 1 = graphics, 0 = business (UK) */
     int pet2k;                  /* 1 = do PET 2001 kernal patches */
-    int pet2kchar;              /* 1 = do PET 2001 chargen patches */
     int eoiblank;               /* 1 = EOI blanks screen */
     int screenmirrors2001;      /* 1 = 4x1K screen mirrors all over $8*** */
     int superpet;               /* 1 = enable SuperPET I/O */
