@@ -28,17 +28,17 @@
 
 #include <stdio.h>
 
+#include "archdep.h"
 #include "drive-snapshot.h"
 #include "drive.h"
-#include "ioutil.h"
 #include "joyport.h"
 #include "joystick.h"
 #include "keyboard.h"
 #include "log.h"
 #include "machine.h"
 #include "maincpu.h"
-#include "plus4-snapshot.h"
 #include "plus4memsnapshot.h"
+#include "serial.h"
 #include "snapshot.h"
 #include "sound.h"
 #include "tapeport.h"
@@ -47,6 +47,9 @@
 #include "userport.h"
 #include "vice-event.h"
 
+#include "plus4-snapshot.h"
+
+
 /* #define DEBUGSNAPSHOT */
 
 #ifdef DEBUGSNAPSHOT
@@ -55,8 +58,8 @@
 #define DBG(x)
 #endif
 
-#define SNAP_MAJOR 1
-#define SNAP_MINOR 1
+#define SNAP_MAJOR 2
+#define SNAP_MINOR 0
 
 int plus4_snapshot_write(const char *name, int save_roms, int save_disks,
                          int event_mode)
@@ -77,6 +80,7 @@ int plus4_snapshot_write(const char *name, int save_roms, int save_disks,
     if (maincpu_snapshot_write_module(s) < 0
         || plus4_snapshot_write_module(s, save_roms) < 0
         || drive_snapshot_write_module(s, save_disks, save_roms) < 0
+        || fsdrive_snapshot_write_module(s) < 0
         || ted_snapshot_write_module(s) < 0
         || event_snapshot_write_module(s, event_mode) < 0
         || tapeport_snapshot_write_module(s, save_disks) < 0
@@ -85,7 +89,7 @@ int plus4_snapshot_write(const char *name, int save_roms, int save_disks,
         || joyport_snapshot_write_module(s, JOYPORT_2) < 0
         || userport_snapshot_write_module(s) < 0) {
         snapshot_close(s);
-        ioutil_remove(name);
+        archdep_remove(name);
         DBG(("error writing snapshot modules.\n"));
         return -1;
     }
@@ -118,6 +122,7 @@ int plus4_snapshot_read(const char *name, int event_mode)
     if (maincpu_snapshot_read_module(s) < 0
         || plus4_snapshot_read_module(s) < 0
         || drive_snapshot_read_module(s) < 0
+        || fsdrive_snapshot_read_module(s) < 0
         || ted_snapshot_read_module(s) < 0
         || event_snapshot_read_module(s, event_mode) < 0
         || tapeport_snapshot_read_module(s) < 0
