@@ -209,9 +209,9 @@ static uint8_t tiatcbm_read(uint16_t addr, unsigned int dnr)
 
 uint8_t plus4tcbm1_read(uint16_t addr)
 {
-    if (drive_context[0]->drive->enable
-        && drive_context[0]->drive->type == DRIVE_TYPE_1551) {
-        drive_cpu_execute_one(drive_context[0], maincpu_clk);
+    if (diskunit_context[0]->enable
+        && diskunit_context[0]->type == DRIVE_TYPE_1551) {
+        drive_cpu_execute_one(diskunit_context[0], maincpu_clk);
         return tiatcbm_read(addr, 0);
     }
     return 0;
@@ -219,18 +219,18 @@ uint8_t plus4tcbm1_read(uint16_t addr)
 
 void plus4tcbm1_store(uint16_t addr, uint8_t value)
 {
-    if (drive_context[0]->drive->enable
-        && drive_context[0]->drive->type == DRIVE_TYPE_1551) {
-        drive_cpu_execute_one(drive_context[0], maincpu_clk);
+    if (diskunit_context[0]->enable
+        && diskunit_context[0]->type == DRIVE_TYPE_1551) {
+        drive_cpu_execute_one(diskunit_context[0], maincpu_clk);
         tiatcbm_store(addr, value, 0);
     }
 }
 
 uint8_t plus4tcbm2_read(uint16_t addr)
 {
-    if (drive_context[1]->drive->enable
-        && drive_context[1]->drive->type == DRIVE_TYPE_1551) {
-        drive_cpu_execute_one(drive_context[1], maincpu_clk);
+    if (diskunit_context[1]->enable
+        && diskunit_context[1]->type == DRIVE_TYPE_1551) {
+        drive_cpu_execute_one(diskunit_context[1], maincpu_clk);
         return tiatcbm_read(addr, 1);
     }
     return 0;
@@ -238,9 +238,9 @@ uint8_t plus4tcbm2_read(uint16_t addr)
 
 void plus4tcbm2_store(uint16_t addr, uint8_t value)
 {
-    if (drive_context[1]->drive->enable
-        && drive_context[1]->drive->type == DRIVE_TYPE_1551) {
-        drive_cpu_execute_one(drive_context[1], maincpu_clk);
+    if (diskunit_context[1]->enable
+        && diskunit_context[1]->type == DRIVE_TYPE_1551) {
+        drive_cpu_execute_one(diskunit_context[1], maincpu_clk);
         tiatcbm_store(addr, value, 1);
     }
 }
