@@ -96,7 +96,7 @@ static void screenshot_line_data(screenshot_t *screenshot, uint8_t *data,
     uint8_t color;
 
     if (line > screenshot->height) {
-        log_error(screenshot_log, "Invalild line `%i' request.", line);
+        log_error(screenshot_log, "Invalild line `%u' request.", line);
         return;
     }
 
@@ -130,7 +130,7 @@ static void screenshot_line_data(screenshot_t *screenshot, uint8_t *data,
             }
             break;
         default:
-            log_error(screenshot_log, "Invalid mode %i.", mode);
+            log_error(screenshot_log, "Invalid mode %u.", mode);
     }
 }
 
@@ -208,9 +208,9 @@ int screenshot_save(const char *drvname, const char *filename,
         recording_driver = drv;
         recording_canvas = canvas;
 
-        reopen_recording_drivername = lib_stralloc(drvname);
+        reopen_recording_drivername = lib_strdup(drvname);
         reopen_recording_canvas = canvas;
-        reopen_filename = lib_stralloc(filename);
+        reopen_filename = lib_strdup(filename);
     }
 
     result = screenshot_save_core(&screenshot, drv, filename);
