@@ -29,6 +29,11 @@
 
 #include "types.h"
 
+#define SERIAL_NAMELENGTH 255
+
+extern uint8_t SerialBuffer[SERIAL_NAMELENGTH + 1];
+extern int SerialPtr;
+
 extern void fsdrive_init(void);
 extern void fsdrive_reset(void);
 extern void fsdrive_open(unsigned int device, uint8_t secondary, void (*st_func)(uint8_t));
@@ -38,5 +43,4 @@ extern void fsdrive_unlisten(unsigned int device, uint8_t secondary, void (*st_f
 extern void fsdrive_untalk(unsigned int device, uint8_t secondary, void (*st_func)(uint8_t));
 extern void fsdrive_write(unsigned int device, uint8_t secondary, uint8_t data, void (*st_func)(uint8_t));
 extern uint8_t fsdrive_read(unsigned int device, uint8_t secondary, void (*st_func)(uint8_t));
-
 #endif
