@@ -24,6 +24,8 @@
  *
  */
 
+/* #define DEBUG_SERIAL_IEC_BUS */
+
 #include "vice.h"
 
 #include "fsdrive.h"
@@ -32,9 +34,16 @@
 #include "serial.h"
 #include "types.h"
 
+#ifdef DEBUG_SERIAL_IEC_BUS
+#include "log.h"
+#define DBG(x)  log_debug x
+#else
+#define DBG(x)
+#endif
 
 void serial_iec_bus_open(unsigned int device, uint8_t secondary, void (*st_func)(uint8_t))
 {
+    DBG(("serial_iec_bus_open device: 0x%2x secondary: 0x%02x", device, secondary));
 #ifdef HAVE_REALDEVICE
     if (serial_device_type_get(device & 0x0f) == SERIAL_DEVICE_REAL) {
         realdevice_open(device, secondary, st_func);
@@ -95,6 +104,7 @@ void serial_iec_bus_untalk(unsigned int device, uint8_t secondary, void (*st_fun
 
 void serial_iec_bus_write(unsigned int device, uint8_t secondary, uint8_t data, void (*st_func)(uint8_t))
 {
+    DBG(("serial_iec_bus_write device: 0x%2x secondary: 0x%02x data: 0x%02x", device, secondary, data));
 #ifdef HAVE_REALDEVICE
     if (serial_device_type_get(device & 0x0f) == SERIAL_DEVICE_REAL) {
         realdevice_write(data, st_func);
