@@ -90,34 +90,21 @@ struct sid_snapshot_state_s;
 #define SIDTYPE_SIDDTV    1
 #define SIDTYPE_SIDCART   2
 
-
-/** \brief  Maximum number of SIDs supported by the emulation
- *
- * This differs from the number of SIDs actually possible per emu.
- */
-#define SID_COUNT_MAX   8
-
-
-/** \brief  Maximum number of SIDs supported by the PSID file format
- *
- * VSID specific: this differs from the number of SIDs actually possible per
- * emu, although it can easily be extended to support more SIDs, since the
- * header has on offset to the tune data, so expanding the header is easy, but
- * will probably break some SID tools.
- */
-#define SID_COUNT_MAX_PSID  3
-
-
 #define SID_MACHINE_MAX_SID_C64     8
 #define SID_MACHINE_MAX_SID_C64DTV  1
 #define SID_MACHINE_MAX_SID_C128    8
-#define SID_MACHINE_MAX_SID_VIC20   0
+/** \brief  The VIC20 has an optional SID cartridge */
+#define SID_MACHINE_MAX_SID_VIC20   1
+/** \brief  The Plus4 has an optional SIDCard expansion */
 #define SID_MACHINE_MAX_SID_PLUS4   1
 #define SID_MACHINE_MAX_SID_CBM5x0  1
 #define SID_MACHINE_MAX_SID_CBM6x0  0
-#define SID_MACHINE_MAX_SID_PET     0
-/** \brief  This can be the same as C64 in emulation, but PSID currently only
- *          manages 3 SIDs
+/** \brief  The PET has an optional SID Card expansion */
+#define SID_MACHINE_MAX_SID_PET     1
+/** \brief  VSID supports up to three SIDS
+ *
+ * This can be the same as C64 in emulation, but PSID currently only manages 3
+ * SIDs.
  */
 #define SID_MACHINE_MAX_SID_VSID    3
 
