@@ -33,7 +33,6 @@
 #include "archdep.h"
 #include "cmdline.h"
 #include "findpath.h"
-#include "ioutil.h"
 #include "lib.h"
 #include "log.h"
 #include "resources.h"
@@ -65,7 +64,7 @@ static int set_system_path(const char *val, void *param)
 
     tmp_path_save = util_subst(system_path, "$$", default_path); /* malloc'd */
 
-    current_dir = ioutil_current_dir();
+    current_dir = archdep_current_dir();
 
     tmp_path = tmp_path_save; /* tmp_path points into tmp_path_save */
     for (;;) {
@@ -86,19 +85,19 @@ static int set_system_path(const char *val, void *param)
         } else { /* relative path */
             if (expanded_system_path == NULL) {
                 s = util_concat(current_dir,
-                                FSDEV_DIR_SEP_STR,
+                                ARCHDEP_DIR_SEP_STR,
                                 tmp_path, NULL );
             } else {
                 s = util_concat(expanded_system_path,
                                 ARCHDEP_FINDPATH_SEPARATOR_STRING,
                                 current_dir,
-                                FSDEV_DIR_SEP_STR,
+                                ARCHDEP_DIR_SEP_STR,
                                 tmp_path, NULL );
             }
         }
         lib_free(expanded_system_path);
         expanded_system_path = s;
-        
+
         if (p == NULL) {
             break;
         }
@@ -179,7 +178,7 @@ FILE *sysfile_open(const char *name, const char *subpath, char **complete_path_r
         return NULL;
     }
 
-    p = findpath(name, expanded_system_path, subpath, IOUTIL_ACCESS_R_OK);
+    p = findpath(name, expanded_system_path, subpath, ARCHDEP_ACCESS_R_OK);
 
     if (p == NULL) {
         if (complete_path_return != NULL) {
@@ -225,6 +224,7 @@ int sysfile_load(const char *name, const char *subpath, uint8_t *dest, int minsi
 {
     FILE *fp = NULL;
     size_t rsize = 0;
+    off_t tmpsize;
     char *complete_path = NULL;
     int load_at_end;
 
@@ -233,7 +233,7 @@ int sysfile_load(const char *name, const char *subpath, uint8_t *dest, int minsi
     if (fp == NULL) {
         /* Try to open the file from the current directory. */
         const char working_dir_prefix[3] = {
-            '.', FSDEV_DIR_SEP_CHR, '\0'
+            '.', ARCHDEP_DIR_SEP_CHR, '\0'
         };
         char *local_name = NULL;
 
@@ -249,7 +249,12 @@ int sysfile_load(const char *name, const char *subpath, uint8_t *dest, int minsi
 
     log_message(LOG_DEFAULT, "Loading system file `%s'.", complete_path);
 
-    rsize = util_file_length(fp);
+    tmpsize = archdep_file_size(fp);
+    if (tmpsize < 0) {
+        log_message(LOG_DEFAULT, "Failed to determine size of '%s'.", complete_path);
+        goto fail;
+    }
+    rsize = (size_t)tmpsize;
     if (minsize < 0) {
         minsize = -minsize;
         load_at_end = 0;
