@@ -29,7 +29,7 @@
 
 #include "types.h"
 
-extern int tapertc_resources_init(void);
+extern int tapertc_resources_init(int amount);
 extern int tapertc_cmdline_options_init(void);
 extern void tapertc_resources_shutdown(void);
 
