@@ -29,9 +29,6 @@
 
 #include "types.h"
 
-extern int userport_diag_586220_harness_enable;
-
 extern int userport_diag_586220_harness_resources_init(void);
-extern int userport_diag_586220_harness_cmdline_options_init(void);
 
 #endif
