@@ -4,6 +4,9 @@
  * Written by
  *  Andreas Boose <viceteam@t-online.de>
  *
+ * Multi-drive and DHD enhancements by
+ *  Roberto Muscedere <rmusced@uwindsor.ca>
+ *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
  *
@@ -46,10 +49,18 @@
 static log_t vdrive_internal_log = LOG_DEFAULT;
 
 
+/*
+Called by 2 things:
+disk preview tool - read_only mode is 1 (imagecontents/diskcontents.c)
+disk create tool - read_only is 0 (in this file)
+when read_only is 0, the image is expected to be created regardless of
+errors.
+*/
 vdrive_t *vdrive_internal_open_fsimage(const char *name, unsigned int read_only)
 {
     vdrive_t *vdrive;
     disk_image_t *image;
+    int ret;
 
     image = lib_malloc(sizeof(disk_image_t));
 
@@ -75,9 +86,22 @@ vdrive_t *vdrive_internal_open_fsimage(const char *name, unsigned int read_only)
 
     vdrive = lib_calloc(1, sizeof(vdrive_t));
 
-    vdrive_device_setup(vdrive, 100, 0);
+    vdrive_device_setup(vdrive, 100);
     vdrive->image = image;
-    vdrive_attach_image(image, 100, 0, vdrive);
+    ret = vdrive_attach_image(image, 100, 0, vdrive);
+
+    /* if we can't attached to it IN READ MODE, we should return NULL */
+    if (ret && read_only) {
+        vdrive_device_shutdown(vdrive);
+        lib_free(vdrive);
+        disk_image_media_destroy(image);
+        P64ImageDestroy((void*)image->p64);
+        lib_free(image->p64);
+        lib_free(image);
+        return NULL;
+    }
+
+    /* otherwise return the vdrive context, hoping everything will work out */
     return vdrive;
 }
 
@@ -142,6 +166,9 @@ int vdrive_internal_create_format_disk_image(const char *filename,
         case DISK_IMAGE_TYPE_D4M:
             return cbmimage_create_dxm_image(filename, diskname, type);
             break;
+        case DISK_IMAGE_TYPE_DHD:
+            /* no creation method this this type yet */
+            return -1;
         default:
             if (cbmimage_create_image(filename, type) < 0) {
                 return -1;
