@@ -37,11 +37,6 @@
 #include <ctype.h>
 #include <string.h>
 
-#ifdef AMIGA_AROS
-#define __AROS_OFF_T_DECLARED
-#define __AROS_PID_T_DECLARED
-#endif
-
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
