@@ -30,6 +30,7 @@
 #include <string.h>
 #include <assert.h>
 
+#include "archdep.h"
 #include "cartio.h"
 #include "cartridge.h"
 #include "cmdline.h"
@@ -273,6 +274,9 @@ static void io_source_log_collisions(uint16_t addr, int amount, io_source_list_t
     }
 }
 
+/* FIXME: the upper 4 bits of the mask are used to indicate the register size if not equal to the mask,
+          this is done as a temporary HACK to keep mirrors working and still get the correct register size,
+          this needs to be fixed properly after the 3.6 release */
 static inline uint8_t io_read(io_source_list_t *list, uint16_t addr)
 {
     io_source_list_t *current = list->next;
@@ -285,7 +289,7 @@ static inline uint8_t io_read(io_source_list_t *list, uint16_t addr)
     while (current) {
         if (current->device->read != NULL) {
             if ((addr >= current->device->start_address) && (addr <= current->device->end_address)) {
-                retval = current->device->read((uint16_t)(addr & current->device->address_mask));
+                retval = current->device->read((uint16_t)(addr & (current->device->address_mask & 0x3ff)));
                 if (current->device->io_source_valid) {
                     if (current->device->io_source_prio == 1) {
                         return retval;
@@ -349,6 +353,9 @@ static inline uint8_t io_read(io_source_list_t *list, uint16_t addr)
     return vic20_cpu_last_data;
 }
 
+/* FIXME: the upper 4 bits of the mask are used to indicate the register size if not equal to the mask,
+          this is done as a temporary HACK to keep mirrors working and still get the correct register size,
+          this needs to be fixed properly after the 3.6 release */
 /* peek from I/O area with no side-effects */
 static inline uint8_t io_peek(io_source_list_t *list, uint16_t addr)
 {
@@ -357,9 +364,9 @@ static inline uint8_t io_peek(io_source_list_t *list, uint16_t addr)
     while (current) {
         if (addr >= current->device->start_address && addr <= current->device->end_address) {
             if (current->device->peek) {
-                return current->device->peek((uint16_t)(addr & current->device->address_mask));
+                return current->device->peek((uint16_t)(addr & (current->device->address_mask & 0x3ff)));
             } else if (current->device->read) {
-                return current->device->read((uint16_t)(addr & current->device->address_mask));
+                return current->device->read((uint16_t)(addr & (current->device->address_mask & 0x3ff)));
             }
         }
         current = current->next;
@@ -368,6 +375,9 @@ static inline uint8_t io_peek(io_source_list_t *list, uint16_t addr)
     return vic20_cpu_last_data;
 }
 
+/* FIXME: the upper 4 bits of the mask are used to indicate the register size if not equal to the mask,
+          this is done as a temporary HACK to keep mirrors working and still get the correct register size,
+          this needs to be fixed properly after the 3.6 release */
 static inline void io_store(io_source_list_t *list, uint16_t addr, uint8_t value)
 {
     io_source_list_t *current = list->next;
@@ -377,7 +387,7 @@ static inline void io_store(io_source_list_t *list, uint16_t addr, uint8_t value
     while (current) {
         if (current->device->store != NULL) {
             if (addr >= current->device->start_address && addr <= current->device->end_address) {
-                current->device->store((uint16_t)(addr & current->device->address_mask), value);
+                current->device->store((uint16_t)(addr & (current->device->address_mask & 0x3ff)), value);
             }
         }
         current = current->next;
@@ -405,6 +415,13 @@ io_source_list_t *io_source_register(io_source_t *device)
         case 0x9c00:
             current = &vic20io3_head;
             break;
+        default:
+            log_error(LOG_DEFAULT,
+                    "io_source_register internal error: I/O range 0x%04x "
+                    "does not exist",
+                    device->start_address & 0xff00U);
+            archdep_vice_exit(-1);
+            break;
     }
 
     while (current->next != NULL) {
@@ -528,49 +545,33 @@ void vic20io3_store(uint16_t addr, uint8_t value)
 
 /* ---------------------------------------------------------------------------------------------------------- */
 
-static int decodemask(uint16_t mask)
+/* FIXME: the upper 4 bits of the mask are used to indicate the register size if not equal to the mask,
+          this is done as a temporary HACK to keep mirrors working and still get the correct register size,
+          this needs to be fixed properly after the 3.6 release */
+static void io_source_ioreg_add_onelist(struct mem_ioreg_list_s **mem_ioreg_list, io_source_list_t *current)
 {
-    int len = 255;
+    uint16_t end;
 
-    while (((mask & 0x200) == 0) && (len > 0)) {
-        mask <<= 1;
-        len >>= 1;
+    while (current) {
+        end = current->device->end_address;
+        if (current->device->address_mask & 0xf000) {
+            end = current->device->start_address + (current->device->address_mask >> 12);
+        } else if (end > current->device->start_address + current->device->address_mask) {
+            end = current->device->start_address + current->device->address_mask;
+        }
+
+        mon_ioreg_add_list(mem_ioreg_list, current->device->name, current->device->start_address,
+                           end, current->device->dump, NULL, current->device->mirror_mode);
+        current = current->next;
     }
-
-    return len;
 }
 
 /* add all registered I/O devices to the list for the monitor */
 void io_source_ioreg_add_list(struct mem_ioreg_list_s **mem_ioreg_list)
 {
-    io_source_list_t *current;
-
-    current = vic20io0_head.next;
-
-    while (current) {
-        mon_ioreg_add_list(mem_ioreg_list, current->device->name, current->device->start_address,
-                           current->device->start_address + decodemask(current->device->address_mask),
-                           current->device->dump, NULL, current->device->mirror_mode);
-        current = current->next;
-    }
-
-    current = vic20io2_head.next;
-
-    while (current) {
-        mon_ioreg_add_list(mem_ioreg_list, current->device->name, current->device->start_address,
-                           current->device->start_address + decodemask(current->device->address_mask),
-                           current->device->dump, NULL, current->device->mirror_mode);
-        current = current->next;
-    }
-
-    current = vic20io3_head.next;
-
-    while (current) {
-        mon_ioreg_add_list(mem_ioreg_list, current->device->name, current->device->start_address,
-                           current->device->start_address + decodemask(current->device->address_mask),
-                           current->device->dump, NULL, current->device->mirror_mode);
-        current = current->next;
-    }
+    io_source_ioreg_add_onelist(mem_ioreg_list, vic20io0_head.next);
+    io_source_ioreg_add_onelist(mem_ioreg_list, vic20io2_head.next);
+    io_source_ioreg_add_onelist(mem_ioreg_list, vic20io3_head.next);
 }
 
 /* ---------------------------------------------------------------------------------------------------------- */
