@@ -32,6 +32,7 @@
 #include "vic20cart.h"
 #include "vic20mem.h"
 #include "vic20model.h"
+#include "vic20rom.h"
 #include "machine.h"
 #include "resources.h"
 #include "types.h"
@@ -40,6 +41,7 @@ struct model_s {
     int video;   /* machine video timing */
     int ramblocks;
     char *chargenname;
+    char *kernalname;
 };
 
 enum {
@@ -50,23 +52,25 @@ enum {
     BLOCK_5 = 1 << 5
 };
 
+/* FIXME: JAP and NTSC machines should use different kernal ROMs */
 static const struct model_s vic20models[] = {
-    { MACHINE_SYNC_PAL,  NO_EXTRA_RAM, "chargen"},
-    { MACHINE_SYNC_NTSC, NO_EXTRA_RAM, "chargen"},
-    { MACHINE_SYNC_NTSC, BLOCK_1 | BLOCK_2, "chargen"}, /* SuperVIC */
-    { MACHINE_SYNC_NTSC, NO_EXTRA_RAM, "chargen-jp"},    /* vic-1001 (japanese VIC20) */
+    { MACHINE_SYNC_PAL,  NO_EXTRA_RAM, VIC20_CHARGEN_NAME, VIC20_KERNAL_REV7_NAME},
+    { MACHINE_SYNC_NTSC, NO_EXTRA_RAM, VIC20_CHARGEN_NAME, VIC20_KERNAL_REV6_NAME},
+    { MACHINE_SYNC_NTSC, BLOCK_1 | BLOCK_2, VIC20_CHARGEN_NAME, VIC20_KERNAL_REV6_NAME}, /* SuperVIC */
+    { MACHINE_SYNC_NTSC, NO_EXTRA_RAM, VIC20_CHARGEN_JAP_NAME, VIC20_KERNAL_REV2_NAME},    /* vic-1001 (japanese VIC20) */
 };
 
 /* ------------------------------------------------------------------------- */
 
-static int vic20model_get_temp(int video, int ramblocks, const char *chargen)
+static int vic20model_get_temp(int video, int ramblocks, const char *chargen, const char *kernal)
 {
     int i;
 
     for (i = 0; i < VIC20MODEL_NUM; ++i) {
         if ((vic20models[i].video == video)
             && (vic20models[i].ramblocks == ramblocks)
-            && (chargen ? !strcmp(vic20models[i].chargenname, chargen) : 1)) {
+            && (chargen && (strcmp(vic20models[i].chargenname, chargen) == 0))
+            && (kernal && (strcmp(vic20models[i].kernalname, kernal) == 0))) {
             return i;
         }
     }
@@ -77,8 +81,8 @@ static int vic20model_get_temp(int video, int ramblocks, const char *chargen)
 int vic20model_get(void)
 {
     int video, ramblocks, block0, block1, block2, block3, block5;
-    char c[0x10];
-    const char *chargen = c;
+    const char *chargen;
+    const char *kernal;
 
     if ((resources_get_int("MachineVideoStandard", &video) < 0)
         || (resources_get_int("RamBlock0", &block0) < 0)
@@ -86,7 +90,8 @@ int vic20model_get(void)
         || (resources_get_int("RamBlock2", &block2) < 0)
         || (resources_get_int("RamBlock3", &block3) < 0)
         || (resources_get_int("RamBlock5", &block5) < 0)
-        || (resources_get_string("ChargenName", &chargen) < 0)) {
+        || (resources_get_string("ChargenName", &chargen) < 0)
+        || (resources_get_string("KernalName", &kernal) < 0)) {
         return -1;
     }
     ramblocks = (block0 ? BLOCK_0 : 0);
@@ -94,7 +99,7 @@ int vic20model_get(void)
     ramblocks |= (block2 ? BLOCK_2 : 0);
     ramblocks |= (block3 ? BLOCK_3 : 0);
     ramblocks |= (block5 ? BLOCK_5 : 0);
-    return vic20model_get_temp(video, ramblocks, chargen);
+    return vic20model_get_temp(video, ramblocks, chargen, kernal);
 }
 
 #if 0
@@ -131,4 +136,5 @@ void vic20model_set(int model)
     resources_set_int("RamBlock3", blocks & BLOCK_3 ? 1 : 0);
     resources_set_int("RamBlock5", blocks & BLOCK_5 ? 1 : 0);
     resources_set_string("ChargenName", vic20models[model].chargenname);
+    resources_set_string("KernalName", vic20models[model].kernalname);
 }
