@@ -31,29 +31,12 @@
 #ifndef VICE_VICE_H
 #define VICE_VICE_H
 
-#ifdef ANDROID_COMPILE
-#  include "config.android.h"
-#else
-#  include "config.h" /* Automagically created by the `configure' script.  */
-#endif
+#include "config.h" /* Automagically created by the `configure' script.  */
 
 /* ------------------------------------------------------------------------- */
 
 /* Portability... */
 
-/*
- * I really wonder if we need this anymore, when was the last time VICE was
- * compiled with anything not GCC or Clang?
- */
-#if defined(__IBMC__)
-#ifndef _POSIX_SOURCE
-#define _POSIX_SOURCE
-#endif
-#ifndef _INCLUDE_POSIX_SOURCE
-#define _INCLUDE_POSIX_SOURCE
-#endif
-#endif  /* __hpux, nope __IMBC__ at best */
-
 /* currently tested/testing for the following cpu types:
  *
  * (please let's get rid of this, I personally enjoy making stuff work on OS's
@@ -102,76 +85,67 @@
 #define ALLOW_UNALIGNED_ACCESS
 #endif
 
-/* SunOS 4.x specific stuff */
-#if defined(sun) || defined(__sun)
-#  if !defined(__SVR4) && !defined(__svr4__)
-#    include <unistd.h>
-typedef int ssize_t;
-#  endif
-#endif
-
-/* ------------------------------------------------------------------------- */
-/* A common define for the SDL UIs. */
-#if defined(USE_SDLUI) || defined(USE_SDLUI2)
-#define SDL_UI_SUPPORT
-#endif
-
 /* ------------------------------------------------------------------------- */
 
-#ifdef __OS2__
-int yyparse (void);
-#undef __GNUC__
-#endif
-
-
-#if (defined(__BEOS__) && defined(WORDS_BIGENDIAN)) || defined(__OS2__)
+#if (defined(BEOS_COMPILE) && defined(WORDS_BIGENDIAN))
 #ifndef __cplusplus
 #undef inline
 #define inline
 #endif
 #endif
 
-/* interix using c89 doesn't like empty files, this will work around that */
-#if defined(_MSC_VER) && defined(__INTERIX)
-static int noop;
-#endif
-
 #ifdef USE_GCC
 #define int64_t_C(c) (c ## ll)
 #define uint64_t_C(c) (c ## ull)
 #endif
 
-/* sortix does not have rs232 support */
-#ifdef __sortix__
-#undef HAVE_RS232DEV
-#endif
-
 /* Avoid windows.h including too much garbage
  */
-#ifdef WIN32_COMPILE
+#ifdef WINDOWS_COMPILE
 # define WIN32_LEAN_AND_MEAN
 #endif
 
+/* Provide define for checking 32/64-bit Windows
+ *
+ * No need for WIN32_COMPILE, just use !WIN64_COMPILE. Avoid confusion with the
+ * old WIN23_COMPILE define.
+ */
+#ifdef WINDOWS_COMPILE
+# ifdef _WIN64
+#  define WIN64_COMPILE
+# endif
+#endif
+
 /* some attribute defines that are useful mostly for static analysis */
 /* see https://clang.llvm.org/docs/AttributeReference.html */
 #ifdef __clang__
 #define VICE_ATTR_NORETURN  __attribute__((analyzer_noreturn))
+#elif defined(__GNUC__)
+#define VICE_ATTR_NORETURN  __attribute__((noreturn))
 #else
 #define VICE_ATTR_NORETURN
 #endif
 
-
-/* Not all platforms have fseeko()/fseeko(), so we define macros here that use
- * fseek()/ftell() instead. Which is wrong, but will have to do before proper
- * fixes after the 3.6 release. (so: FIXME!)
- *
- * -- Compyx, 2021-11-10, in response to bug #1612
- */
-#ifndef HAVE_FSEEKO
-#define fseeko(stream, offset, whence) fseek(stream, offset, whence)
+/* format checking attributes for printf style functions */
+#if defined(__GNUC__)
+/* like regular printf, func(format, ...) */
+#define VICE_ATTR_PRINTF    __attribute__((format(printf, 1, 2)))
+/* one extra param on the left, func(param, format, ...) */
+#define VICE_ATTR_PRINTF2   __attribute__((format(printf, 2, 3)))
+/* two extra param on the left, func(param, param, format, ...) */
+#define VICE_ATTR_PRINTF3   __attribute__((format(printf, 3, 4)))
+/* one extra param after the format, func(format, param, ...) (used for resource sprintf) */
+#define VICE_ATTR_RESPRINTF __attribute__((format(printf, 1, 3)))
+#else
+#define VICE_ATTR_PRINTF
+#define VICE_ATTR_PRINTF2
+#define VICE_ATTR_PRINTF3
+#define VICE_ATTR_RESPRINTF
 #endif
-#ifndef HAVE_FTELLO
-#define ftello(stream) ftell(stream)
+
+/* M_PI is non-standard, so in order for -std=c99 to work we define it here */
+#ifndef M_PI
+#define M_PI 3.14159265358979323846
 #endif
 
 #endif
