@@ -34,6 +34,7 @@
 #include "interrupt.h"
 #include "log.h"
 #include "mem.h"
+#include "raster-snapshot.h"
 #include "raster-sprite-status.h"
 #include "raster-sprite.h"
 #include "snapshot.h"
@@ -104,9 +105,9 @@ void vicii_snapshot_prepare(void)
 
  */
 
-static char snap_module_name[] = "VIC-II";
+static const char snap_module_name[] = "VIC-II";
 #define SNAP_MAJOR 1
-#define SNAP_MINOR 1
+#define SNAP_MINOR 3
 
 int vicii_snapshot_write_module(snapshot_t *s)
 {
@@ -196,7 +197,7 @@ int vicii_snapshot_write_module(snapshot_t *s)
 
     if (0
         /* FetchEventTick */
-        || SMW_DW(m, vicii.fetch_clk - maincpu_clk) < 0
+        || SMW_CLOCK(m, vicii.fetch_clk - maincpu_clk) < 0
         /* FetchEventType */
         || SMW_B(m, (uint8_t)vicii.fetch_idx) < 0) {
         goto fail;
@@ -215,6 +216,10 @@ int vicii_snapshot_write_module(snapshot_t *s)
         goto fail;
     }
 
+    if (raster_snapshot_write(m, &vicii.raster)) {
+        goto fail;
+    }
+
     return snapshot_module_close(m);
 
 fail:
@@ -492,17 +497,17 @@ int vicii_snapshot_read_module(snapshot_t *s)
     alarm_set(vicii.raster_draw_alarm, vicii.draw_clk);
 
     {
-        uint32_t dw;
+        CLOCK qw;
         uint8_t b;
 
         if (0
-            || SMR_DW(m, &dw) < 0  /* FetchEventTick */
+            || SMR_CLOCK(m, &qw) < 0  /* FetchEventTick */
             || SMR_B(m, &b) < 0    /* FetchEventType */
             ) {
             goto fail;
         }
 
-        vicii.fetch_clk = maincpu_clk + dw;
+        vicii.fetch_clk = maincpu_clk + qw;
         vicii.fetch_idx = b;
 
         alarm_set(vicii.raster_fetch_alarm, vicii.fetch_clk);
@@ -513,7 +518,7 @@ int vicii_snapshot_read_module(snapshot_t *s)
     }
 
     /* added in version 1.1 of snapshot format */
-    if (minor_version > 0) {
+    if (major_version >= 1 && minor_version >= 1) {
         uint32_t RamBase;
 
         if (0
@@ -527,6 +532,10 @@ int vicii_snapshot_read_module(snapshot_t *s)
         vicii_update_memory_ptrs(VICII_RASTER_CYCLE(maincpu_clk));
     }
 
+    if (raster_snapshot_read(m, &vicii.raster)) {
+        goto fail;
+    }
+
     raster_force_repaint(&vicii.raster);
     snapshot_module_close(m);
     return 0;
