@@ -284,15 +284,11 @@ static DRAW_INLINE void draw_graphics8(unsigned int cycle_flags)
         if (!vicii.idle_state) {
             vbuf_pipe0_reg = vicii.vbuf[dmli];
             cbuf_pipe0_reg = vicii.cbuf[dmli];
+            dmli++;
         } else {
             vbuf_pipe0_reg = 0;
             cbuf_pipe0_reg = 0;
         }
-    }
-
-    /* update display index in the visible region */
-    if (vis_en) {
-        dmli++;
     } else {
         dmli = 0;
     }
