@@ -30,19 +30,6 @@
 #include "palette.h"
 #include "types.h"
 
-/* shared gamma table for renderers */
-extern uint32_t gamma_red[256 * 3];
-extern uint32_t gamma_grn[256 * 3];
-extern uint32_t gamma_blu[256 * 3];
-
-/* shared gamma table for renderers */
-extern uint32_t gamma_red_fac[256 * 3 * 2];
-extern uint32_t gamma_grn_fac[256 * 3 * 2];
-extern uint32_t gamma_blu_fac[256 * 3 * 2];
-
-/* optional alpha value for 32bit rendering */
-extern uint32_t alpha;
-
 extern void video_color_palette_free(struct palette_s *palette);
 
 #endif
